/*****************************************************************************
 *  Rohde&Schwarz SFU Broadcast Test System instrument driver    
 *  VXIpnp Style Instrument Driver
 *  Original Release: 10/2005
 *  By: Jiri Kominek
 *
 *  Should you have any technical questions please contact the hotline of
 *  Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
 *
 *  e-mail: CustomerSupport@rohde-schwarz.com
 *
 *****************************************************************************/

#ifndef __RSSFU_HEADER
#define __RSSFU_HEADER

#include "rsidr_core.h"
#include "rssfu_attributes.h"
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif


/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/


/* Class Driver Identification */

#define RSSFU_CLASS_DRIVER_DESCRIPTION           ""
#define RSSFU_CLASS_DRIVER_PREFIX                ""
#define RSSFU_CLASS_DRIVER_VENDOR                ""
#define RSSFU_CLASS_DRIVER_REVISION              ""
#define RSSFU_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSSFU_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSSFU_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSSFU_SPECIFIC_DRIVER_PREFIX             "rssfu"
#define RSSFU_SPECIFIC_DRIVER_LOCATOR            ""
#define RSSFU_SPECIFIC_DRIVER_VENDOR             ""
#define RSSFU_MAJOR_VERSION                      2L    /* Instrument driver major version          */
#define RSSFU_MINOR_VERSION                      80   /* Instrument driver minor version          */
#define RSSFU_MINOR_MINOR_VERSION                14L    /* Instrument driver minor minor version    */

/* Driver Capabilities */          

#define RSSFU_SUPPORTED_INSTRUMENT_MODELS        ""    /* Instrument driver supported model(s)     */
#define RSSFU_GROUP_CAPABILITIES                 ""
#define RSSFU_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSSFU_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSSFU_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSSFU_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSSFU_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSSFU_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSSFU_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSSFU_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSSFU_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSSFU_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSSFU_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSSFU_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSSFU_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSSFU_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSSFU_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSSFU_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSSFU_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSSFU_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSSFU_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSSFU_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSSFU_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSSFU_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSSFU_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSSFU_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSSFU_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSSFU_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSSFU_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSSFU_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSSFU_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSSFU_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSSFU_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSSFU_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    
    /*- Instrument-Specific Attributes -------------------------------------*/
/* BEGIN GENERATE */
#define RSSFU_ATTR_FREQ_CW                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1
#define RSSFU_ATTR_FREQ_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2
#define RSSFU_ATTR_FREQ_MODE_BTC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1247
#define RSSFU_ATTR_FREQ_OFFSET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3
#define RSSFU_ATTR_FREQ_ACT_CENTER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSSFU_ATTR_FREQ_CHANNEL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define RSSFU_ATTR_FREQ_CHANNEL_NAME                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6
#define RSSFU_ATTR_FREQ_CHANNEL_TABLE_SELECT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define RSSFU_ATTR_FREQ_CHANNEL_TABLE_STORE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 8
#define RSSFU_ATTR_FREQ_CHANNEL_TABLE_DELETE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSSFU_ATTR_FREQ_VSB_REF_POINT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define RSSFU_ATTR_FREQ_SWE_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 11
#define RSSFU_ATTR_FREQ_SWE_CENTER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define RSSFU_ATTR_FREQ_SWE_SPAN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 13
#define RSSFU_ATTR_FREQ_SWE_START                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define RSSFU_ATTR_FREQ_SWE_STOP                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define RSSFU_ATTR_FREQ_SWE_MAN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define RSSFU_ATTR_FREQ_SWE_DWELL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define RSSFU_ATTR_FREQ_SWE_TRIG                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 18
#define RSSFU_ATTR_FREQ_SWE_RESET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 19
#define RSSFU_ATTR_FREQ_SWE_SPACING                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 20
#define RSSFU_ATTR_FREQ_SWE_STEP_LIN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 21
#define RSSFU_ATTR_FREQ_SWE_STEP_LOG                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 22
#define RSSFU_ATTR_POW_PEAK_ENVELOPE_POWER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 23
#define RSSFU_ATTR_POW_LEVEL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 24
#define RSSFU_ATTR_TX_VOLATGE_LEVEL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1276
#define RSSFU_ATTR_RFOUT_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define RSSFU_ATTR_POW_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define RSSFU_ATTR_POW_USER_LIMIT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define RSSFU_ATTR_RFOUT_AMODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define RSSFU_ATTR_RFOUT_ATT_MIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define RSSFU_ATTR_RFOUT_ATT_MAX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define RSSFU_ATTR_RFOUT_CLEAR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define RSSFU_ATTR_RFOUT_TRIPPED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 32
#define RSSFU_ATTR_POW_ALC_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 33
#define RSSFU_ATTR_POW_ALCOFF_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 34
#define RSSFU_ATTR_POW_ALC_SEARCH_ONCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 35
#define RSSFU_ATTR_POW_LEV_UNIT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 36
#define RSSFU_ATTR_MOD_DM_MODULATION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define RSSFU_ATTR_MOD_DM_SIGNAL_SOURCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1245
#define RSSFU_ATTR_MOD_DM_TRANSMISSION_STANDARD                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define RSSFU_ATTR_MOD_DM_SIGNAL_SOURCE_BTC                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1244
#define RSSFU_ATTR_MOD_DM_ATV_TRANSMISSION_STANDARD                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define RSSFU_ATTR_MOD_DM_SPECTRUM                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 41
#define RSSFU_ATTR_MOD_DM_INTERFERER_SOURCE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 42
#define RSSFU_ATTR_MOD_DM_ATV_PREDEF_STANDARD                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 43
#define RSSFU_ATTR_MOD_DM_INTERFERER_ATTENUATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 44
#define RSSFU_ATTR_MOD_DM_INTERFERER_ADDITION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define RSSFU_ATTR_MOD_DM_INTERFERER_FREQ_OFFSET                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 46
#define RSSFU_ATTR_MOD_DM_INTERFERER_ARB_ATTENUATION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1277
#define RSSFU_ATTR_MOD_DM_INTERFERER_ARB_FREQ_OFFSET                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1278
#define RSSFU_ATTR_MOD_DM_SIGNAL_FREQ_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 47
#define RSSFU_ATTR_TX_MOD_INTERFERER_REFERENCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 48
#define RSSFU_ATTR_TX_MOD_INTERFERER_LEVEL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 49
#define RSSFU_ATTR_MOD_DM_INTERFERER_ARB_LEVEL                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1279
#define RSSFU_ATTR_MOD_AUDIO_BC_STANDARD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 50
#define RSSFU_ATTR_TX_MODULATION_SPECTRUM_INVERSION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1266
#define RSSFU_ATTR_MOD_MODULATOR_LEVEL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 51
#define RSSFU_ATTR_MOD_MODULATOR_LEVEL_BTC                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1248
#define RSSFU_ATTR_MOD_WIDEBAND_IN_CREST_FACTOR                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 52
#define RSSFU_ATTR_MOD_WIDEBAND_RF_FILTERING                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define RSSFU_ATTR_MOD_DIGITAL_IN_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 54
#define RSSFU_ATTR_MOD_DIGITAL_OUTPUT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 55
#define RSSFU_ATTR_MOD_ANALOG_IQ_INPUT_RMS_VAL                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 56
#define RSSFU_ATTR_MOD_ANALOG_IQ_INPUT_PEAK_VAL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 57
#define RSSFU_ATTR_MOD_DIGITAL_IQ_INPUT_RMS_VAL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 58
#define RSSFU_ATTR_MOD_DIGITAL_IQ_INPUT_PEAK_VAL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 59
#define RSSFU_ATTR_MOD_DIGITAL_IQ_INPUT_REFRESH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 60
#define RSSFU_ATTR_MOD_ANALOG_IQ_INPUT_REFRESH                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 61
#define RSSFU_ATTR_MODULATION_DIGITAL_IQ_INPUT_SYMBOL_RATE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 62
#define RSSFU_ATTR_BTC_INPUT_SIGNAL_SOURCE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1249
#define RSSFU_ATTR_BTC_INPUT_SIGNAL_INPUT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1250
#define RSSFU_ATTR_BTC_INPUT_SIGNAL_INPUT_LOW                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1251
#define RSSFU_ATTR_BTC_INPUT_SIGNAL_IP_TS_CHANNEL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1252
#define RSSFU_ATTR_BTC_C2_INPUT_SIGNAL_IP_TS_CHANNEL                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1253
#define RSSFU_ATTR_BTC_S2_INPUT_SIGNAL_IP_TS_CHANNEL                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1254
#define RSSFU_ATTR_IQC_DVBT_MIPC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 63
#define RSSFU_ATTR_IQC_DVBT_SOUR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 65
#define RSSFU_ATTR_IQC_DVBT_SOUR_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 66
#define RSSFU_ATTR_IQC_DVBT_INP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 67
#define RSSFU_ATTR_IQC_DVBT_INP_LOW                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 68
#define RSSFU_ATTR_IQC_DVBT_STUF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 69
#define RSSFU_ATTR_IQC_DVBT_STUF_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 70
#define RSSFU_ATTR_IQC_DVBT_TEST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 71
#define RSSFU_ATTR_IQC_DVBT_TEST_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 72
#define RSSFU_ATTR_IQC_DVBT_PACKET_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 73
#define RSSFU_ATTR_IQC_DVBT_PACKET_LENGTH_LOW                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 74
#define RSSFU_ATTR_IQC_DVBT_MAX_USEFUL_DATA_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 75
#define RSSFU_ATTR_IQC_DVBT_MAX_USEFUL_DATA_RATE_LOW                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 76
#define RSSFU_ATTR_IQC_DVBT_MEASURED_DATA_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 77
#define RSSFU_ATTR_IQC_DVBT_MEASURED_DATA_RATE_LOW                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 78
#define RSSFU_ATTR_IQC_DVBT_USEFUL_DATA_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 79
#define RSSFU_ATTR_IQC_DVBT_USEFUL_DATA_RATE_LOW                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 80
#define RSSFU_ATTR_IQC_DVBT_CHAN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 81
#define RSSFU_ATTR_IQC_DVBT_USED_RESULT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 82
#define RSSFU_ATTR_IQC_DVBT_FFT_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 83
#define RSSFU_ATTR_IQC_DVBT_GUAR_INT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 84
#define RSSFU_ATTR_IQC_DVBT_HIER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 85
#define RSSFU_ATTR_IQC_DVBT_CONS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 86
#define RSSFU_ATTR_IQC_DVBT_RATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 87
#define RSSFU_ATTR_IQC_DVBT_RATE_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 88
#define RSSFU_ATTR_IQC_DVBT_DVHS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 89
#define RSSFU_ATTR_IQC_DVBT_DVBH_SYMB                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 90
#define RSSFU_ATTR_IQC_DVBT_SETT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 91
#define RSSFU_ATTR_IQC_DVBT_SCR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 92
#define RSSFU_ATTR_IQC_DVBT_SCR_LOW                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 93
#define RSSFU_ATTR_IQC_DVBT_SYNC_INV                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 94
#define RSSFU_ATTR_IQC_DVBT_SYNC_INV_LOW                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 95
#define RSSFU_ATTR_IQC_DVBT_REED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 96
#define RSSFU_ATTR_IQC_DVBT_REED_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 97
#define RSSFU_ATTR_IQC_DVBT_CONV                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 98
#define RSSFU_ATTR_IQC_DVBT_CONV_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 99
#define RSSFU_ATTR_IQC_DVBT_BIT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 100
#define RSSFU_ATTR_IQC_DVBT_SYMB                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 101
#define RSSFU_ATTR_IQC_DVBT_GUAR_STAT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 102
#define RSSFU_ATTR_IQC_DVBT_DATA_MOD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 103
#define RSSFU_ATTR_IQC_DVBT_PIL_MOD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 104
#define RSSFU_ATTR_IQC_DVBT_TPS_MOD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 105
#define RSSFU_ATTR_IQC_DVBT_DATA                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 106
#define RSSFU_ATTR_IQC_DVBT_PIL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 107
#define RSSFU_ATTR_IQC_DVBT_TPS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 108
#define RSSFU_ATTR_IQC_DVBT_EQU                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 109
#define RSSFU_ATTR_IQC_DVBT_DIS_CARR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 110
#define RSSFU_ATTR_DVBT_SPECIAL_LOAD_CARRIERS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 111
#define RSSFU_ATTR_DVBT_SPECIAL_STORE_CARRIERS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 112
#define RSSFU_ATTR_IQC_DVBT_TSP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 113
#define RSSFU_ATTR_IQC_DVBT_PIDT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 114
#define RSSFU_ATTR_IQC_DVBT_PID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 115
#define RSSFU_ATTR_IQC_DVBT_PAYL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 116
#define RSSFU_ATTR_IQC_DVBT_PRBS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 117
#define RSSFU_ATTR_IQC_DVBT_CELL_ID                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 118
#define RSSFU_ATTR_IQC_DVBT_TPSR_STAT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 119
#define RSSFU_ATTR_IQC_DVBT_TPSR_VAL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 120
#define RSSFU_ATTR_IQC_DVBT_TIM                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 121
#define RSSFU_ATTR_IQC_DVBT_TIM_LOW                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 122
#define RSSFU_ATTR_IQC_DVBT_MPEF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 123
#define RSSFU_ATTR_IQC_DVBT_MPEF_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 124
#define RSSFU_ATTR_IQC_DVBT_LOCK                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 125
#define RSSFU_ATTR_IQC_DVBT_LOCK_HIGH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 126
#define RSSFU_ATTR_IQC_DVBT_LOCK_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 127
#define RSSFU_ATTR_IQC_DVBC_LOCK                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 128
#define RSSFU_ATTR_IQC_DVBC_SOUR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 129
#define RSSFU_ATTR_IQC_DVBC_INP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 130
#define RSSFU_ATTR_IQC_DVBC_STUF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 131
#define RSSFU_ATTR_IQC_DVBC_TEST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 132
#define RSSFU_ATTR_IQC_DVBC_PACKET_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 133
#define RSSFU_ATTR_IQC_DVBC_MAX_USEFUL_DATA_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 134
#define RSSFU_ATTR_IQC_DVBC_MEASURED_DATA_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 135
#define RSSFU_ATTR_IQC_DVBC_USEFUL_DATA_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 136
#define RSSFU_ATTR_IQC_DVBC_SYMB                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 137
#define RSSFU_ATTR_IQC_DVBC_CONS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 138
#define RSSFU_ATTR_IQC_DVBC_ROLL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 139
#define RSSFU_ATTR_IQC_DVBC_SETT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 140
#define RSSFU_ATTR_IQC_DVBC_SCR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 141
#define RSSFU_ATTR_IQC_DVBC_SYNC_INV                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 142
#define RSSFU_ATTR_IQC_DVBC_REED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 143
#define RSSFU_ATTR_IQC_DVBC_INT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 144
#define RSSFU_ATTR_IQC_DVBC_TSP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 145
#define RSSFU_ATTR_IQC_DVBC_PIDT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 146
#define RSSFU_ATTR_IQC_DVBC_PID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 147
#define RSSFU_ATTR_IQC_DVBC_PAYL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 148
#define RSSFU_ATTR_IQC_DVBC_PRBS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 149
#define RSSFU_ATTR_IQC_DVBS_LOCK                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 150
#define RSSFU_ATTR_IQC_DVBS_SOUR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 151
#define RSSFU_ATTR_IQC_DVBS_INP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 152
#define RSSFU_ATTR_IQC_DVBS_STUF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 153
#define RSSFU_ATTR_IQC_DVBS_TEST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 154
#define RSSFU_ATTR_IQC_DVBS_PACKET_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 155
#define RSSFU_ATTR_IQC_DVBS_MAX_USEFUL_DATA_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 156
#define RSSFU_ATTR_IQC_DVBS_MEASURED_DATA_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 157
#define RSSFU_ATTR_IQC_DVBS_USEFUL_DATA_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 158
#define RSSFU_ATTR_IQC_DVBS_REQ_DATA_RATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 159
#define RSSFU_ATTR_IQC_DVBS_SYMB                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 160
#define RSSFU_ATTR_IQC_DVBS_CONS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 161
#define RSSFU_ATTR_IQC_DVBS_ROLL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 162
#define RSSFU_ATTR_IQC_DVBS_ROLL_BTC                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1273
#define RSSFU_ATTR_IQC_DVBS_RATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 163
#define RSSFU_ATTR_IQC_DVBS_SETT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 164
#define RSSFU_ATTR_IQC_DVBS_SCR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 165
#define RSSFU_ATTR_IQC_DVBS_SYNC_INV                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 166
#define RSSFU_ATTR_IQC_DVBS_REED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 167
#define RSSFU_ATTR_IQC_DVBS_INT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 168
#define RSSFU_ATTR_IQC_DVBS_TSP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 169
#define RSSFU_ATTR_IQC_DVBS_PIDT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 170
#define RSSFU_ATTR_IQC_DVBS_PID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 171
#define RSSFU_ATTR_IQC_DVBS_PAYL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 172
#define RSSFU_ATTR_IQC_DVBS_PRBS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 173
#define RSSFU_ATTR_IQC_8VSB_LOCK                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 174
#define RSSFU_ATTR_IQC_8VSB_SOURCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 175
#define RSSFU_ATTR_IQC_8VSB_INPUT_SIGNAL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 176
#define RSSFU_ATTR_IQC_8VSB_STUFFING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 177
#define RSSFU_ATTR_IQC_8VSB_PACKET_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 178
#define RSSFU_ATTR_IQC_8VSB_MAX_USEFUL_DATA_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 179
#define RSSFU_ATTR_IQC_8VSB_MEASURED_DATA_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 180
#define RSSFU_ATTR_IQC_8VSB_USEFUL_DATA_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 181
#define RSSFU_ATTR_IQC_8VSB_TEST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 182
#define RSSFU_ATTR_IQC_8VSB_SYMBOL_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 183
#define RSSFU_ATTR_IQC_8VSB_CONSTELLATION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 184
#define RSSFU_ATTR_IQC_8VSB_ROLL_OFF                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 185
#define RSSFU_ATTR_IQC_8VSB_SPECIAL_SETTINGS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 186
#define RSSFU_ATTR_IQC_8VSB_RANDOMIZER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 187
#define RSSFU_ATTR_IQC_8VSB_REED_SOLOMON                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 188
#define RSSFU_ATTR_IQC_8VSB_INTERLEAVER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 189
#define RSSFU_ATTR_IQC_8VSB_PILOT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 190
#define RSSFU_ATTR_IQC_8VSB_PILOT_VALUE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 191
#define RSSFU_ATTR_IQC_8VSB_TEST_TS_PACKED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 192
#define RSSFU_ATTR_IQC_8VSB_PID_TEST_PACKET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 193
#define RSSFU_ATTR_IQC_8VSB_PID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 194
#define RSSFU_ATTR_IQC_8VSB_PAYLOAD_TEST                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 195
#define RSSFU_ATTR_IQC_8VSB_PRBS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 196
#define RSSFU_ATTR_IQC_J83B_LOCK                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 232
#define RSSFU_ATTR_IQC_J83B_SOURCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 233
#define RSSFU_ATTR_IQC_J83B_INPUT_SIGNAL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 234
#define RSSFU_ATTR_IQC_J83B_STUFFING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 235
#define RSSFU_ATTR_IQC_J83B_PACKET_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 236
#define RSSFU_ATTR_IQC_J83B_MAX_USEFUL_DATA_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 237
#define RSSFU_ATTR_IQC_J83B_MEASURED_DATA_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 238
#define RSSFU_ATTR_IQC_J83B_USEFUL_DATA_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 239
#define RSSFU_ATTR_IQC_J83B_TEST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 240
#define RSSFU_ATTR_IQC_J83B_SYMBOL_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 241
#define RSSFU_ATTR_IQC_J83B_CONSTELLATION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 242
#define RSSFU_ATTR_IQC_J83B_ROLL_OFF                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 243
#define RSSFU_ATTR_IQC_J83B_INTERLEAVER_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 244
#define RSSFU_ATTR_IQC_J83B_SPECIAL_SETTINGS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 245
#define RSSFU_ATTR_IQC_J83B_CHECKSUMGEN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 246
#define RSSFU_ATTR_IQC_J83B_REED_SOLOMON                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 247
#define RSSFU_ATTR_IQC_J83B_INTERLEAVER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 248
#define RSSFU_ATTR_IQC_J83B_RANDOMIZER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 249
#define RSSFU_ATTR_IQC_J83B_TEST_TS_PACKED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 250
#define RSSFU_ATTR_IQC_J83B_PID_TEST_PACKET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 251
#define RSSFU_ATTR_IQC_J83B_PID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 252
#define RSSFU_ATTR_IQC_J83B_PAYLOAD_TEST                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 253
#define RSSFU_ATTR_IQC_J83B_PRBS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 254
#define RSSFU_ATTR_IQC_ISDBT_LOCK                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 255
#define RSSFU_ATTR_IQC_ISDBT_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 256
#define RSSFU_ATTR_IQC_ISDBT_TEST                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 257
#define RSSFU_ATTR_ISDBT_INPUT_SIGNAL_REMUX                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1169
#define RSSFU_ATTR_ISDBT_INPUT_SIGNAL_STUFFING                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1170
#define RSSFU_ATTR_IQC_ISDBT_INPUT_SIGNAL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 258
#define RSSFU_ATTR_IQC_ISDBT_INPUT_DATA_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 259
#define RSSFU_ATTR_IQC_ISDBT_MAX_USEFUL_DATA_RATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 260
#define RSSFU_ATTR_IQC_ISDBT_MEAS_USEFUL_DATA_RATE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 261
#define RSSFU_ATTR_IQC_ISDBT_CODING_SYSTEM                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 262
#define RSSFU_ATTR_ISDBT_CODING_CONTROL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1171
#define RSSFU_ATTR_IQC_ISDBT_PORTION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 263
#define RSSFU_ATTR_IQC_ISDBT_CONSTELLATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 264
#define RSSFU_ATTR_IQC_ISDBT_SEGMENTS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 265
#define RSSFU_ATTR_IQC_ISDBT_CODE_RATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 266
#define RSSFU_ATTR_IQC_ISDBT_TIME_INTERLEAVING                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 267
#define RSSFU_ATTR_IQC_ISDBT_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 268
#define RSSFU_ATTR_IQC_ISDBT_GUARD_INTERVAL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 269
#define RSSFU_ATTR_IQC_ISDBT_CODING_SUB_CHANNEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 270
#define RSSFU_ATTR_IQC_ISDBT_BANDWIDTH_VARIATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 271
#define RSSFU_ATTR_ISDBT_CODING_CHANNEL_BANDWIDTH                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1097
#define RSSFU_ATTR_IQC_ISDBT_BANDWIDTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 272
#define RSSFU_ATTR_IQC_ISDBT_SPECIAL_SETTINGS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 273
#define RSSFU_ATTR_IQC_ISDBT_SCRAMBLER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 274
#define RSSFU_ATTR_IQC_ISDBT_REED_SOLOMON                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 275
#define RSSFU_ATTR_IQC_ISDBT_BYTE_INTERLEAVER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 276
#define RSSFU_ATTR_IQC_ISDBT_BIT_INTERLEAVER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 277
#define RSSFU_ATTR_IQC_ISDBT_FREQUENCY_INTERLEAVER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 278
#define RSSFU_ATTR_IQC_ISDBT_ALERT_BROADCAST_FLAG                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 279
#define RSSFU_ATTR_IQC_ISDBT_DATA_CARRIERS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 280
#define RSSFU_ATTR_IQC_ISDBT_SCATTERED_PILOTS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 281
#define RSSFU_ATTR_IQC_ISDBT_CONTINUAL_PILOTS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 282
#define RSSFU_ATTR_IQC_ISDBT_TMCC_PILOTS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 283
#define RSSFU_ATTR_IQC_ISDBT_AC_PILOTS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 284
#define RSSFU_ATTR_IQC_ISDBT_MOD_DATA_CARRIERS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 285
#define RSSFU_ATTR_IQC_ISDBT_MOD_SCATTERED_PILOTS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 286
#define RSSFU_ATTR_IQC_ISDBT_MOD_CONTINUAL_PILOTS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 287
#define RSSFU_ATTR_IQC_ISDBT_MOD_TMCC_PILOTS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 288
#define RSSFU_ATTR_ISDBT_SPECIAL_SETTINGS_MOD_TMCC_NEXT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 289
#define RSSFU_ATTR_IQC_ISDBT_MOD_AC_PILOTS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 290
#define RSSFU_ATTR_IQC_ISDBT_AC_DATA1                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 291
#define RSSFU_ATTR_IQC_ISDBT_AC_DATA2                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 292
#define RSSFU_ATTR_IQC_ISDBT_GUARD_INSERTION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 293
#define RSSFU_ATTR_ISDBT_SPECIAL_SETT_TX_PARAM_SWITCH_IND                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 294
#define RSSFU_ATTR_IQC_ISDBT_TEST_TS_PACKED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 295
#define RSSFU_ATTR_IQC_ISDBT_PID_TEST_PACKET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 296
#define RSSFU_ATTR_IQC_ISDBT_PID                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 297
#define RSSFU_ATTR_ISDBT_SETTINGS_PAYLOAD_TEST_STUFF                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 298
#define RSSFU_ATTR_IQC_ISDBT_PRBS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 299
#define RSSFU_ATTR_IQC_ISDBT_TEST_TS_PACKED_BTC                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1255
#define RSSFU_ATTR_IQC_ISDBT_PID_TEST_PACKET_BTC                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1256
#define RSSFU_ATTR_IQC_ISDBT_PID_BTC                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1257
#define RSSFU_ATTR_ISDBT_SETTINGS_PAYLOAD_TEST_STUFF_BTC                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1258
#define RSSFU_ATTR_ISDBTMM_INPUT_SIGNAL_SOURCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1179
#define RSSFU_ATTR_ISDBTMM_INPUT_SIGNAL_TEST_SIGNAL                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1181
#define RSSFU_ATTR_ISDBTMM_INPUT_SIGNAL_INPUT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1180
#define RSSFU_ATTR_ISDBTMM_INPUT_SIGNAL_STUFFING                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1182
#define RSSFU_ATTR_READ_ISDBTMM_INPUT_DATA_RATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1183
#define RSSFU_ATTR_READ_ISDBTMM_MAX_USEFUL_DATA_RATE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1184
#define RSSFU_ATTR_ISDBTMM_CODING_CONTROL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1186
#define RSSFU_ATTR_ISDBTMM_CODING_PARTIAL_RECEPTION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1187
#define RSSFU_ATTR_ISDBTMM_CODING_NUMBER_OF_SUPER_SEGMENTS                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1188
#define RSSFU_ATTR_ISDBTMM_CODING_SUPER_SEGMENTS_TYPE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1189
#define RSSFU_ATTR_ISDBTMM_CODING_NUMBER_SEGMENTS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1190
#define RSSFU_ATTR_ISDBTMM_CODING_LAYER_OFDM_SEGMENTS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1191
#define RSSFU_ATTR_ISDBTMM_CODING_LAYER_CENTER_SUBCHANNEL                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1192
#define RSSFU_ATTR_ISDBTMM_CODING_LAYER_CONSTELLATION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1193
#define RSSFU_ATTR_ISDBTMM_CODING_LAYER_CODE_RATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1194
#define RSSFU_ATTR_ISDBTMM_CODING_LAYER_TIME_INTERLEAVING                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1195
#define RSSFU_ATTR_ISDBTMM_CODING_EMERGENCY_ALARM                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1196
#define RSSFU_ATTR_ISDBTMM_CODING_ISDBT_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1197
#define RSSFU_ATTR_ISDBTMM_CODING_GUARD_INTERVAL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1198
#define RSSFU_ATTR_ISDBTMM_CODING_REFERENCE_CHANNEL                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1199
#define RSSFU_ATTR_ISDBTMM_CODING_BANDWIDTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1200
#define RSSFU_ATTR_ISDBTMM_SPECIAL_SETTINGS_STATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1201
#define RSSFU_ATTR_ISDBTMM_SPECIAL_SETTINGS_BYTE_INTERLEAVER                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1202
#define RSSFU_ATTR_ISDBTMM_SPECIAL_SETTINGS_BIT_INTERLEAVER                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1203
#define RSSFU_ATTR_ISDBTMM_SPECIAL_SETTINGS_FREQUENCY_INTERLEAVER           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1204
#define RSSFU_ATTR_ISDBTMM_SPECIAL_REED_SOLOMON                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1205
#define RSSFU_ATTR_ISDBTMM_SPECIAL_SCRAMBLER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1206
#define RSSFU_ATTR_ISDBTMM_SPECIAL_SETTINGS_TX_PARAM_SWITCHING_INDICATOR    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1207
#define RSSFU_ATTR_ISDBTMM_SPECIAL_SETTINGS_TMCC_NEXT                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1208
#define RSSFU_ATTR_ISDBTMM_SETTINGS_TEST_TS_PACKET                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1209
#define RSSFU_ATTR_ISDBTMM_SETTINGS_PAYLOAD_TEST_TS_PACKET                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1210
#define RSSFU_ATTR_ISDBTMM_SETTINGS_PID_TEST_PACKET                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1211
#define RSSFU_ATTR_ISDBTMM_SETTINGS_PID                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1212
#define RSSFU_ATTR_ISDBTMM_SETTINGS_PRBS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1213
#define RSSFU_ATTR_IQC_DMBTH_LOCK                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 300
#define RSSFU_ATTR_IQC_DMBTH_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 301
#define RSSFU_ATTR_IQC_DMBTH_INPUT_SIGNAL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 302
#define RSSFU_ATTR_IQC_DMBTH_STUFFING                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 303
#define RSSFU_ATTR_IQC_DMBTH_PACKET_LENGTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 304
#define RSSFU_ATTR_IQC_DMBTH_MAX_USEFUL_DATA_RATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 305
#define RSSFU_ATTR_IQC_DMBTH_MEASURED_DATA_RATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 306
#define RSSFU_ATTR_IQC_DMBTH_USEFUL_DATA_RATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 307
#define RSSFU_ATTR_IQC_DMBTH_TEST                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 308
#define RSSFU_ATTR_IQC_DMBTH_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 309
#define RSSFU_ATTR_IQC_DMBTH_NETWORK_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 310
#define RSSFU_ATTR_IQC_DMBTH_CONTROL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 311
#define RSSFU_ATTR_IQC_DMBTH_CONSTELLATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 312
#define RSSFU_ATTR_IQC_DMBTH_CONSTELLATION_H                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 313
#define RSSFU_ATTR_IQC_DMBTH_CODE_RATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 314
#define RSSFU_ATTR_IQC_DMBTH_CODE_RATE_H                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 315
#define RSSFU_ATTR_IQC_DMBTH_GUARD_INTERVAL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 316
#define RSSFU_ATTR_IQC_DMBTH_TIME_INTERLEAVER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 317
#define RSSFU_ATTR_IQC_DMBTH_CHANNEL_BANDWIDTH                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 318
#define RSSFU_ATTR_IQC_DMBTH_SIG_TIME_STAMP                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 319
#define RSSFU_ATTR_IQC_DMBTH_MAXIMUM_DELAY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 320
#define RSSFU_ATTR_IQC_DMBTH_LOCAL_DELAY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 321
#define RSSFU_ATTR_IQC_DMBTH_ADDITIONAL_DELAY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 322
#define RSSFU_ATTR_IQC_DMBTH_SPECIAL_SETTINGS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 323
#define RSSFU_ATTR_IQC_DMBTH_GI_POWER_BOOST                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 324
#define RSSFU_ATTR_IQC_DMBTH_LDPC_OUTPUT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 325
#define RSSFU_ATTR_IQC_DMBTH_PN_POLARITY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 326
#define RSSFU_ATTR_IQC_DMBTH_QAM_CONSTELLATION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 327
#define RSSFU_ATTR_IQC_DMBTH_QPSK_CONSTELLATION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 328
#define RSSFU_ATTR_IQC_DMBTH_SPECIAL_SINGLE_CARRIER                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 329
#define RSSFU_ATTR_IQC_DMBTH_CONTROL_FRAMES                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 330
#define RSSFU_ATTR_IQC_DMBTH_TEST_TS_PACKET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 331
#define RSSFU_ATTR_IQC_DMBTH_PID_TEST_PACKED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 332
#define RSSFU_ATTR_IQC_DMBTH_PID                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 333
#define RSSFU_ATTR_IQC_DMBTH_PAYLOAD_TEST                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 334
#define RSSFU_ATTR_IQC_DMBTH_PRBS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 335
#define RSSFU_ATTR_IQC_DMBT_LOCK                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 336
#define RSSFU_ATTR_IQC_DMBT_SOUR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 337
#define RSSFU_ATTR_IQC_DMBT_INP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 338
#define RSSFU_ATTR_IQC_DMBT_STUF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 339
#define RSSFU_ATTR_IQC_DMBT_TEST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 340
#define RSSFU_ATTR_IQC_DMBT_PACKET_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 341
#define RSSFU_ATTR_IQC_DMBT_MAX_USEFUL_DATA_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 342
#define RSSFU_ATTR_IQC_DMBT_MEASURED_DATA_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 343
#define RSSFU_ATTR_IQC_DMBT_USEFUL_DATA_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 344
#define RSSFU_ATTR_IQC_DMBT_NETW                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345
#define RSSFU_ATTR_IQC_DMBT_DEL_ADD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346
#define RSSFU_ATTR_IQC_DMBT_CONT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347
#define RSSFU_ATTR_IQC_DMBT_CHAN_BAND                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348
#define RSSFU_ATTR_IQC_DMBT_CONS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 349
#define RSSFU_ATTR_IQC_DMBT_RATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350
#define RSSFU_ATTR_IQC_DMBT_GUAR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351
#define RSSFU_ATTR_IQC_DMBT_TIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352
#define RSSFU_ATTR_IQC_DMBT_SIGN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353
#define RSSFU_ATTR_IQC_DMBT_DEL_MAX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354
#define RSSFU_ATTR_IQC_DMBT_DEL_LOC                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355
#define RSSFU_ATTR_IQC_DMBT_SETT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356
#define RSSFU_ATTR_IQC_DMBT_SYNC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357
#define RSSFU_ATTR_IQC_DMBT_RAND                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358
#define RSSFU_ATTR_IQC_DMBT_RAND_REST                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359
#define RSSFU_ATTR_IQC_DMBT_BYTE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360
#define RSSFU_ATTR_IQC_DMBT_TPS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361
#define RSSFU_ATTR_IQC_DMBT_GIP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362
#define RSSFU_ATTR_IQC_DMBT_FRAM                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363
#define RSSFU_ATTR_IQC_DMBT_TSP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 364
#define RSSFU_ATTR_IQC_DMBT_PIDT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 365
#define RSSFU_ATTR_IQC_DMBT_PID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 366
#define RSSFU_ATTR_IQC_DMBT_PAYL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 367
#define RSSFU_ATTR_IQC_DMBT_PRBS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 368
#define RSSFU_ATTR_IQC_DTMB_LOCK                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 369
#define RSSFU_ATTR_IQC_DTMB_CODING_SOURCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 370
#define RSSFU_ATTR_IQC_DTMB_CODING_INPUT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 371
#define RSSFU_ATTR_IQC_DTMB_CODING_STUFFING                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 372
#define RSSFU_ATTR_IQC_DTMB_CODING_PACKED_LENGTH                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 373
#define RSSFU_ATTR_IQC_DTMB_CODING_MAX_USEFUL_DATA_RATE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 374
#define RSSFU_ATTR_IQC_DTMB_CODING_MEAS_DATA_RATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 375
#define RSSFU_ATTR_IQC_DTMB_CODING_USEFUL_DATA_RATE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 376
#define RSSFU_ATTR_IQC_DTMB_CODER_TEST_SIGNAL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 377
#define RSSFU_ATTR_IQC_DTMB_CODING_NETWORK_MODE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 378
#define RSSFU_ATTR_IQC_DTMB_CODING_SINGLE_CARRIER_MODE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 379
#define RSSFU_ATTR_IQC_DTMB_CODING_DUAL_PILOT_TONE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 380
#define RSSFU_ATTR_IQC_DTMB_CODING_CONTROL_FRAMES                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 381
#define RSSFU_ATTR_IQC_DTMB_CODING_CONSTELLATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 382
#define RSSFU_ATTR_IQC_DTMB_CODING_CODE_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 384
#define RSSFU_ATTR_IQC_DTMB_CODING_GUARD_INTERVAL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 386
#define RSSFU_ATTR_DTMB_CODING_GUARD_INTERVAL_PN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1098
#define RSSFU_ATTR_IQC_DTMB_SPECIAL_GUARD_INTERVAL_PN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 387
#define RSSFU_ATTR_IQC_DTMB_CODING_TIME_INTERLEAVER                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 388
#define RSSFU_ATTR_IQC_DTMB_CODING_CHANNEL_BANDWIDTH                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 389
#define RSSFU_ATTR_IQC_DTMB_CODING_LOCAL_MAX_DELAY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 391
#define RSSFU_ATTR_DTMB_SFN_DISTRIBUTION_DELAY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1099
#define RSSFU_ATTR_DTMB_SFN_RF_DELAY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1100
#define RSSFU_ATTR_DTMB_SFN_DELAY_OFFSET                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1101
#define RSSFU_ATTR_IQC_DTMB_CODING_LOCAL_DELAY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 392
#define RSSFU_ATTR_DTMB_SFN_TX_ADDRESS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1102
#define RSSFU_ATTR_DTMB_SFN_DELAY_ADJUST                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1103
#define RSSFU_ATTR_DTMB_SFN_FREQUENCY_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1104
#define RSSFU_ATTR_DTMB_SFN_TX_POWER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1105
#define RSSFU_ATTR_IQC_DTMB_SPECIAL_SETTINGS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 394
#define RSSFU_ATTR_IQC_DTMB_SPECIAL_GI_POWER_BOOST                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 396
#define RSSFU_ATTR_DTMB_SPECIAL_CO_CHANNEL_INTERFERER                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1106
#define RSSFU_ATTR_DTMB_SPECIAL_SI_POWER_NORMALIZATION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1107
#define RSSFU_ATTR_IQC_DTMB_SETTINGS_TEST_TS_PACKET                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 401
#define RSSFU_ATTR_IQC_DTMB_SETTINGS_PID_TEST_PACKET                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 402
#define RSSFU_ATTR_IQC_DTMB_SETTINGS_PID                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 403
#define RSSFU_ATTR_IQC_DTMB_SETTINGS_PAYLOAD_TEST_STUFF                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 404
#define RSSFU_ATTR_IQC_DTMB_SETTINGS_PRBS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 405
#define RSSFU_ATTR_CMMB_INPUT_SIGNAL_SOURCE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 438
#define RSSFU_ATTR_CMMB_INPUT_SIGNAL_INPUT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 439
#define RSSFU_ATTR_CMMB_INPUT_SIGNAL_STUFFING                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 440
#define RSSFU_ATTR_READ_CMMB_MAX_USEFUL_DATA_RATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 441
#define RSSFU_ATTR_READ_CMMB_MEASURED_DATA_RATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 442
#define RSSFU_ATTR_CMMB_INPUT_SIGNAL_NUMBER_OF_SERVICES                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 443
#define RSSFU_ATTR_CMMB_INPUT_SIGNAL_TEST_SIGNAL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 444
#define RSSFU_ATTR_CMMB_CODING_CONTROL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 445
#define RSSFU_ATTR_CMMB_CODING_BANDWIDTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 446
#define RSSFU_ATTR_CMMB_CODING_OFDM_MODE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 447
#define RSSFU_ATTR_CMMB_SPECIAL_SETTINGS_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 448
#define RSSFU_ATTR_CMMB_SPECIAL_REED_SOLOMON                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 449
#define RSSFU_ATTR_CMMB_SPECIAL_BYTE_INTERLEAVER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 450
#define RSSFU_ATTR_CMMB_SPECIAL_BIT_INTERLEAVER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 451
#define RSSFU_ATTR_CMMB_SPECIAL_SCRAMBLING                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 452
#define RSSFU_ATTR_CMMB_SETTINGS_TRANSMITTER_ID                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 453
#define RSSFU_ATTR_CMMB_SETTINGS_AREA_ID                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 454
#define RSSFU_ATTR_CMMB_SETTINGS_PAYLOAD_TEST_SIGNAL                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 455
#define RSSFU_ATTR_CMMB_SETTINGS_PRBS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 456
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_INTERFACE_STATE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 457
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_INTERFACE_INPUT                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 458
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_SOURCE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 459
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PID                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1108
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_SID                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1214
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_NUMBER_OF_PLP                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 460
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_INPUT_FORMAT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 461
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_SOURCE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 462
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_INPUT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 463
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_STUFFING                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 464
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_MAX_USEF_DR                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 465
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_MEAS_DR                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 466
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_USEFUL_DR                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 467
#define RSSFU_ATTR_READ_DVBS2_CODING_REQUIRED_SOURCE_DATA_RATE              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1241
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_TEST_SIGNAL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 468
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_RESET_T2_MI_ANALYZER_LOG_FILE         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1109
#define RSSFU_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_ANALYZER                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1110
#define RSSFU_ATTR_DVBT2_MODE_STREAM_ADAPT_PLP_ID                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 469
#define RSSFU_ATTR_DVBT2_MODE_STREAM_ADAPT_PLP_GROUP_ID                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 470
#define RSSFU_ATTR_DVBT2_MODE_STREAM_ADAPT_PLP_TYPE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 471
#define RSSFU_ATTR_DVBT2_MODE_STREAM_ADAPT_BB_MODE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 472
#define RSSFU_ATTR_DVBT2_MODE_STREAM_ADAPT_ISSY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 473
#define RSSFU_ATTR_DVBT2_MODE_STREAM_ADAPT_NULL_PACKET_DEL                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 474
#define RSSFU_ATTR_DVBT2_MODE_STREAM_ADAPT_IN_BAND_SIGNAL                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 475
#define RSSFU_ATTR_DVBT2_MODE_STREAM_ADAPT_IN_BAND_SIGNAL_A                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1111
#define RSSFU_ATTR_DVBT2_MODE_STREAM_ADAPT_IN_BAND_SIGNAL_B                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1112
#define RSSFU_ATTR_DVBT2_MODE_STREAM_ADAPT_OTHER_IN_BAND_PLP                RS_SPECIFIC_PUBLIC_ATTR_BASE + 476
#define RSSFU_ATTR_DVBT2_MODE_STREAM_ADAPT_CM_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 477
#define RSSFU_ATTR_DVBT2_BICM_FEC_FRAME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 478
#define RSSFU_ATTR_DVBT2_BICM_CODE_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 479
#define RSSFU_ATTR_DVBT2_BICM_CONSTELL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 480
#define RSSFU_ATTR_DVBT2_BICM_CONSTELL_ROTATION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 481
#define RSSFU_ATTR_DVBT2_BICM_TIME_INTERL_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 482
#define RSSFU_ATTR_DVBT2_BICM_FRAME_INT_I_JUMP                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 483
#define RSSFU_ATTR_DVBT2_BICM_TIME_INTERL_LENGTH                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 484
#define RSSFU_ATTR_DVBT2_BICM_FEC_BLOCKS_PER_IF                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 485
#define RSSFU_ATTR_DVBT2_BICM_FEC_MAX_BLOCKS_PER_IF                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 486
#define RSSFU_ATTR_DVBT2_FRAMING_CHANNEL_BANDWIDTH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 487
#define RSSFU_ATTR_DVBT2_FRAMING_USED_BANDWIDTH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 488
#define RSSFU_ATTR_DVBT2_FRAMING_BANDWIDTH_VARIATION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1113
#define RSSFU_ATTR_DVBT2_FRAMING_FFT_SIZE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 489
#define RSSFU_ATTR_DVBT2_FRAMING_GUARD_INTERVAL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 490
#define RSSFU_ATTR_DVBT2_FRAMING_PILOT_PATTERN                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 491
#define RSSFU_ATTR_DVBT2_FRAMING_T2_FRAMES_PER_SUPER_FRAME                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 492
#define RSSFU_ATTR_DVBT2_FRAMING_OFDM_SYMBOLS_PER_T2_FRAME                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 493
#define RSSFU_ATTR_DVBT2_FRAMING_DATA_SYMBOLS_PER_T2_FRAME                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 494
#define RSSFU_ATTR_DVBT2_FRAMING_SUBSLICES_PER_T2_FRAME                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 495
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_NETWORK_MODE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 496
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_PROFILE_MODE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1215
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_TRANSMISSION_SYSTEM                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 497
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_MISO_GROUP_MODE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1172
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_MISO_GROUP                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 498
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_PEAK_TO_AVRAGE_POWER_RATIO               RS_SPECIFIC_PUBLIC_ATTR_BASE + 499
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_FUTURE_EXTENSION_FRAMES                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 500
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_FUTURE_EXTENSION_FRAMES_LENGTH           RS_SPECIFIC_PUBLIC_ATTR_BASE + 501
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_FUTURE_EXTENSION_FRAMES_TYPE             RS_SPECIFIC_PUBLIC_ATTR_BASE + 502
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_FUTURE_EXTENSION_FRAMES_INTERVAL         RS_SPECIFIC_PUBLIC_ATTR_BASE + 503
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_FUTURE_EXTENSION_FRAMES_PAYLOAD          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1216
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_TIME_FREQUENCY_SLICING                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 504
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_L1_POST_MODULATION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 505
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_L1_REPETITION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 506
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_L1_POST_EXTENSION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 507
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_L1_POST_SCRAMBLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1217
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_T2_BASE_LITE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1218
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_NUM_AUX_STREAMS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 508
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_L1_RF_SIGNALLING                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 509
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_L1_SIGNALLING_FREQUENCY                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 510
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_CELL_ID                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 511
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_NETWORK_ID                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 512
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_ID                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 513
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_TX_ID_AVAILABILITY                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1219
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_TRANSMITTER_ID_STATE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 514
#define RSSFU_ATTR_DVBT2_T2_SYSTEM_L1_T2_VERSION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 515
#define RSSFU_ATTR_DVBT2_SFN_PROCESS_DELAY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1173
#define RSSFU_ATTR_DVBT2_SFN_STATIC_DELAY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1174
#define RSSFU_ATTR_DVBT2_SFN_DYNAMIC_DELAY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1175
#define RSSFU_ATTR_DVBT2_SFN_TOTAL_DELAY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1176
#define RSSFU_ATTR_DVBT2_SFN_MAX_DEVIATION_TIME                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1177
#define RSSFU_ATTR_DVBT2_SFN_MUTE_FIRST_P1_OF_SUPER_FRAME                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1178
#define RSSFU_ATTR_DVBT2_SFN_TIMESTAMP_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1220
#define RSSFU_ATTR_DVBT2_SFN_TIMESTAMP_MODE_UTC_DATE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1221
#define RSSFU_ATTR_DVBT2_SFN_UPDATE_TIMESTAMP                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1222
#define RSSFU_ATTR_DVBT2_SFN_TIMESTAMP_MODE_UTC_TIME                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1223
#define RSSFU_ATTR_DVBT2_SFN_TIMESTAMP_MODE_OFFSET                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1224
#define RSSFU_ATTR_DVBT2_SFN_TIMESTAMP_MODE_SECONDS_SINCE_2000              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1225
#define RSSFU_ATTR_DVBT2_SETTINGS_TEST_TS_PACKET                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 516
#define RSSFU_ATTR_DVBT2_SETTINGS_PID_TEST_PACKET                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 517
#define RSSFU_ATTR_DVBT2_SETTINGS_PID                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 518
#define RSSFU_ATTR_DVBT2_SETTINGS_PAYLOAD_TEST_TS_PACKET                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 519
#define RSSFU_ATTR_DVBT2_SETTINGS_PRBS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 520
#define RSSFU_ATTR_DVBC2_INPUT_SIGNAL_NUMBER_OF_PLP                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1114
#define RSSFU_ATTR_DVBC2_INPUT_SIGNAL_INPUT_FORMAT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1115
#define RSSFU_ATTR_DVBC2_INPUT_SIGNAL_SOURCE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1116
#define RSSFU_ATTR_DVBC2_INPUT_SIGNAL_INPUT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1117
#define RSSFU_ATTR_READ_DVBC2_INPUT_SIGNAL_MAX_DR                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1118
#define RSSFU_ATTR_READ_DVBC2_INPUT_SIGNAL_MEAS_DR                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1119
#define RSSFU_ATTR_READ_DVBC2_INPUT_SIGNAL_USEFUL_DR                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1120
#define RSSFU_ATTR_DVBC2_INPUT_SIGNAL_TEST_SIGNAL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1121
#define RSSFU_ATTR_DVBC2_MODE_STREAM_ADAPT_PLP_ID                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1122
#define RSSFU_ATTR_DVBC2_MODE_STREAM_ADAPT_PLP_TYPE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1123
#define RSSFU_ATTR_DVBC2_MODE_STREAM_ADAPT_BB_MODE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1124
#define RSSFU_ATTR_DVBC2_MODE_STREAM_ADAPT_ISSY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1125
#define RSSFU_ATTR_DVBC2_MODE_STREAM_ADAPT_NULL_PACKET_DEL                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1126
#define RSSFU_ATTR_DVBC2_MODE_STREAM_ADAPT_GROUP                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1259
#define RSSFU_ATTR_DVBC2_BICM_FEC_FRAME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1127
#define RSSFU_ATTR_DVBC2_BICM_CODE_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1128
#define RSSFU_ATTR_DVBC2_BICM_CONSTELL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1129
#define RSSFU_ATTR_DVBC2_BICM_XFEC_FRAME_LENGTH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1130
#define RSSFU_ATTR_DVBC2_BICM_MAP_TO_DSLICE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1131
#define RSSFU_ATTR_DVBC2_DATA_SLICE_MIN_MAX_REL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1132
#define RSSFU_ATTR_DVBC2_DATA_SLICE_MIN_MAX_ABS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1133
#define RSSFU_ATTR_DVBC2_DATA_SLICE_NUMBER_OF_DATA_SLICES                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1134
#define RSSFU_ATTR_DVBC2_DATA_SLICE_DSLICE_ID                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1135
#define RSSFU_ATTR_DVBC2_DATA_SLICE_DSLICE_TI_DEPTH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1136
#define RSSFU_ATTR_DVBC2_DATA_SLICE_DSLICE_TYPE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1137
#define RSSFU_ATTR_DVBC2_DATA_SLICE_FEC_HEADER_TYPE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1138
#define RSSFU_ATTR_DVBC2_DATA_SLICE_NUM_XFEC_FRAMES                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1139
#define RSSFU_ATTR_DVBC2_DATA_SLICE_DSLICE_NUM_PLP                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1140
#define RSSFU_ATTR_DVBC2_DATA_SLICE_OFFSET_LEFT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1141
#define RSSFU_ATTR_DVBC2_DATA_SLICE_TUNE_POS_REL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1142
#define RSSFU_ATTR_DVBC2_DATA_SLICE_OFFSET_RIGHT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1143
#define RSSFU_ATTR_DVBC2_DATA_SLICE_START_REL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1144
#define RSSFU_ATTR_DVBC2_DATA_SLICE_STOP_REL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1145
#define RSSFU_ATTR_DVBC2_DATA_SLICE_WIDTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1146
#define RSSFU_ATTR_DVBC2_DATA_SLICE_START_ABS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1147
#define RSSFU_ATTR_DVBC2_DATA_SLICE_TUNE_POS_ABS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1148
#define RSSFU_ATTR_DVBC2_DATA_SLICE_STOP_ABS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1149
#define RSSFU_ATTR_DVBC2_DATA_SLICE_TUNE_FREQ                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1229
#define RSSFU_ATTR_DVBC2_DATA_SLICE_START_FREQ                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1230
#define RSSFU_ATTR_DVBC2_DATA_SLICE_STOP_FREQ                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1231
#define RSSFU_ATTR_DVBC2_NOTCH_NUMBER_OF_NOTCHES                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1150
#define RSSFU_ATTR_DVBC2_NOTCH_START_REL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1232
#define RSSFU_ATTR_DVBC2_NOTCH_STOP_REL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1233
#define RSSFU_ATTR_DVBC2_NOTCH_START_ABS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1234
#define RSSFU_ATTR_DVBC2_NOTCH_STOP_ABS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1235
#define RSSFU_ATTR_DVBC2_NOTCH_START_FREQ                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1236
#define RSSFU_ATTR_DVBC2_NOTCH_STOP_FREQ                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1237
#define RSSFU_ATTR_DVBC2_NOTCH_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1238
#define RSSFU_ATTR_DVBC2_NOTCH_WIDTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1239
#define RSSFU_ATTR_DVBC2_FRAMING_CHANNEL_BANDWIDTH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1151
#define RSSFU_ATTR_DVBC2_FRAMING_C2_BANDWIDTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1240
#define RSSFU_ATTR_DVBC2_FRAMING_USED_BANDWIDTH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1153
#define RSSFU_ATTR_DVBC2_FRAMING_GUARD_INTERVAL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1154
#define RSSFU_ATTR_DVBC2_FRAMING_BASEBAND_FILTER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1226
#define RSSFU_ATTR_DVBC2_FRAMING_DX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1155
#define RSSFU_ATTR_DVBC2_FRAMING_START_FREQUENCY                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1156
#define RSSFU_ATTR_DVBC2_FRAMING_CALC_CENTER_FREQUENCY                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1227
#define RSSFU_ATTR_DVBC2_FRAMING_ADJUST_RF_FREQUENCY                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1228
#define RSSFU_ATTR_DVBC2_FRAMING_CARRIER_SPACING                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1157
#define RSSFU_ATTR_DVBC2_FRAMING_NUMBER_OF_DATA_SYMBOLS_PER_C2_FRAME        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1158
#define RSSFU_ATTR_DVBC2_FRAMING_NUMBER_OF_PREAMBLE_SYMBOLS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1159
#define RSSFU_ATTR_DVBC2_C2_SYSTEM_NETWORK_ID                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1160
#define RSSFU_ATTR_DVBC2_C2_SYSTEM_ID                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1161
#define RSSFU_ATTR_DVBC2_C2_SYSTEM_L1_TIME_INTERLEAVER                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1162
#define RSSFU_ATTR_DVBC2_C2_SYSTEM_RESERVED_TONES                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1163
#define RSSFU_ATTR_DVBC2_SETTINGS_TEST_TS_PACKET                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1164
#define RSSFU_ATTR_DVBC2_SETTINGS_PID_TEST_PACKET                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1165
#define RSSFU_ATTR_DVBC2_SETTINGS_PID                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1166
#define RSSFU_ATTR_DVBC2_SETTINGS_PAYLOAD_TEST_TS_PACKET                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1167
#define RSSFU_ATTR_DVBC2_SETTINGS_PRBS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1168
#define RSSFU_ATTR_ATSCMH_INPUT_SIGNAL_SOURCE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 521
#define RSSFU_ATTR_ATSCMH_INPUT_SIGNAL_INPUT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 522
#define RSSFU_ATTR_ATSCMH_INPUT_SIGNAL_STUFFING                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 523
#define RSSFU_ATTR_ATSCMH_INPUT_SIGNAL_TEST_SIGNAL                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 524
#define RSSFU_ATTR_READ_ATSCMH_PACKET_LENGTH                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 525
#define RSSFU_ATTR_READ_ATSCMH_MAX_USEFUL_DATA_RATE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 526
#define RSSFU_ATTR_READ_ATSCMH_MEASURED_DATA_RATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 527
#define RSSFU_ATTR_READ_ATSCMH_USEFUL_DATA_RATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 528
#define RSSFU_ATTR_ATSCMH_CODING_SYMBOL_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 529
#define RSSFU_ATTR_ATSCMH_CODING_CONSTELLATION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 530
#define RSSFU_ATTR_ATSCMH_CODING_ROLL_OFF                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 531
#define RSSFU_ATTR_ATSCMH_CODING_MH_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 532
#define RSSFU_ATTR_ATSCMH_SPECIAL_SETTINGS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 533
#define RSSFU_ATTR_ATSCMH_SPECIAL_RANDOMIZER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 534
#define RSSFU_ATTR_ATSCMH_SPECIAL_REED_SOLOMON                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 535
#define RSSFU_ATTR_ATSCMH_SPECIAL_INTERLEAVER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 536
#define RSSFU_ATTR_ATSCMH_SPECIAL_SFN_INITIALIZATION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 537
#define RSSFU_ATTR_ATSCMH_SPECIAL_TRELLIS_INITIALIZATION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 538
#define RSSFU_ATTR_ATSCMH_SPECIAL_PILOT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 539
#define RSSFU_ATTR_ATSCMH_SPECIAL_PILOT_VALUE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 540
#define RSSFU_ATTR_ATSCMH_SETTINGS_MHE_PID                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 541
#define RSSFU_ATTR_ATSCMH_SETTINGS_RF_WATERMARK                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 542
#define RSSFU_ATTR_ATSCMH_SETTINGS_TX_ADDRESS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 543
#define RSSFU_ATTR_ATSCMH_SETTINGS_NETWORK_ID                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 544
#define RSSFU_ATTR_ATSCMH_SETTINGS_BURY_RATIO                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 545
#define RSSFU_ATTR_ATSCMH_SETTINGS_MTXID_TRANSMISSION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 546
#define RSSFU_ATTR_ATSCMH_SETTINGS_TRANSMITTER_ID                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 547
#define RSSFU_ATTR_ATSCMH_SETTINGS_MARKET_ID                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 548
#define RSSFU_ATTR_ATSCMH_SETTINGS_TEST_TS_PACKET                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 549
#define RSSFU_ATTR_ATSCMH_SETTINGS_PID_TEST_PACKET                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 550
#define RSSFU_ATTR_ATSCMH_SETTINGS_PID                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 551
#define RSSFU_ATTR_ATSCMH_SETTINGS_PAYLOAD_TEST_STUFF                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 552
#define RSSFU_ATTR_ATSCMH_SETTINGS_PRBS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 553
#define RSSFU_ATTR_IQC_DVBS2_LOCK                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 554
#define RSSFU_ATTR_IQC_DVBS2_SOUR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 555
#define RSSFU_ATTR_IQC_DVBS2_INP                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 556
#define RSSFU_ATTR_IQC_DVBS2_STUF                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 557
#define RSSFU_ATTR_IQC_DVBS2_TEST                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 558
#define RSSFU_ATTR_IQC_DVBS2_ACM_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 559
#define RSSFU_ATTR_IQC_DVBS2_PACKET_LENGTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 560
#define RSSFU_ATTR_IQC_DVBS2_MAX_USEFUL_DATA_RATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 561
#define RSSFU_ATTR_IQC_DVBS2_MEASURED_DATA_RATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 562
#define RSSFU_ATTR_IQC_DVBS2_USEFUL_DATA_RATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 563
#define RSSFU_ATTR_IQC_DVBS2_REQ_DATA_RATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 564
#define RSSFU_ATTR_IQC_DVBS2_SYMB                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 565
#define RSSFU_ATTR_IQC_DVBS2_CONS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 566
#define RSSFU_ATTR_DVBS2_CODING_FECFRAME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 567
#define RSSFU_ATTR_IQC_DVBS2_PIL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 568
#define RSSFU_ATTR_IQC_DVBS2_ROLL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 569
#define RSSFU_ATTR_IQC_DVBS2_RATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 570
#define RSSFU_ATTR_IQC_DVBS2_AMC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 571
#define RSSFU_ATTR_IQC_DVBS2_SETT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 572
#define RSSFU_ATTR_IQC_DVBS2_SCR_SEQ                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 573
#define RSSFU_ATTR_IQC_DVBS2_CWM                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 574
#define RSSFU_ATTR_IQC_DVBS2_ERR_HEAD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 575
#define RSSFU_ATTR_IQC_DVBS2_ERR_PAYL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 576
#define RSSFU_ATTR_IQC_DVBS2_ERR_BCH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 577
#define RSSFU_ATTR_IQC_DVBS2_ERR_LDPC                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 578
#define RSSFU_ATTR_IQC_DVBS2_PHAS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 579
#define RSSFU_ATTR_IQC_DVBS2_PHAS_SHAP                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 580
#define RSSFU_ATTR_IQC_DVBS2_PHAS_MAGN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 581
#define RSSFU_ATTR_IQC_DVBS2_TSP                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 582
#define RSSFU_ATTR_IQC_DVBS2_PIDT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 583
#define RSSFU_ATTR_IQC_DVBS2_PID                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 584
#define RSSFU_ATTR_IQC_DVBS2_PAYL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 585
#define RSSFU_ATTR_IQC_DVBS2_PRBS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 586
#define RSSFU_ATTR_IQC_DIR_LOCK                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 587
#define RSSFU_ATTR_IQC_DIR_PAYL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 588
#define RSSFU_ATTR_IQC_DIR_PID                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 589
#define RSSFU_ATTR_IQC_DIR_PIDT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 590
#define RSSFU_ATTR_IQC_DIR_SOUR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 591
#define RSSFU_ATTR_IQC_DIR_INP                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 592
#define RSSFU_ATTR_IQC_DIR_STUF                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 593
#define RSSFU_ATTR_IQC_DIR_PACKET_LENGTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 594
#define RSSFU_ATTR_IQC_DIR_REQ_SOURCE_DATA_RATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 595
#define RSSFU_ATTR_IQC_DIR_MAX_USEFUL_DATA_RATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 596
#define RSSFU_ATTR_IQC_DIR_MEASURED_DATA_RATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 597
#define RSSFU_ATTR_IQC_DIR_USEFUL_DATA_RATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 598
#define RSSFU_ATTR_IQC_DIR_TEST                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 599
#define RSSFU_ATTR_IQC_DIR_SYMB                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 600
#define RSSFU_ATTR_IQC_DIR_CONS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 601
#define RSSFU_ATTR_IQC_DIR_ROLL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 602
#define RSSFU_ATTR_IQC_DIR_RATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 603
#define RSSFU_ATTR_IQC_DIR_SPEC_STAT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 604
#define RSSFU_ATTR_IQC_DIR_INSERT_ERR_CONV_ENC                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 605
#define RSSFU_ATTR_IQC_DIR_CW_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 606
#define RSSFU_ATTR_DIRECTV_CODING_PHASE_NOISE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 607
#define RSSFU_ATTR_DIRECTV_CODING_PHASE_NOISE_SHAPE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 608
#define RSSFU_ATTR_DIRECTV_CODING_PHASE_NOISE_MAGNITUDE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 609
#define RSSFU_ATTR_IQC_DIR_TSP                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 610
#define RSSFU_ATTR_IQC_DIR_PRBS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 611
#define RSSFU_ATTR_IQC_MFLO_LOCK                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 612
#define RSSFU_ATTR_IQC_MFLO_NETWORK_DELAY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 613
#define RSSFU_ATTR_IQC_MFLO_TRANSMITTER_DELAY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 614
#define RSSFU_ATTR_IQC_MFLO_SINUSOID_TEST                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 615
#define RSSFU_ATTR_IQC_MFLO_SINUSOID_TEST_FREQ                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 616
#define RSSFU_ATTR_IQC_MFLO_GAIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 617
#define RSSFU_ATTR_IQC_MFLO_LOCAL_AREA_CONTENT_PID                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 618
#define RSSFU_ATTR_IQC_MFLO_WIDE_AREA_CONTENT_PID                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 619
#define RSSFU_ATTR_IQC_MFLO_LOCAL_AREA_LENGTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 620
#define RSSFU_ATTR_IQC_MFLO_INFRASTRUCTURE_ID                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 621
#define RSSFU_ATTR_IQC_MFLO_LOCAL_TIME_OFFSET                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 622
#define RSSFU_ATTR_IQC_MFLO_DAYLIGHT_SAV_TIME_IND                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 623
#define RSSFU_ATTR_IQC_MFLO_SOURCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 624
#define RSSFU_ATTR_IQC_MFLO_INPUT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 625
#define RSSFU_ATTR_READ_MEDIAFLO_INPUT_SIGNAL_MEAS_DATA_RATE                RS_SPECIFIC_PUBLIC_ATTR_BASE + 626
#define RSSFU_ATTR_READ_MEDIAFLO_INPUT_SIGNAL_WIDE_CONTENT_DATA_RATE        RS_SPECIFIC_PUBLIC_ATTR_BASE + 627
#define RSSFU_ATTR_READ_MEDIAFLO_INPUT_SIGNAL_WIDE_CONTROL_CH_DATA_RATE     RS_SPECIFIC_PUBLIC_ATTR_BASE + 628
#define RSSFU_ATTR_READ_MEDIAFLO_INPUT_SIGNAL_WIDE_OIS_DATA_RATE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 629
#define RSSFU_ATTR_READ_MEDIAFLO_INPUT_SIGNAL_LOCAL_CONTENT_DATA_RATE       RS_SPECIFIC_PUBLIC_ATTR_BASE + 630
#define RSSFU_ATTR_READ_MEDIAFLO_INPUT_SIGNAL_LOCAL_CONTROL_CH_DATA_RATE    RS_SPECIFIC_PUBLIC_ATTR_BASE + 631
#define RSSFU_ATTR_READ_MEDIAFLO_INPUT_SIGNAL_LOCAL_OIS_DATA_RATE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 632
#define RSSFU_ATTR_READ_MEDIAFLO_STATUS_SSF_ARRIVAL_TIME                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 633
#define RSSFU_ATTR_READ_MEDIAFLO_STATUS_1PPS_TDM1_ERROR                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 634
#define RSSFU_ATTR_READ_MEDIAFLO_STATUS_OUT_OF_FRAME_COUNT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 635
#define RSSFU_ATTR_READ_MEDIAFLO_STATUS_SEQUENCE_ERROR_COUNT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 636
#define RSSFU_ATTR_READ_MEDIAFLO_STATUS_SCHEDULING_ERROR_COUNT              RS_SPECIFIC_PUBLIC_ATTR_BASE + 637
#define RSSFU_ATTR_MEDIAFLO_CODING_CHANNEL_BANDWIDTH                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 638
#define RSSFU_ATTR_MEDIAFLO_CODING_IFFT_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 639
#define RSSFU_ATTR_MEDIAFLO_CODING_SLOT_TO_INTERLACE_MAPPING                RS_SPECIFIC_PUBLIC_ATTR_BASE + 640
#define RSSFU_ATTR_MEDIAFLO_CODING_CYCLIC_PREFIX_LENGTH                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 641
#define RSSFU_ATTR_IQC_MFLO_WIDE_AREA_ID_VALUE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 642
#define RSSFU_ATTR_IQC_MFLO_LOCAL_AREA_ID_VALUE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 643
#define RSSFU_ATTR_MEDIAFLO_CODING_WIDE_MAC_SYMBOLS_FRAME                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 644
#define RSSFU_ATTR_MEDIAFLO_CODING_LOCAL_MAC_SYMBOLS_FRAME                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 645
#define RSSFU_ATTR_MEDIAFLO_CODING_NETWORK_GEOGRAPHY_DELAY                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 646
#define RSSFU_ATTR_IQC_MFLO_SPECIAL_SETTING                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 647
#define RSSFU_ATTR_IQC_MFLO_TDM1_NULL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 648
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_WIDE_PID_CONTENT                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 649
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_WIDE_PID_CONTROL_CHANNEL               RS_SPECIFIC_PUBLIC_ATTR_BASE + 650
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_WIDE_PID_OIS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 651
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_LOCAL_PID_CONTENT                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 652
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_LOCAL_PID_CONTROL_CHANNEL              RS_SPECIFIC_PUBLIC_ATTR_BASE + 653
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_LOCAL_PID_OIS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 654
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_LOCAL_OIS_INSERTION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 655
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_INFRASTRUCTURE_ID                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 656
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_LOCAL_TIME_OFFSET                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 657
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_DAYLIGHT_SAVINGS_TIME_INDICATOR        RS_SPECIFIC_PUBLIC_ATTR_BASE + 658
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_POSITION_PILOT_SYMBOLS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 659
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_TRANSMITTER_ID                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 660
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_NUMBER_OF_TRANSMITTERS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 661
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_TX_POSITION_ENABLE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 662
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_TX_POSITION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 663
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_TX_OFFSET_ENABLE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 664
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_TX_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 665
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_TX_LATITUDE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 666
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_TX_LONGITUDE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 667
#define RSSFU_ATTR_MEDIAFLO_SETTINGS_TX_ALTITUDE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 668
#define RSSFU_ATTR_IQC_TDMB_LOCK                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 669
#define RSSFU_ATTR_TDMB_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 670
#define RSSFU_ATTR_TDMB_ETI_INPUT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 671
#define RSSFU_ATTR_TDMB_NUMBER_OF_STREAMS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 672
#define RSSFU_ATTR_TDMB_MODE_IDENTITY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 673
#define RSSFU_ATTR_TDMB_SCID                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 674
#define RSSFU_ATTR_TDMB_PROT_PROFILE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 675
#define RSSFU_ATTR_TDMB_PROT_LEVEL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 676
#define RSSFU_ATTR_TDMB_DATA_RATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 677
#define RSSFU_ATTR_TDMB_SPECIAL_SETTINGS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 678
#define RSSFU_ATTR_TDMB_TRANSMISSION_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 679
#define RSSFU_ATTR_TDMB_SELECT_TRANSMISSION_MODE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 680
#define RSSFU_ATTR_TDMB_PRBS_TESTSIGNAL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 681
#define RSSFU_ATTR_TDMB_TESTSIGNAL_SCID                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 682
#define RSSFU_ATTR_TDMB_TII                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 683
#define RSSFU_ATTR_TDMB_TII_MAIN_SUB_ID                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 684
#define RSSFU_ATTR_TDMB_NETWORK                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 685
#define RSSFU_ATTR_TDMB_PRBS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 686
#define RSSFU_ATTR_TDMB_TII_MAIN_ID                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 687
#define RSSFU_ATTR_TDMB_TII_SUB_ID                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 688
#define RSSFU_ATTR_ATV_FREQ_SOUND_MONO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 689
#define RSSFU_ATTR_ATV_LEVEL_SOUND_MONO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 690
#define RSSFU_ATTR_ATV_FREQ_SOUND_LEFT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 691
#define RSSFU_ATTR_ATV_FREQ_SOUND_RIGHT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 692
#define RSSFU_ATTR_ATV_LEVEL_SOUND_LEFT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 693
#define RSSFU_ATTR_ATV_LEVEL_SOUND_RIGHT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 694
#define RSSFU_ATTR_ATV_FREQ_SOUND_CH1                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 695
#define RSSFU_ATTR_ATV_FREQ_SOUND_CH2                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 696
#define RSSFU_ATTR_ATV_LEVEL_SOUND_CH1                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 697
#define RSSFU_ATTR_ATV_LEVEL_SOUND_CH2                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 698
#define RSSFU_ATTR_ATV_AUDIO_AF_1                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 699
#define RSSFU_ATTR_ATV_AUDIO_AF_2                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 700
#define RSSFU_ATTR_ATV_AUDIO_INPUT_SIGNAL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 701
#define RSSFU_ATTR_ATV_AUDIO_IMPEDANCE_SIGNAL_SOURCE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 702
#define RSSFU_ATTR_ATV_SOUND_MODUL_AUEX_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 703
#define RSSFU_ATTR_ANALOG_TV_AUDIO_LOAD_AUDIO_PLAYER_FILE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 704
#define RSSFU_ATTR_ATV_VIDEO_INPUT_SIGNAL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 705
#define RSSFU_ATTR_ATV_VISION_PICTURE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 706
#define RSSFU_ATTR_ATV_LOAD_VIDEO_LIB                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 707
#define RSSFU_ATTR_ATV_SOUND_MODUL_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 708
#define RSSFU_ATTR_ATV_SOUND_MODUL_FREQ_DEV_SUBCAR1                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 709
#define RSSFU_ATTR_ATV_SOUND_MODUL_FREQ_DEV_SUBCAR2                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 710
#define RSSFU_ATTR_ATV_SOUND_MODUL_FREQ_DEV_PILOT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 711
#define RSSFU_ATTR_ATV_SOUND_MODUL_FREQ_DEV_MONO                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 712
#define RSSFU_ATTR_ATV_SOUND_MODUL_NICAM_SIGNAL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 713
#define RSSFU_ATTR_ATV_SPECIAL_SETTINGS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 714
#define RSSFU_ATTR_ATV_SPECIAL_PREEMPHASIS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 715
#define RSSFU_ATTR_ATV_SPECIAL_PILOT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 716
#define RSSFU_ATTR_ATV_SPECIAL_NOM_FREQ_DEV_PILOT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 717
#define RSSFU_ATTR_ATV_SPECIAL_NOM_FREQ_DEV_MONO                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 718
#define RSSFU_ATTR_ATV_SPECIAL_NOM_FREQ_DEV_SUBCAR_1                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 719
#define RSSFU_ATTR_ATV_SPECIAL_NOM_FREQ_DEV_SUBCAR_2                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 720
#define RSSFU_ATTR_ATV_SPECIAL_SUBCARRIER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 721
#define RSSFU_ATTR_ATV_SPECIAL_SUBCARRIER_1                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 722
#define RSSFU_ATTR_ATV_SPECIAL_SUBCARRIER_2                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 723
#define RSSFU_ATTR_ATV_SPECIAL_FREQ_SUBCARRIER                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 724
#define RSSFU_ATTR_ATV_SPECIAL_FREQ_SUBCARRIER_1                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 725
#define RSSFU_ATTR_ATV_SPECIAL_FREQ_SUBCARRIER_2                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 726
#define RSSFU_ATTR_ATV_SPECIAL_LEVEL_SUBCARRIER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 727
#define RSSFU_ATTR_ATV_SPECIAL_LEVEL_SUBCARRIER_1                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 728
#define RSSFU_ATTR_ATV_SPECIAL_LEVEL_SUBCARRIER_2                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 729
#define RSSFU_ATTR_ATV_SPECIAL_VSB_FILTER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 730
#define RSSFU_ATTR_ATV_SPECIAL_VSB_CHARACTERISTIC                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 731
#define RSSFU_ATTR_ATV_SPECIAL_GD_PRECORRECTION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 732
#define RSSFU_ATTR_ATV_SPECIAL_RESIDUAL_CARRIER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 733
#define RSSFU_ATTR_ATV_SPECIAL_CARRIER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 734
#define RSSFU_ATTR_ATV_SPECIAL_VIDEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 735
#define RSSFU_ATTR_ATV_SPECIAL_AM_MODULATION_DEPTH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 736
#define RSSFU_ATTR_MODULATOR_IMPAIRMENTS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 737
#define RSSFU_ATTR_MODULATOR_I_OFFSET                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 738
#define RSSFU_ATTR_MODULATOR_Q_OFFSET                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 739
#define RSSFU_ATTR_MODULATOR_QUADRATURE_ERROR                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 740
#define RSSFU_ATTR_MODULATOR_AMPLITUDE_IMBALANCE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 741
#define RSSFU_ATTR_MOD_GAIN                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 742
#define RSSFU_ATTR_BB_IMPAIRMENTS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 743
#define RSSFU_ATTR_BB_I_OFFSET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 744
#define RSSFU_ATTR_BB_Q_OFFSET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 745
#define RSSFU_ATTR_BB_QUADRATURE_ERROR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 746
#define RSSFU_ATTR_BB_AMPLITUDE_IMBALANCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 747
#define RSSFU_ATTR_BB_OPTIMIZE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 748
#define RSSFU_ATTR_BB_OPTIMIZATION_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 749
#define RSSFU_ATTR_AUDIO_BC_SOURCE_LEFT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 750
#define RSSFU_ATTR_AUDIO_BC_SOURCE_RIGHT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 751
#define RSSFU_ATTR_AUDIO_BC_INPUT_SOURCE_BTC                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1260
#define RSSFU_ATTR_AUDIO_BC_AF_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 752
#define RSSFU_ATTR_AUDIO_BC_IMPEDANCE_SIGNAL_SOURCE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 753
#define RSSFU_ATTR_AUDIO_BC_SOURCE_FREQUENCY_LEFT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 754
#define RSSFU_ATTR_AUDIO_BC_SOURCE_FREQUENCY_RIGHT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 755
#define RSSFU_ATTR_AUDIO_BC_SOURCE_LEVEL_LEFT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 756
#define RSSFU_ATTR_AUDIO_BC_SOURCE_LEVEL_RIGHT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 757
#define RSSFU_ATTR_AUDIO_BC_SOURCE_INPUT_LEVEL_RIGHT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 758
#define RSSFU_ATTR_AUDIO_BC_SOURCE_INPUT_LEVEL_LEFT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 759
#define RSSFU_ATTR_AUDIO_BC_RDS_GROUP_SEQUENCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 760
#define RSSFU_ATTR_AUDIO_BC_RDS_PI                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 761
#define RSSFU_ATTR_AUDIO_BC_RDS_PS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 762
#define RSSFU_ATTR_AUDIO_BC_RDS_TP                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 763
#define RSSFU_ATTR_AUDIO_BC_RDS_TA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 764
#define RSSFU_ATTR_AUDIO_BC_RDS_PTY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 765
#define RSSFU_ATTR_AUDIO_BC_RDS_PTYN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 766
#define RSSFU_ATTR_AUDIO_BC_RDS_RT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 767
#define RSSFU_ATTR_AUDIO_BC_RDS_RT_READY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 768
#define RSSFU_ATTR_AUDIO_BC_RDS_MS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 769
#define RSSFU_ATTR_AUDIO_BC_RDS_DI_DYNAMIC_PTY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 770
#define RSSFU_ATTR_AUDIO_BC_RDS_DI_COMPRESSED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 771
#define RSSFU_ATTR_AUDIO_BC_RDS_DI_ART_HEAD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 772
#define RSSFU_ATTR_AUDIO_BC_RDS_DI_STEREO                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 773
#define RSSFU_ATTR_AUDIO_BC_RDS_DI_CT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 774
#define RSSFU_ATTR_AUDIO_BC_RDS_DI_CT_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 775
#define RSSFU_ATTR_AUDIO_BC_RDS_DI_AF_METHOD                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 776
#define RSSFU_ATTR_AUDIO_BC_AF_A_NUMBER_OF_FREQ                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 777
#define RSSFU_ATTR_AUDIO_BC_AF_A_FREQUENCY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 778
#define RSSFU_ATTR_AUDIO_BC_AF_B_NUMBER_OF_LISTS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 779
#define RSSFU_ATTR_AUDIO_BC_AF_B_NUMBER_OF_FREQ                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 780
#define RSSFU_ATTR_AUDIO_BC_AF_B_TUNING_FREQ                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 781
#define RSSFU_ATTR_AUDIO_BC_AF_B_AF_FREQUENCY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 782
#define RSSFU_ATTR_AUDIO_BC_AF_B_AF_ORDER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 783
#define RSSFU_ATTR_AUDIO_BC_EON_PI                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 784
#define RSSFU_ATTR_AUDIO_BC_EON_PS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 785
#define RSSFU_ATTR_AUDIO_BC_EON_TP                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 786
#define RSSFU_ATTR_AUDIO_BC_EON_TA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 787
#define RSSFU_ATTR_AUDIO_BC_EON_LA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 788
#define RSSFU_ATTR_AUDIO_BC_EON_EG                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 789
#define RSSFU_ATTR_AUDIO_BC_EON_ILS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 790
#define RSSFU_ATTR_AUDIO_BC_EON_LSN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 791
#define RSSFU_ATTR_AUDIO_BC_EON_PTY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 792
#define RSSFU_ATTR_AUDIO_BC_EON_PIN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 793
#define RSSFU_ATTR_AUDIO_BC_EON_AF_METHOD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 794
#define RSSFU_ATTR_AUDIO_BC_EON_AF_A_NUMBER_OF_FREQ                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 795
#define RSSFU_ATTR_AUDIO_BC_EON_AF_A_FREQUENCY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 796
#define RSSFU_ATTR_AUDIO_BC_EON_AF_MAPPED_FREQ_NUMBER_OF_FREQ               RS_SPECIFIC_PUBLIC_ATTR_BASE + 797
#define RSSFU_ATTR_AUDIO_BC_EON_AF_MAPPED_FREQ_TUNING_FREQ                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 798
#define RSSFU_ATTR_AUDIO_BC_EON_AF_MAPPED_FREQ_AF_FREQUENCY                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 799
#define RSSFU_ATTR_AUDIO_BC_TMC_TMC                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 800
#define RSSFU_ATTR_AUDIO_BC_TMC_GROUP_3A_VAR_00                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 801
#define RSSFU_ATTR_AUDIO_BC_TMC_GROUP_3A_VAR_01                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 802
#define RSSFU_ATTR_AUDIO_BC_TMC_NUMBER_OF_8A_GROUPS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 803
#define RSSFU_ATTR_AUDIO_BC_TMC_8A_BLOCK                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 804
#define RSSFU_ATTR_AUDIO_BC_TMC_APPLY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 805
#define RSSFU_ATTR_AUDIO_BC_OPEN_FORMAT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 806
#define RSSFU_ATTR_AUDIO_BC_OPEN_FORMAT_APPLY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 807
#define RSSFU_ATTR_AUDIO_BC_OPEN_FORMAT_GROUP_A                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 808
#define RSSFU_ATTR_AUDIO_BC_OPEN_FORMAT_GROUP_B                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 809
#define RSSFU_ATTR_AUDIO_BC_OPEN_FORMAT_GROUP_A_READY                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 810
#define RSSFU_ATTR_AUDIO_BC_OPEN_FORMAT_GROUP_B_READY                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 811
#define RSSFU_ATTR_AUDIO_BC_MODULATION_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 812
#define RSSFU_ATTR_AUDIO_BC_MODULATION_PREEMPHASIS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 813
#define RSSFU_ATTR_AUDIO_BC_MODULATION_RDS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 814
#define RSSFU_ATTR_AUDIO_BC_MODULATION_NOM_FREQ_DEV_AUDIO                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 815
#define RSSFU_ATTR_AUDIO_BC_MODULATION_FREQ_DEV_AUDIO                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 816
#define RSSFU_ATTR_AUDIO_BC_MODULATION_FREQ_DEV_RDS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 817
#define RSSFU_ATTR_AUDIO_BC_MODULATION_FREQ_DEV_PILOT_19KHZ                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 818
#define RSSFU_ATTR_AUDIO_BC_MODULATION_NOM_FREQ_DEV_MPX                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 819
#define RSSFU_ATTR_AUDIO_BC_MODULATION_FREQ_DEV_MPX                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 820
#define RSSFU_ATTR_AUDIO_BC_FM_SPECIAL_SETTINGS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 821
#define RSSFU_ATTR_AUDIO_BC_SPECIAL_PILOT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 822
#define RSSFU_ATTR_AUDIO_BC_SPECIAL_PHASE_OFFSET_PILOT_19KHZ                RS_SPECIFIC_PUBLIC_ATTR_BASE + 823
#define RSSFU_ATTR_AUDIO_BC_SPECIAL_PHASE_OFFSET_RDS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 824
#define RSSFU_ATTR_AUDIO_BC_AM_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 825
#define RSSFU_ATTR_AUDIO_BC_AM_SOURCE_BTC                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1274
#define RSSFU_ATTR_AUDIO_BC_AM_INTERNAL_FREQUENCY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 826
#define RSSFU_ATTR_AUDIO_BC_AM_INTERNAL_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 827
#define RSSFU_ATTR_AUDIO_BC_AM_IMPEDNACE_SIGNAL_SOURCE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 828
#define RSSFU_ATTR_AUDIO_BC_AM_INPUT_LEVEL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 829
#define RSSFU_ATTR_AUDIO_BC_AM_NOM_MOD_DEPTH                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 830
#define RSSFU_ATTR_AUDIO_BC_AM_MOD_DEPTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 831
#define RSSFU_ATTR_NOISE_STORE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 832
#define RSSFU_ATTR_NOISE_SELECT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 833
#define RSSFU_ATTR_NOISE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 834
#define RSSFU_ATTR_AWGN                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 835
#define RSSFU_ATTR_PHASE_NOISE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 837
#define RSSFU_ATTR_NOISE_CN                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 838
#define RSSFU_ATTR_NOISE_EB_N0_RATIO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 839
#define RSSFU_ATTR_NOISE_IMPULSIVE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 840
#define RSSFU_ATTR_NOISE_CI                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 841
#define RSSFU_ATTR_NOISE_FRAME_DURATION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 842
#define RSSFU_ATTR_NOISE_FRAME_DURATION_BTC                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1265
#define RSSFU_ATTR_NOISE_PULSES_PER_BURST                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 843
#define RSSFU_ATTR_NOISE_PULSE_SPACING_MIN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 844
#define RSSFU_ATTR_NOISE_PULSE_SPACING_MAX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 845
#define RSSFU_ATTR_NOISE_SSB_SHAPE_PROFILE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 846
#define RSSFU_ATTR_PHASE_NOISE_LEVEL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 847
#define RSSFU_ATTR_NOISE_BANDWIDTH_COUPLING                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 848
#define RSSFU_ATTR_NOISE_RECEIVER_BANDWIDTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 849
#define RSSFU_ATTR_GEN_NOISE_BANDWIDTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 850
#define RSSFU_ATTR_FADING_SPEED_COUPLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 851
#define RSSFU_ATTR_FADING_DOPPLER_SHIFT_COUPLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 852
#define RSSFU_ATTR_FADING_DELETE_FILE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 853
#define RSSFU_ATTR_FADING_STORE_FILE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 854
#define RSSFU_ATTR_FADING_LOAD_FILE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 856
#define RSSFU_ATTR_FADING_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 857
#define RSSFU_ATTR_FADING_STANDARD_DEVIATION_COUPLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 858
#define RSSFU_ATTR_FADING_SPEED_UNIT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 859
#define RSSFU_ATTR_FADING_COMMON_SPEED_ALL_PATH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 860
#define RSSFU_ATTR_FADING_LOCAL_CONSTANT_COUPLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 861
#define RSSFU_ATTR_FADING_IGNORE_RF_CHANGES                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 862
#define RSSFU_ATTR_FADING_DEFAULT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 864
#define RSSFU_ATTR_FADING_SIGNAL_DEDICATED_TO                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 865
#define RSSFU_ATTR_FADING_VIRTUAL_RF                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 866
#define RSSFU_ATTR_FADING_INSERT_LOSS_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 867
#define RSSFU_ATTR_FADING_INSERT_LOSS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 868
#define RSSFU_ATTR_FADING_CLIPPED_SAMPLE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 869
#define RSSFU_ATTR_FADING_RESTART_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 870
#define RSSFU_ATTR_FADING_REFERENCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 871
#define RSSFU_ATTR_FADING_REFERENCE_BTC                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1275
#define RSSFU_ATTR_FADING_COMMON_DOPPLER_SHIFT_ALL_PATH                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 872
#define RSSFU_ATTR_FADING_MAX_PATHS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 873
#define RSSFU_ATTR_FADING_SIGNAL_DELAY_SHIFT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 874
#define RSSFU_ATTR_FADING_STATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 875
#define RSSFU_ATTR_FADING_RESTART                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 876
#define RSSFU_ATTR_FADING_PARAMETER_SET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 877
#define RSSFU_ATTR_FADING_PAR_DEL_STATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 878
#define RSSFU_ATTR_FADING_PAR_DEL_PROFILE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 879
#define RSSFU_ATTR_FADING_PAR_DEL_PATH_LOSS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 880
#define RSSFU_ATTR_FADING_PAR_DEL_BASIC_DELAY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 881
#define RSSFU_ATTR_FADING_PAR_DEL_ADDITIONAL_DELAY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 882
#define RSSFU_ATTR_FADING_PAR_DEL_RESULTING_DELAY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 883
#define RSSFU_ATTR_FADING_PAR_DEL_POWER_RATIO                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 884
#define RSSFU_ATTR_FADING_PAR_DEL_CONST_PHASE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 885
#define RSSFU_ATTR_FADING_PAR_DEL_SPEED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 886
#define RSSFU_ATTR_FADING_PAR_DEL_FREQ_RATIO                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 887
#define RSSFU_ATTR_FADING_PAR_DEL_RESULT_DOPPLER_SHIFT                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 888
#define RSSFU_ATTR_FADING_PAR_DEL_CORRELATION_PATH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 889
#define RSSFU_ATTR_FADING_PAR_DEL_COEFFICIENT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 890
#define RSSFU_ATTR_FADING_PAR_DEL_PHASE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 891
#define RSSFU_ATTR_FADING_PAR_DEL_LOGNORMAL_STATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 892
#define RSSFU_ATTR_FADING_PAR_DEL_LOCAL_CONSTANT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 893
#define RSSFU_ATTR_FADING_PAR_DEL_STANDARD_DEVIATION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 894
#define RSSFU_ATTR_FADING_PAR_DEL_STATE_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 895
#define RSSFU_ATTR_FADING_PAR_DEL30_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 896
#define RSSFU_ATTR_FADING_PAR_DEL30_PROFILE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 897
#define RSSFU_ATTR_FADING_PAR_DEL30_PATH_LOSS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 898
#define RSSFU_ATTR_FADING_PAR_DEL30_BASIC_DELAY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 899
#define RSSFU_ATTR_FADING_PAR_DEL30_ADDITIONAL_DELAY                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 900
#define RSSFU_ATTR_FADING_PAR_DEL30_RESULTING_DELAY                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 901
#define RSSFU_ATTR_FADING_PAR_DEL30_POWER_RATIO                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 902
#define RSSFU_ATTR_FADING_PAR_DEL30_CONST_PHASE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 903
#define RSSFU_ATTR_FADING_PAR_DEL30_SPEED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 904
#define RSSFU_ATTR_FADING_PAR_DEL30_FREQ_RATIO                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 905
#define RSSFU_ATTR_FADING_PAR_DEL30_RESULT_DOPPLER_SHIFT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 906
#define RSSFU_ATTR_FADING_PAR_DEL30_CORRELATION_PATH                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 907
#define RSSFU_ATTR_FADING_PAR_DEL30_COEFFICIENT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 908
#define RSSFU_ATTR_FADING_PAR_DEL30_PHASE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 909
#define RSSFU_ATTR_FADING_PAR_DEL30_LOGNORMAL_STATE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 910
#define RSSFU_ATTR_FADING_PAR_DEL30_LOCAL_CONSTANT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 911
#define RSSFU_ATTR_FADING_PAR_DEL30_STANDARD_DEVIATION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 912
#define RSSFU_ATTR_FADING_PAR_DEL30_STATE_MODE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 913
#define RSSFU_ATTR_FADING_PAR_DEL50_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 914
#define RSSFU_ATTR_FADING_PAR_DEL50_PROFILE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 915
#define RSSFU_ATTR_FADING_PAR_DEL50_PATH_LOSS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 916
#define RSSFU_ATTR_FADING_PAR_DEL50_BASIC_DELAY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 917
#define RSSFU_ATTR_FADING_PAR_DEL50_ADDITIONAL_DELAY                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 918
#define RSSFU_ATTR_FADING_PAR_DEL50_RESULTING_DELAY                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 919
#define RSSFU_ATTR_FADING_PAR_DEL50_POWER_RATIO                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 920
#define RSSFU_ATTR_FADING_PAR_DEL50_CONST_PHASE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 921
#define RSSFU_ATTR_FADING_PAR_DEL50_SPEED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 922
#define RSSFU_ATTR_FADING_PAR_DEL50_FREQ_RATIO                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 923
#define RSSFU_ATTR_FADING_PAR_DEL50_RESULT_DOPPLER_SHIFT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 924
#define RSSFU_ATTR_FADING_PAR_DEL50_CORRELATION_PATH                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 925
#define RSSFU_ATTR_FADING_PAR_DEL50_COEFFICIENT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 926
#define RSSFU_ATTR_FADING_PAR_DEL50_PHASE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 927
#define RSSFU_ATTR_FADING_PAR_DEL50_LOGNORMAL_STATE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 928
#define RSSFU_ATTR_FADING_PAR_DEL50_LOCAL_CONSTANT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 929
#define RSSFU_ATTR_FADING_PAR_DEL50_STANDARD_DEVIATION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 930
#define RSSFU_ATTR_FADING_PAR_DEL50_STATE_MODE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 931
#define RSSFU_ATTR_FADING_PAR_STATE_MODE_BIRTH_DEATH                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 932
#define RSSFU_ATTR_FADING_PAR_PROFILE_BIRTH_DEATH                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 933
#define RSSFU_ATTR_FADING_PAR_PATH_LOSS_BIRTH_DEATH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 934
#define RSSFU_ATTR_FADING_PAR_MIN_DELAY_BIRTH_DEATH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 935
#define RSSFU_ATTR_FADING_PAR_DELAY_GRID_BIRTH_DEATH                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 936
#define RSSFU_ATTR_FADING_PAR_POSITIONS_BIRTH_DEATH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 937
#define RSSFU_ATTR_FADING_PAR_MAX_DELAY_BIRTH_DEATH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 938
#define RSSFU_ATTR_FADING_PAR_START_OFFSET_BIRTH_DEATH                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 939
#define RSSFU_ATTR_FADING_PAR_HOPPING_DWELL_BIRTH_DEATH                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 940
#define RSSFU_ATTR_FADING_PAR_SPEED_BIRTH_DEATH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 941
#define RSSFU_ATTR_FADING_PAR_FREQ_RATIO_BIRTH_DEATH                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 942
#define RSSFU_ATTR_FADING_PAR_RES_DOPPLER_SHIFT_BIRTH_DEATH                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 943
#define RSSFU_ATTR_FADING_PAR_REF_PATH_STATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 944
#define RSSFU_ATTR_FADING_PAR_REF_PATH_LOSS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 945
#define RSSFU_ATTR_FADING_PAR_REF_PATH_DELAY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 946
#define RSSFU_ATTR_FADING_PAR_MOVING_PATH_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 947
#define RSSFU_ATTR_FADING_PAR_MOVING_PATH_LOSS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 948
#define RSSFU_ATTR_FADING_PAR_MOVING_PATH_DELAY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 949
#define RSSFU_ATTR_FADING_PAR_MOVING_PATH_VARIATION_PK                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 950
#define RSSFU_ATTR_FADING_PAR_MOVING_PATH_VARIATION_PERIOD                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 951
#define RSSFU_ATTR_FADING_PAR_MOVING_PATH_STATE_MODE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 952
#define RSSFU_ATTR_FADING_2PATH_DYNAMIC_DELAY_STATE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 953
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_REF_PATH_STATE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 954
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_REF_PATH_PROFILE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 955
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_REF_PATH_LOSS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 956
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_SPEED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 957
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_REF_PATH_FREQ_RATIO                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 958
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_REF_PATH_DOPLER_SHIFT               RS_SPECIFIC_PUBLIC_ATTR_BASE + 959
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_REF_PATH_MIN_DELAY                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 960
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_MOVING_PATH_STATE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 961
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_MOVING_PATH_PROFILE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 962
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_MOVING_PATH_LOSS                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 963
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_MOVING_PATH_FREQ_RATIO              RS_SPECIFIC_PUBLIC_ATTR_BASE + 964
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_MOVING_PATH_DOPLER_SHIFT            RS_SPECIFIC_PUBLIC_ATTR_BASE + 965
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_MOVING_PATH_MIN_DELAY               RS_SPECIFIC_PUBLIC_ATTR_BASE + 966
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_MOVING_PATH_MAX_DELAY               RS_SPECIFIC_PUBLIC_ATTR_BASE + 967
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_MOVING_MODE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 968
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_MOVING_PERIOD                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 969
#define RSSFU_ATTR_FADING_2PATH_DYN_DEL_MOVING_DWELL                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 970
#define RSSFU_ATTR_FADING_CONFIGURATION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 971
#define RSSFU_ATTR_BER_MEAS_STAT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 972
#define RSSFU_ATTR_BER_RESTART                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 973
#define RSSFU_ATTR_BER_SEL_MEAS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 974
#define RSSFU_ATTR_BER_SEL_MEAS_BTC                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1261
#define RSSFU_ATTR_BER_SIGNAL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 975
#define RSSFU_ATTR_BER_PARALLEL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 976
#define RSSFU_ATTR_BER_GATING_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 977
#define RSSFU_ATTR_BER_INP_CLK                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 978
#define RSSFU_ATTR_BER_DATA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 979
#define RSSFU_ATTR_BER_FUNC_INP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 980
#define RSSFU_ATTR_BER_USER_GATING_TIME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 981
#define RSSFU_ATTR_BER_PRBS_SEQ                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 982
#define RSSFU_ATTR_BER_BIT_PATT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 983
#define RSSFU_ATTR_BER_READ_RESULT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 984
#define RSSFU_ATTR_BER_READ_EVAL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 985
#define RSSFU_ATTR_BER_STATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 986
#define RSSFU_ATTR_BER_ERROR_COUNT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 987
#define RSSFU_ATTR_BER_GATING_TIME                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 988
#define RSSFU_ATTR_BER_READ_ALL_RESULTS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 989
#define RSSFU_ATTR_BER_GATING_RATIO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 990
#define RSSFU_ATTR_ARB                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 991
#define RSSFU_ATTR_ARB_LOAD_WAVEFORM                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 992
#define RSSFU_ATTR_ARB_WAVEFORM_DELETE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 993
#define RSSFU_ATTR_ARB_MEMORY_SIZE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 994
#define RSSFU_ATTR_ARB_MAXIMUM_SAMPLES                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 995
#define RSSFU_ATTR_ARB_CLOCK_FREQUENCY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 996
#define RSSFU_ATTR_ARB_CLOCK_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 997
#define RSSFU_ATTR_ARB_EXT_CLOCK_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 998
#define RSSFU_ATTR_ARB_EXT_SAMPLE_CLOCK_MULTIPLIER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 999
#define RSSFU_ATTR_ARB_EXT_MEASURED_EXTERNAL_CLOCK                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1000
#define RSSFU_ATTR_ARB_TRIGGER_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1001
#define RSSFU_ATTR_ARB_TRIGGER_STATUS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1002
#define RSSFU_ATTR_ARB_TRIGGER_ARM                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1003
#define RSSFU_ATTR_ARB_TRIGGER_EXECUTE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1004
#define RSSFU_ATTR_ARB_TRIGGER_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1005
#define RSSFU_ATTR_ARB_TRIGGER_DELAY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1006
#define RSSFU_ATTR_ARB_TRIGGER_INHIBIT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1007
#define RSSFU_ATTR_ARB_MARKER1                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1008
#define RSSFU_ATTR_ARB_MARKER_DELAY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1009
#define RSSFU_ATTR_ARB_TST_SIG_FREQUENCY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1010
#define RSSFU_ATTR_ARB_TST_SIG_SAMPLES_PER_PERIOD                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1011
#define RSSFU_ATTR_ARB_TST_SIG_PHASE_OFFSET_Q                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1012
#define RSSFU_ATTR_ARB_TST_SIG_GENERATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1013
#define RSSFU_ATTR_TSGEN_PREPARE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1014
#define RSSFU_ATTR_TSGEN_COMMAND                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1015
#define RSSFU_ATTR_TSGEN_COMMAND_BTC                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1262
#define RSSFU_ATTR_TSGEN_COMMAND_STATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1016
#define RSSFU_ATTR_TSGEN_SEEK_POSITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1017
#define RSSFU_ATTR_TSGEN_PLAYER_PLAYFILE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1018
#define RSSFU_ATTR_TSGEN_FILE_DATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1019
#define RSSFU_ATTR_TSGEN_ORIGINAL_TS_DATA_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1020
#define RSSFU_ATTR_TSGEN_PLAYER_BYTERATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1021
#define RSSFU_ATTR_TSGEN_TS_DATA_RATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1022
#define RSSFU_ATTR_TSGEN_PLAY_WINDOW_START                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1023
#define RSSFU_ATTR_TSGEN_PLAY_WINDOW_STOP                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1024
#define RSSFU_ATTR_TSGEN_PCR_JITTER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1025
#define RSSFU_ATTR_TSGEN_WAVEFORM                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1026
#define RSSFU_ATTR_TSGEN_AMPLITUDE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1027
#define RSSFU_ATTR_TSGEN_FREQUENCY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1028
#define RSSFU_ATTR_TSGEN_PACKET_LENGTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1029
#define RSSFU_ATTR_TSGEN_TS_SERIAL_OUTPUT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1030
#define RSSFU_ATTR_TSGEN_ORIGINAL_LOOP_TIME                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1031
#define RSSFU_ATTR_TSGEN_PLAYER_NULLPACKET_STUFFING                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1032
#define RSSFU_ATTR_TSGEN_SEAMLESS_LOOP_CONT_COUNT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1033
#define RSSFU_ATTR_TSGEN_SEAMLESS_LOOP_PCR_DTS_PTS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1034
#define RSSFU_ATTR_TSGEN_SEAMLESS_LOOP_TDT_TOT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1035
#define RSSFU_ATTR_TSGEN_STOP_DATA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1036
#define RSSFU_ATTR_TSGEN_PLAYER_TEST_TS_PACKET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1037
#define RSSFU_ATTR_TSGEN_PAYLOAD_TEST_STUFF                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1038
#define RSSFU_ATTR_TSGEN_PLAYER_PRBS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1039
#define RSSFU_ATTR_MM_GENERATOR_PLAYER_FILE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1267
#define RSSFU_ATTR_MM_GENERATOR_PLAYER_OUTPUT_PACKET_LENGTH                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1268
#define RSSFU_ATTR_MM_GENERATOR_PLAYER_OUTPUT_MODE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1269
#define RSSFU_ATTR_MM_GENERATOR_PLAYER_TS_DATA_RATE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1270
#define RSSFU_ATTR_MM_GENERATOR_PLAY_WINDOW_START                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1271
#define RSSFU_ATTR_MM_GENERATOR_PLAY_WINDOW_STOP                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1272
#define RSSFU_ATTR_TSGEN_FREE_MEMORY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1040
#define RSSFU_ATTR_TSGEN_INPUT_TS_DATA_RATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1041
#define RSSFU_ATTR_TSGEN_RECORD_LENGTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1042
#define RSSFU_ATTR_TSGEN_INPUT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1043
#define RSSFU_ATTR_TSGEN_RECORD_SIZE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1044
#define RSSFU_ATTR_TSGEN_RECORD_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1045
#define RSSFU_ATTR_TSGEN_RECORD_PROGRESS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1046
#define RSSFU_ATTR_TSGEN_RECORD_FILENAME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1047
#define RSSFU_ATTR_CAL_ALL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1048
#define RSSFU_ATTR_CAL_ALL_RESULT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1049
#define RSSFU_ATTR_CAL_FREQ                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1050
#define RSSFU_ATTR_CAL_FREQ_RESULT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1051
#define RSSFU_ATTR_CAL_FREQ_DATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1052
#define RSSFU_ATTR_CAL_LEV                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1053
#define RSSFU_ATTR_CAL_LEV_RESULT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1054
#define RSSFU_ATTR_CAL_LEV_DATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1055
#define RSSFU_ATTR_CAL_LOCAL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1056
#define RSSFU_ATTR_CAL_LOCAL_RESULT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1057
#define RSSFU_ATTR_CAL_LOCAL_DATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1058
#define RSSFU_ATTR_CAL_IQM_FULL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1059
#define RSSFU_ATTR_CAL_IQM_FULL_RESULT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1060
#define RSSFU_ATTR_CAL_IQM_FULL_DATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1061
#define RSSFU_ATTR_CAL_LEV_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1062
#define RSSFU_ATTR_ROSC_FREQ                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1065
#define RSSFU_ATTR_ROSC_ADJ_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1066
#define RSSFU_ATTR_ROSC_ADJ_FREQUENCY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1067
#define RSSFU_ATTR_ROSC_SYNC_BANDWIDTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1068
#define RSSFU_ATTR_ROSC_SOURCE_BTC                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1246
#define RSSFU_ATTR_ROSC_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1069
#define RSSFU_ATTR_TRIGGER_IO_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1070
#define RSSFU_ATTR_TRIGGER_IO_SOURCE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1071
#define RSSFU_ATTR_TRIGGER_IO_DESTINATION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1072
#define RSSFU_ATTR_DM_DRATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1073
#define RSSFU_ATTR_DM_DIGITAL_I_OUTPUT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1074
#define RSSFU_ATTR_DM_DIGITAL_Q_OUTPUT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1075
#define RSSFU_ATTR_DM_ANALOG_I_OUTPUT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1076
#define RSSFU_ATTR_DM_ANALOG_Q_OUTPUT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1077
#define RSSFU_ATTR_SYSTEM_DISPLAY_UPDATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1078
#define RSSFU_ATTR_SYSTEM_KLOCK                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1079
#define RSSFU_ATTR_ERROR_LIST                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1242
#define RSSFU_ATTR_PRESET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1243
#define RSSFU_ATTR_RCL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1080
#define RSSFU_ATTR_SAV                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1081
#define RSSFU_ATTR_SYSTEM_DRIVES                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1263
#define RSSFU_ATTR_SYSTEM_FILE_ATTRIBUTE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1264
#define RSSFU_ATTR_POWER_METER_STATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1082
#define RSSFU_ATTR_POWER_METER_POWER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1083
#define RSSFU_ATTR_POWER_METER_UNIT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1084
#define RSSFU_ATTR_POWER_METER_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1085
#define RSSFU_ATTR_POWER_METER_FREQUENCY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1086
#define RSSFU_ATTR_POWER_METER_REL_POWER_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1087
#define RSSFU_ATTR_POWER_METER_M2REF                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1088
#define RSSFU_ATTR_POWER_METER_REF_POWER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1089
#define RSSFU_ATTR_POWER_METER_REL_POWER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1090
#define RSSFU_ATTR_POWER_METER_FILTER_TYPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1091
#define RSSFU_ATTR_POWER_METER_FILTER_LENGTH                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1092
#define RSSFU_ATTR_POWER_METER_AUTO_ONCE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1093
#define RSSFU_ATTR_POWER_METER_ZERO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1094
#define RSSFU_ATTR_POWER_METER_SENSOR_TYPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1095
#define RSSFU_ATTR_ID_QUERY_RESPONSE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1096

// rssfu_rngCalibrationResult
#define RSSFU_VAL_FAIL                                                      0
#define RSSFU_VAL_PASS                                                      1

// rssfu_rngRfoutAmode
#define RSSFU_RFOUT_AMODE_AUTO                                              0
#define RSSFU_RFOUT_AMODE_FIX                                               1
#define RSSFU_RFOUT_AMODE_NORM                                              2
#define RSSFU_RFOUT_AMODE_HPOW                                              3

// rssfu_rngIqcInp
#define RSSFU_IQC_ASIF                                                      0
#define RSSFU_IQC_ASIR                                                      1
#define RSSFU_IQC_SPIF                                                      2
#define RSSFU_IQC_SPIR                                                      3
#define RSSFU_IQC_SMPF                                                      4
#define RSSFU_IQC_SMPR                                                      5
#define RSSFU_IQC_ASI1                                                      6
#define RSSFU_IQC_ASI2                                                      7
#define RSSFU_IQC_SFAR                                                      8

// rssfu_rngIqcPayl
#define RSSFU_IQC_PRBS                                                      0
#define RSSFU_IQC_H00                                                       1
#define RSSFU_IQC_HFF                                                       2

// rssfu_rngIqcPidt
#define RSSFU_IQC_PIDT_NULL                                                 0
#define RSSFU_IQC_PIDT_VAR                                                  1

// rssfu_rngIqcPrbsMode
#define RSSFU_IQC_PRBS_P231                                                 0
#define RSSFU_IQC_PRBS_P151                                                 1

// rssfu_rngIqcDirCodeRate
#define RSSFU_IQC_CRATE_R12                                                 0
#define RSSFU_IQC_CRATE_R23                                                 1
#define RSSFU_IQC_CRATE_R67                                                 2

// rssfu_rngIqcStuf
#define RSSFU_IQC_STUF_OFF                                                  0
#define RSSFU_IQC_STUF_ON                                                   1
#define RSSFU_IQC_STUF_ONEX                                                 2

// rssfu_rngIqcTestSig
#define RSSFU_IQC_TEST_TTSP                                                 0
#define RSSFU_IQC_TEST_PBEC                                                 1
#define RSSFU_IQC_TEST_PAFC                                                 2
#define RSSFU_IQC_TEST_PBEM                                                 3

// rssfu_rngIqcTestPacketMode
#define RSSFU_IQC_TS_MODE_HEAD                                              0
#define RSSFU_IQC_TS_MODE_SYNC                                              1

// rssfu_rngIqcDmbtChanBwd
#define RSSFU_IQC_DMBT_CHBW6                                                0
#define RSSFU_IQC_DMBT_CHBW7                                                1
#define RSSFU_IQC_DMBT_CHBW8                                                2

// rssfu_rngIqcDmbtCons
#define RSSFU_IQC_CONST_QPSK                                                0
#define RSSFU_IQC_CONST_16QAM                                               1
#define RSSFU_IQC_CONST_64QAM                                               2

// rssfu_rngIqcDbmtCont
#define RSSFU_IQC_DBMT_CONT_MAN                                             0
#define RSSFU_IQC_DBMT_CONT_MIP                                             1

// rssfu_rngIqcDmbtGuar
#define RSSFU_IQC_GUAR_G14                                                  0
#define RSSFU_IQC_GUAR_G19                                                  1

// rssfu_rngIqcDmbtNetw
#define RSSFU_IQC_NETW_SFN                                                  0
#define RSSFU_IQC_NETW_MFN                                                  1

// rssfu_rngIqcDmbtCodeRate
#define RSSFU_IQC_DMBT_CRATE_23                                             0
#define RSSFU_IQC_DMBT_CRATE_49                                             1
#define RSSFU_IQC_DMBT_CRATE_89                                             2

// rssfu_rngIqcDmbtPrbsMode
#define RSSFU_IQC_PRBS_P91                                                  2

// rssfu_rngIqcRandRest
#define RSSFU_IQC_RAND_FRAM                                                 0
#define RSSFU_IQC_RAND_FRGR                                                 1

// rssfu_rngIqcDmbtTestSig
#define RSSFU_IQC_TSIG_TTSP                                                 0
#define RSSFU_IQC_TSIG_PRBS                                                 1

// rssfu_rngIqcTimeInter
#define RSSFU_IQC_TINT_OFF                                                  0
#define RSSFU_IQC_TINT_I48                                                  1
#define RSSFU_IQC_TINT_I240                                                 2
#define RSSFU_IQC_TINT_I720                                                 3

// rssfu_rngIqcDvbcCons
#define RSSFU_IQC_DVBC_CONS_16QAM                                           0
#define RSSFU_IQC_DVBC_CONS_32QAM                                           1
#define RSSFU_IQC_DVBC_CONS_64QAM                                           2
#define RSSFU_IQC_DVBC_CONS_128QAM                                          3
#define RSSFU_IQC_DVBC_CONS_256QAM                                          4

// rssfu_rngIqcDvbcTest
#define RSSFU_IQC_DVBC_TEST_TTSP                                            0
#define RSSFU_IQC_DVBC_TEST_PBEM                                            1

// rssfu_rngIqcDvbtChanBw
#define RSSFU_IQC_DVBT_CHBW_VAR                                             0
#define RSSFU_IQC_DVBT_CHBW6                                                1
#define RSSFU_IQC_DVBT_CHBW7                                                2
#define RSSFU_IQC_DVBT_CHBW8                                                3
#define RSSFU_IQC_DVBT_CHBW5                                                4

// rssfu_rngIqcDvbtSymb
#define RSSFU_IQC_DVBT_SYMB_NAT                                             0
#define RSSFU_IQC_DVBT_SYMB_IND                                             1

// rssfu_rngIqcDvbtFftMode
#define RSSFU_IQC_DVBT_FFT_M2K                                              0
#define RSSFU_IQC_DVBT_FFT_M4K                                              1
#define RSSFU_IQC_DVBT_FFT_M8K                                              2

// rssfu_rngIqcDvbtGuarInt
#define RSSFU_IQC_DVBT_GUAR_14                                              0
#define RSSFU_IQC_DVBT_GUAR_18                                              1
#define RSSFU_IQC_DVBT_GUAR_16                                              2
#define RSSFU_IQC_DVBT_GUAR_32                                              3

// rssfu_rngIqcDvbtHier
#define RSSFU_IQC_DVBT_HIER_NONE                                            0
#define RSSFU_IQC_DVBT_HIER_A1                                              1
#define RSSFU_IQC_DVBT_HIER_A2                                              2
#define RSSFU_IQC_DVBT_HIER_A4                                              3

// rssfu_rngIqcCodeRate
#define RSSFU_IQC_CRATE_12                                                  0
#define RSSFU_IQC_CRATE_23                                                  1
#define RSSFU_IQC_CRATE_34                                                  2
#define RSSFU_IQC_CRATE_56                                                  3
#define RSSFU_IQC_CRATE_78                                                  4
#define RSSFU_IQC_CRATE_89                                                  5

// rssfu_rngIqcDvbsCons
#define RSSFU_IQC_DVBS_CONS_QPSK                                            0
#define RSSFU_IQC_DVBS_CONS_8PSK                                            1
#define RSSFU_IQC_DVBS_CONS_16QAM                                           2

// rssfu_rngIqcDvbsRolloff
#define RSSFU_VAL_DVBS_ROLL_OFF_0_25                                        0
#define RSSFU_VAL_DVBS_ROLL_OFF_0_30                                        1
#define RSSFU_VAL_DVBS_ROLL_OFF_0_35                                        2
#define RSSFU_VAL_DVBS_ROLL_OFF_0_40                                        3
#define RSSFU_VAL_DVBS_ROLL_OFF_0_45                                        4

// rssfu_rngIqcDvbs2Cons
#define RSSFU_IQC_DVBS2_CONS_QPSK                                           0
#define RSSFU_IQC_DVBS2_CONS_8PSK                                           1
#define RSSFU_IQC_DVBS2_CONS_16APSK                                         2
#define RSSFU_IQC_DVBS2_CONS_32APSK                                         3

// rssfu_rngIqcDvbs2Rolloff
#define RSSFU_VAL_DVBS2_ROLL_OFF_0_15                                       0
#define RSSFU_VAL_DVBS2_ROLL_OFF_0_20                                       1
#define RSSFU_VAL_DVBS2_ROLL_OFF_0_25                                       2
#define RSSFU_VAL_DVBS2_ROLL_OFF_0_35                                       3

// rssfu_rngIqcDvbs2Amc
#define RSSFU_IQC_DVBS2_AMC_DVS2                                            0
#define RSSFU_IQC_DVBS2_AMC_DIR                                             1
#define RSSFU_IQC_DVBS2_AMC_DVBS                                            2

// rssfu_rngIqcDvbs2PhasShap
#define RSSFU_VAL_SHAPE1                                                    1
#define RSSFU_VAL_SHAPE2                                                    2
#define RSSFU_VAL_SHAPE3                                                    3

// rssfu_rnqFreqMode
#define RSSFU_VAL_FREQ_MODE_CW_FIX                                          0
#define RSSFU_VAL_FREQ_MODE_SWEEP                                           1

// rssfu_rngFreqSweMode
#define RSSFU_VAL_FREQ_SWE_MODE_AUTO                                        0
#define RSSFU_VAL_FREQ_SWE_MODE_MAN                                         1
#define RSSFU_VAL_FREQ_SWE_MODE_STEP                                        2

// rssfu_rngFreqSweSpac
#define RSSFU_VAL_FREQ_SWE_SPAC_LIN                                         0
#define RSSFU_VAL_FREQ_SWE_SPAC_LOG                                         1

// rssfu_rngBerParallel
#define RSSFU_VAL_BER_ALW                                                   0
#define RSSFU_VAL_BER_DVAL                                                  1

// rssfu_rngBerSelMeas
#define RSSFU_VAL_BER_INP_SEL_SER                                           0
#define RSSFU_VAL_BER_INP_SEL_ASIF                                          1
#define RSSFU_VAL_BER_INP_SEL_ASIR                                          2
#define RSSFU_VAL_BER_INP_SEL_SPIF                                          3
#define RSSFU_VAL_BER_INP_SEL_SPIR                                          4
#define RSSFU_VAL_BER_INP_SEL_SMPF                                          5
#define RSSFU_VAL_BER_INP_SEL_SMPR                                          6

// rssfu_rngBerInpClk
#define RSSFU_BER_INP_CLK_NORM                                              0
#define RSSFU_BER_INP_CLK_INV                                               1

// rssfu_rngBerFuncInp
#define RSSFU_BER_FUNC_INP_ALW                                              0
#define RSSFU_BER_FUNC_INP_HIGH                                             1
#define RSSFU_BER_FUNC_INP_LOW                                              2

// rssfu_rngBerBitPatt
#define RSSFU_ATTR_BER_PATT_PRBS                                            0
#define RSSFU_ATTR_BER_PATT_H00                                             1
#define RSSFU_ATTR_BER_PATT_HFF                                             2

// rssfu_rngBerPrbsSeq
#define RSSFU_VAL_BER_PRBS_P23_1                                            0
#define RSSFU_VAL_BER_PRBS_P15_1                                            1

// rssfu_rngBerDataStream
#define RSSFU_VAL_BER_SIGNAL_H184                                           0
#define RSSFU_VAL_BER_SIGNAL_S187                                           1
#define RSSFU_VAL_BER_SIGNAL_STUF                                           2
#define RSSFU_VAL_BER_SIGNAL_H200                                           3
#define RSSFU_VAL_BER_SIGNAL_S203                                           4
#define RSSFU_VAL_BER_SIGNAL_H204                                           5
#define RSSFU_VAL_BER_SIGNAL_S207                                           6

// rssfu_rngBerGatMode
#define RSSFU_VAL_BER_INF                                                   0
#define RSSFU_VAL_BER_AUTO                                                  1
#define RSSFU_VAL_BER_UWIN                                                  2
#define RSSFU_VAL_BER_USING                                                 3

// rssfu_rngDigMod
#define RSSFU_VAL_DIG_MOD_WBNC                                              0
#define RSSFU_VAL_DIG_MOD_WBEC                                              1
#define RSSFU_VAL_DIG_MOD_DIVN                                              2
#define RSSFU_VAL_DIG_MOD_NRWN                                              3
#define RSSFU_VAL_DIG_MOD_NWEC                                              4
#define RSSFU_VAL_DIG_MOD_AUTO                                              5

// rssfu_rngDigModOutp
#define RSSFU_VAL_DIG_MOD_OUTP_OFF                                          0
#define RSSFU_VAL_DIG_MOD_OUTP_AFC                                          1
#define RSSFU_VAL_DIG_MOD_OUTP_AFFA                                         2
#define RSSFU_VAL_DIG_MOD_OUTP_AFN                                          3
#define RSSFU_VAL_DIG_MOD_OUTP_AFB                                          4
#define RSSFU_VAL_DIG_MOD_OUTP_ARB                                          5
#define RSSFU_VAL_DIG_MOD_OUTP_DIG                                          6
#define RSSFU_VAL_DIG_MOD_OUTP_ANALOG                                       7
#define RSSFU_VAL_DIG_MOD_OUTP_AFFB                                         8

// rssfu_rngModGain
#define RSSFU_VAL_MOD_GAIN_AUTO                                             0
#define RSSFU_VAL_MOD_GAIN_DB6                                              1
#define RSSFU_VAL_MOD_GAIN_DB3                                              2
#define RSSFU_VAL_MOD_GAIN_DB0                                              3
#define RSSFU_VAL_MOD_GAIN_DBM3                                             4

// rssfu_rngArbClkSource
#define RSSFU_VAL_ARB_CLK_SOUR_INT                                          0
#define RSSFU_VAL_ARB_CLK_SOUR_EXT                                          1

// rssfu_rngArbExtClkMode
#define RSSFU_VAL_ARB_EXT_MODE_SAMP                                         0
#define RSSFU_VAL_ARB_EXT_MODE_MSAM                                         1

// rssfu_rngDmSigSource
#define RSSFU_VAL_DM_SOURCE_INT                                             0
#define RSSFU_VAL_DM_SOURCE_ARB                                             1
#define RSSFU_VAL_DM_SOURCE_DIG                                             2
#define RSSFU_VAL_DM_SOURCE_ANAL                                            3
#define RSSFU_VAL_DM_SOURCE_DIR                                             4
#define RSSFU_VAL_DM_SOURCE_DTV                                             5
#define RSSFU_VAL_DM_SOURCE_ATV                                             6
#define RSSFU_VAL_DM_SOURCE_AUDIO                                           7

// rssfu_rngDmInterferSource
#define RSSFU_VAL_DM_INTERFER_SOUR_OFF                                      0
#define RSSFU_VAL_DM_INTERFER_SOUR_ARB                                      1
#define RSSFU_VAL_DM_INTERFER_SOUR_DIG                                      2
#define RSSFU_VAL_DM_INTERFER_SOUR_ANAL                                     3
#define RSSFU_VAL_DM_INTERFER_SOUR_ATVP                                     4

// rssfu_rngDmInterferAdd
#define RSSFU_VAL_DM_INTERFER_ADD_OFF                                       0
#define RSSFU_VAL_DM_INTERFER_ADD_BEFF                                      1
#define RSSFU_VAL_DM_INTERFER_ADD_AFF                                       2
#define RSSFU_VAL_DM_INTERFER_ADD_NOISE                                     3
#define RSSFU_VAL_DM_INTERFER_ADD_MOD                                       4

// rssfu_rngDmTransmStd
#define RSSFU_VAL_DM_STANDARD_DVBT                                          0
#define RSSFU_VAL_DM_STANDARD_DVBC                                          1
#define RSSFU_VAL_DM_STANDARD_DVBS                                          2
#define RSSFU_VAL_DM_STANDARD_8VSB                                          3
#define RSSFU_VAL_DM_STANDARD_J83B                                          4
#define RSSFU_VAL_DM_STANDARD_ISDBT                                         5
#define RSSFU_VAL_DM_STANDARD_DMBT                                          6
#define RSSFU_VAL_DM_STANDARD_DVBS2                                         7
#define RSSFU_VAL_DM_STANDARD_DIR                                           8
#define RSSFU_VAL_DM_STANDARD_TDMB                                          9
#define RSSFU_VAL_DM_STANDARD_MEDIAFLO                                      10
#define RSSFU_VAL_DM_STANDARD_DMBTH                                         11
#define RSSFU_VAL_DM_STANDARD_DTMB                                          12
#define RSSFU_VAL_DM_STANDARD_CMMB                                          14
#define RSSFU_VAL_DM_STANDARD_T2DVB                                         16
#define RSSFU_VAL_DM_STANDARD_ATSM                                          17
#define RSSFU_VAL_DM_STANDARD_DVBC2                                         18
#define RSSFU_VAL_DM_STANDARD_ISDBTMM                                       19

// rssfu_rngDmSpectPolar
#define RSSFU_VAL_DM_SPEC_POLAR_NORM                                        0
#define RSSFU_VAL_DM_SPEC_POLAR_INV                                         1

// rssfu_rngIqcDvbs2TestPacketMode
#define RSSFU_IQC_TS_MODE_H184                                              0
#define RSSFU_IQC_TS_MODE_S187                                              1
#define RSSFU_IQC_TS_MODE_H127                                              2
#define PRSSFU_IQC_TS_MODE_130                                              3

// rssfu_rngNoiseState
#define RSSFU_VAL_NOISE_OFF                                                 0
#define RSSFU_VAL_NOISE_ADD                                                 1
#define RSSFU_VAL_NOISE_ONLY                                                2

// rssfu_rngPowAlcState
#define RSSFU_VAL_POW_ALC_OFF                                               0
#define RSSFU_VAL_POW_ALC_ON                                                1
#define RSSFU_VAL_POW_ALC_AUTO                                              2

// rssfu_rngPowAlcMode
#define RSSFU_VAL_POW_ALC_SHOL                                              0

// rssfu_rngPowLevUnit
#define RSSFU_VAL_POW_LEV_DBM                                               0
#define RSSFU_VAL_POW_LEV_DBUV                                              1
#define RSSFU_VAL_POW_LEV_MV                                                2
#define RSSFU_VAL_POW_LEV_DBMV                                              3

// rssfu_rngRoscFreq
#define RSSFU_VAL_ROSC_FREQ_5M                                              0
#define RSSFU_VAL_ROSC_FREQ_10M                                             1
#define RSSFU_VAL_ROSC_FREQ_13M                                             2

// rssfu_rngRoscSyncBw
#define RSSFU_VAL_ROSC_SYNC_BW_STAN                                         0
#define RSSFU_VAL_ROSC_SYNC_BW_NARR                                         1

// rssfu_rngRoscSource
#define RSSFU_VAL_ROSC_SOURCE_INT                                           0
#define RSSFU_VAL_ROSC_SOURCE_EXT                                           1

// rssfu_rngFadingProf
#define RSSFU_VAL_FADING_DEL_PROF_PDOP                                      0
#define RSSFU_VAL_FADING_DEL_PROF_SPAT                                      1
#define RSSFU_VAL_FADING_DEL_PROF_RAYL                                      2
#define RSSFU_VAL_FADING_DEL_PROF_RICE                                      3
#define RSSFU_VAL_FADING_DEL_PROF_CPH                                       4
#define RSSFU_VAL_FADING_DEL_PROF_GAU1                                      5
#define RSSFU_VAL_FADING_DEL_PROF_GAU2                                      6
#define RSSFU_VAL_FADING_DEL_PROF_GAUD                                      7
#define RSSFU_VAL_FADING_DEL_PROF_GDOP                                      8
#define RSSFU_VAL_FADING_DEL_PROF_G01                                       9
#define RSSFU_VAL_FADING_DEL_PROF_G008                                      10

// rssfu_rngFadingParam
#define RSSFU_VAL_FADING_PAR_EASY3                                          0
#define RSSFU_VAL_FADING_PAR_ECHO                                           1
#define RSSFU_VAL_FADING_PAR_FX                                             2
#define RSSFU_VAL_FADING_PAR_PT                                             3
#define RSSFU_VAL_FADING_PAR_SFN                                            4
#define RSSFU_VAL_FADING_PAR_TU6                                            5
#define RSSFU_VAL_FADING_PAR_RA6                                            6
#define RSSFU_VAL_FADING_PAR_RC6                                            7
#define RSSFU_VAL_FADING_PAR_RL6                                            8
#define RSSFU_VAL_FADING_PAR_RED                                            9
#define RSSFU_VAL_FADING_PAR_ET50                                           10
#define RSSFU_VAL_FADING_PAR_VAL                                            11
#define RSSFU_VAL_FADING_PAR_RC12                                           12
#define RSSFU_VAL_FADING_PAR_RL12                                           13
#define RSSFU_VAL_FADING_PAR_TU3                                            14
#define RSSFU_VAL_FADING_PAR_TU50                                           15
#define RSSFU_VAL_FADING_PAR_HT100                                          16
#define RSSFU_VAL_FADING_PAR_AA_S                                           17
#define RSSFU_VAL_FADING_PAR_AB_S                                           18
#define RSSFU_VAL_FADING_PAR_AC_S                                           19
#define RSSFU_VAL_FADING_PAR_AD_S                                           20
#define RSSFU_VAL_FADING_PAR_AE_S                                           21
#define RSSFU_VAL_FADING_PAR_AF_S                                           22
#define RSSFU_VAL_FADING_PAR_AG_S                                           23
#define RSSFU_VAL_FADING_PAR_B_ECHO                                         24
#define RSSFU_VAL_FADING_PAR_C1R                                            25
#define RSSFU_VAL_FADING_PAR_C2R                                            26
#define RSSFU_VAL_FADING_PAR_C3R                                            27
#define RSSFU_VAL_FADING_PAR_RC20                                           28
#define RSSFU_VAL_FADING_PAR_RL20                                           29
#define RSSFU_VAL_FADING_PAR_HIC                                            30
#define RSSFU_VAL_FADING_PAR_HNIC                                           31
#define RSSFU_VAL_FADING_PAR_HPT                                            32
#define RSSFU_VAL_FADING_PAR_HNPT                                           33
#define RSSFU_VAL_FADING_PAR_MBR                                            34
#define RSSFU_VAL_FADING_PAR_A_BR                                           35
#define RSSFU_VAL_FADING_PAR_B_B                                            36
#define RSSFU_VAL_FADING_PAR_C_BR                                           37
#define RSSFU_VAL_FADING_PAR_CS_B                                           38
#define RSSFU_VAL_FADING_PAR_CM_B                                           39
#define RSSFU_VAL_FADING_PAR_D_BR                                           40
#define RSSFU_VAL_FADING_PAR_DM_B                                           41
#define RSSFU_VAL_FADING_PAR_E_BR                                           42
#define RSSFU_VAL_FADING_PAR_D1CR                                           43
#define RSSFU_VAL_FADING_PAR_D2CR                                           44
#define RSSFU_VAL_FADING_PAR_D3CR                                           45
#define RSSFU_VAL_FADING_PAR_D4CR                                           46
#define RSSFU_VAL_FADING_PAR_A_AC                                           47
#define RSSFU_VAL_FADING_PAR_CHP1                                           48
#define RSSFU_VAL_FADING_PAR_CHP2                                           49
#define RSSFU_VAL_FADING_PAR_CHP3                                           50
#define RSSFU_VAL_FADING_PAR_CHP4                                           51
#define RSSFU_VAL_FADING_PAR_CHP5                                           52
#define RSSFU_VAL_FADING_PAR_CHP6                                           53
#define RSSFU_VAL_FADING_PAR_CHP7                                           54
#define RSSFU_VAL_FADING_PAR_IEC62                                          55
#define RSSFU_VAL_FADING_PAR_RA4                                            56
#define RSSFU_VAL_FADING_PAR_RA6DAB                                         57
#define RSSFU_VAL_FADING_PAR_TU12DA                                         58
#define RSSFU_VAL_FADING_PAR_TU6DAB                                         59
#define RSSFU_VAL_FADING_PAR_DAB_SFN                                        60
#define RSSFU_VAL_FADING_PAR_PI                                             61
#define RSSFU_VAL_FADING_PAR_PO                                             62
#define RSSFU_VAL_FADING_PAR_VU                                             63
#define RSSFU_VAL_FADING_PAR_MR                                             64

// rssfu_rngFsimSpeedUnit
#define RSSFU_VAL_FADING_SPEED_MPS                                          0
#define RSSFU_VAL_FADING_SPEED_KMH                                          1
#define RSSFU_VAL_FADING_SPEED_MPH                                          2

// rssfu_rngFsimFreqHoppMode
#define RSSFU_VAL_FADING_HOPP_FREQ_OFF                                      0
#define RSSFU_VAL_FADING_HOPP_FREQ_IBAN                                     1
#define RSSFU_VAL_FADING_HOPP_FREQ_OOB                                      2

// rssfu_rngFsimDedicTo
#define RSSFU_VAL_FADING_DEDIC_BB                                           0
#define RSSFU_VAL_FADING_DEDIC_RF                                           1
#define RSSFU_VAL_FADING_DEDIC_SFU                                          2
#define RSSFU_VAL_FADING_DEDIC_SFE                                          3
#define RSSFU_VAL_FADING_DEDIC_SMU                                          4

// rssfu_rngFsimInsLossMode
#define RSSFU_VAL_FADING_LOSS_MODE_NORM                                     0
#define RSSFU_VAL_FADING_LOSS_MODE_LACP                                     1
#define RSSFU_VAL_FADING_LOSS_MODE_USER                                     2

// rssfu_rngFsimRestartMode
#define RSSFU_VAL_FADING_RESTART_MODE_AUTO                                  0
#define RSSFU_VAL_FADING_RESTART_MODE_MAN                                   1

// rssfu_rngIqcDvbs2CodeRate
#define RSSFU_IQC_DVBS2_CRATE_12                                            0
#define RSSFU_IQC_DVBS2_CRATE_35                                            1
#define RSSFU_IQC_DVBS2_CRATE_23                                            2
#define RSSFU_IQC_DVBS2_CRATE_34                                            3
#define RSSFU_IQC_DVBS2_CRATE_45                                            4
#define RSSFU_IQC_DVBS2_CRATE_56                                            5
#define RSSFU_IQC_DVBS2_CRATE_67                                            6
#define RSSFU_IQC_DVBS2_CRATE_78                                            7
#define RSSFU_IQC_DVBS2_CRATE_89                                            8
#define RSSFU_IQC_DVBS2_CRATE_910                                           9
#define RSSFU_IQC_DVBS2_CRATE_13                                            10
#define RSSFU_IQC_DVBS2_CRATE_14                                            11
#define RSSFU_IQC_DVBS2_CRATE_25                                            12

// rssfu_rngIqcAtvSoundMode
#define RSSFU_VAL_IQC_ATV_SOUND_MODE_OFF                                    0
#define RSSFU_VAL_IQC_ATV_SOUND_MODE_FMM                                    1
#define RSSFU_VAL_IQC_ATV_SOUND_MODE_FMST                                   2
#define RSSFU_VAL_IQC_ATV_SOUND_MODE_FMD                                    3
#define RSSFU_VAL_IQC_ATV_SOUND_MODE_BTSC                                   4
#define RSSFU_VAL_IQC_ATV_SOUND_MODE_NIC                                    5
#define RSSFU_VAL_IQC_ATV_SOUND_MODE_AMM                                    6
#define RSSFU_VAL_IQC_ATV_SOUND_MODE_MNIC                                   7
#define RSSFU_VAL_IQC_ATV_SOUND_MODE_FMSK                                   8
#define RSSFU_VAL_IQC_ATV_SOUND_MODE_FMDK                                   9

// rssfu_rngTsgenWaveform
#define RSSFU_VAL_TSGEN_WAVEFORM_SINUS                                      0
#define RSSFU_VAL_TSGEN_WAVEFORM_SQUARE                                     1
#define RSSFU_VAL_TSGEN_WAVEFORM_TRIANGLE                                   2

// rssfu_rngTsgenPacketLength
#define RSSFU_VAL_TSGEN_P188                                                0
#define RSSFU_VAL_TSGEN_P204                                                1
#define RSSFU_VAL_TSGEN_P208                                                2

// rssfu_rngTsgenTsSerialOut
#define RSSFU_VAL_TSGEN_ASIBURST                                            0
#define RSSFU_VAL_TSGEN_ASICONT                                             1
#define RSSFU_VAL_TSGEN_SMPTE                                               2

// rssfu_rngTsgenInput
#define RSSFU_VAL_TSGEN_ASIF                                                0
#define RSSFU_VAL_TSGEN_ASIR                                                1
#define RSSFU_VAL_TSGEN_SMPF                                                2
#define RSSFU_VAL_TSGEN_SMPR                                                3
#define RSSFU_VAL_TSGEN_SF8T                                                4
#define RSSFU_VAL_TSGEN_SR8T                                                5
#define RSSFU_VAL_TSGEN_SF8B                                                6
#define RSSFU_VAL_TSGEN_SR8B                                                7
#define RSSFU_VAL_TSGEN_SF10                                                8
#define RSSFU_VAL_TSGEN_SR10                                                9
#define RSSFU_VAL_TSGEN_ETI                                                 10
#define RSSFU_VAL_TSGEN_ASI1                                                11
#define RSSFU_VAL_TSGEN_ASI2                                                12
#define RSSFU_VAL_TSGEN_ASI3                                                13
#define RSSFU_VAL_TSGEN_SMP1                                                14
#define RSSFU_VAL_TSGEN_SMP2                                                15
#define RSSFU_VAL_TSGEN_TSAN                                                16
#define RSSFU_VAL_TSGEN_IP                                                  17
#define RSSFU_VAL_TSGEN_OFF                                                 18

// rssfu_rngTsgenRecordMode
#define RSSFU_VAL_TSGEN_MODE_SINGLESHOT                                     0
#define RSSFU_VAL_TSGEN_MODE_CONTINUOUS                                     1

// rssfu_rngTsgenPrepare
#define RSSFU_VAL_TSGEN_PREPARE_PLAY                                        0
#define RSSFU_VAL_TSGEN_PREPARE_RECORD                                      1

// rssfu_rngTsgenCommand
#define RSSFU_VAL_TSGEN_STOP                                                0
#define RSSFU_VAL_TSGEN_PAUSE                                               1
#define RSSFU_VAL_TSGEN_PLAY                                                2
#define RSSFU_VAL_TSGEN_RECORD                                              3

// rssfu_rngTdmbSource
#define RSSFU_VAL_TDMB_EXT                                                  0
#define RSSFU_VAL_TDMB_GEN                                                  1
#define RSSFU_VAL_TDMB_TEST                                                 2

// rssfu_rngTdmbTranMode
#define RSSFU_VAL_TDMB_TRAN_MODE_MID                                        0
#define RSSFU_VAL_TDMB_TRAN_MODE_MANUAL                                     1

// rssfu_rngTdmbNetwork
#define RSSFU_VAL_TDMB_NETWORK_MFN                                          0
#define RSSFU_VAL_TDMB_NETWORK_SFN                                          1

// rssfu_rngTdmbPrbsSeq
#define RSSFU_VAL_TDMB_PRBS_P23_1                                           0
#define RSSFU_VAL_TDMB_PRBS_P15_1                                           1
#define RSSFU_VAL_TDMB_PRBS_P20_1                                           2
#define RSSFU_VAL_TDMB_PRBS_ZERO                                            3

// rssfu_rngTdmbProtProfile
#define RSSFU_VAL_TDMB_PROFILE_UEP                                          0
#define RSSFU_VAL_TDMB_PROFILE_EEP                                          1

// rssfu_rngTdmbProtLevel
#define RSSFU_VAL_TDMB_LEVEL_UP1                                            0
#define RSSFU_VAL_TDMB_LEVEL_UP2                                            1
#define RSSFU_VAL_TDMB_LEVEL_UP3                                            2
#define RSSFU_VAL_TDMB_LEVEL_UP4                                            3
#define RSSFU_VAL_TDMB_LEVEL_UP5                                            4
#define RSSFU_VAL_TDMB_LEVEL_EP1A                                           5
#define RSSFU_VAL_TDMB_LEVEL_EP2A                                           6
#define RSSFU_VAL_TDMB_LEVEL_EP3A                                           7
#define RSSFU_VAL_TDMB_LEVEL_EP4A                                           8
#define RSSFU_VAL_TDMB_LEVEL_EP1B                                           9
#define RSSFU_VAL_TDMB_LEVEL_EP2B                                           10
#define RSSFU_VAL_TDMB_LEVEL_EP3B                                           11
#define RSSFU_VAL_TDMB_LEVEL_EP4B                                           12

// rssfu_rngTdmbETI
#define RSSFU_VAL_TDMB_ETINPUT_INV                                          0
#define RSSFU_VAL_TDMB_ETINPUT_ENI                                          1
#define RSSFU_VAL_TDMB_ETINPUT_E559                                         2
#define RSSFU_VAL_TDMB_ETINPUT_E537                                         3

// rssfu_rngIqcDirCons
#define RSSFU_IQC_DIR_CONS_QPSK                                             0

// rssfu_rngIqcDirTestPacketMode
#define RSSFU_IQC_DIR_TS_MODE_H127                                          0
#define RSSFU_IQC_DIR_TS_MODE_P130                                          1

// rssfu_rngDmAtvTransmStd
#define RSSFU_VAL_DM_ATV_STANDARD_BG                                        0
#define RSSFU_VAL_DM_ATV_STANDARD_BGN                                       1
#define RSSFU_VAL_DM_ATV_STANDARD_DK                                        2
#define RSSFU_VAL_DM_ATV_STANDARD_I                                         3
#define RSSFU_VAL_DM_ATV_STANDARD_MN                                        4
#define RSSFU_VAL_DM_ATV_STANDARD_L                                         5
#define RSSFU_VAL_DM_ATV_STANDARD_BGPR                                      6
#define RSSFU_VAL_DM_ATV_STANDARD_BGNPR                                     7
#define RSSFU_VAL_DM_ATV_STANDARD_DKPR                                      8
#define RSSFU_VAL_DM_ATV_STANDARD_IPR                                       9
#define RSSFU_VAL_DM_ATV_STANDARD_MNPR                                      10
#define RSSFU_VAL_DM_ATV_STANDARD_LPR                                       11
#define RSSFU_VAL_DM_ATV_STANDARD_B2CH                                      12
#define RSSFU_VAL_DM_ATV_STANDARD_G2CH                                      13
#define RSSFU_VAL_DM_ATV_STANDARD_BN2CH                                     14
#define RSSFU_VAL_DM_ATV_STANDARD_GN2CH                                     15
#define RSSFU_VAL_DM_ATV_STANDARD_I2CH                                      16
#define RSSFU_VAL_DM_ATV_STANDARD_L2CH                                      17
#define RSSFU_VAL_DM_ATV_STANDARD_DTB                                       18
#define RSSFU_VAL_DM_ATV_STANDARD_DTG                                       19
#define RSSFU_VAL_DM_ATV_STANDARD_DTBN                                      20
#define RSSFU_VAL_DM_ATV_STANDARD_DTGN                                      21
#define RSSFU_VAL_DM_ATV_STANDARD_DTI                                       22
#define RSSFU_VAL_DM_ATV_STANDARD_DTL                                       23
#define RSSFU_VAL_DM_ATV_STANDARD_D1PR                                      24
#define RSSFU_VAL_DM_ATV_STANDARD_I1PR                                      25
#define RSSFU_VAL_DM_ATV_STANDARD_DCPR                                      26

// rssfu_rngIqcDirRollOff
#define RSSFU_VAL_DIR_ROLL_OFF_0_15                                         0
#define RSSFU_VAL_DIR_ROLL_OFF_0_20                                         1
#define RSSFU_VAL_DIR_ROLL_OFF_0_25                                         2
#define RSSFU_VAL_DIR_ROLL_OFF_0_35                                         3

// rssfu_rngNoiseFrameDuration
#define RSSFU_VAL_NOISE_FRAME_DURATION_10                                   0
#define RSSFU_VAL_NOISE_FRAME_DURATION_100                                  1
#define RSSFU_VAL_NOISE_FRAME_DURATION_1000                                 2

// rssfu_rngIqcJ83BTestSig
#define RSSFU_VAL_IQC_J83B_TEST_TTSP                                        0
#define RSSFU_VAL_IQC_J83B_TEST_PBET                                        1
#define RSSFU_VAL_IQC_J83B_TEST_PBEM                                        2

// rssfu_rngIqcVsbTestSig
#define RSSFU_VAL_IQC_VSB_TEST_TTSP                                         0
#define RSSFU_VAL_IQC_VSB_TEST_PBIN                                         1
#define RSSFU_VAL_IQC_VSB_TEST_PBET                                         2
#define RSSFU_VAL_IQC_VSB_TEST_PBEM                                         3

// rssfu_rngIqcDirPackLength
#define RSSFU_VAL_IQC_DIR_PACK_LEN_INV                                      0
#define RSSFU_VAL_IQC_DIR_PACK_LEN_P188                                     1

// rssfu_rngIqcAtvVisionPict
#define RSSFU_VAL_IQC_VISION_PICT_C75P                                      0
#define RSSFU_VAL_IQC_VISION_PICT_C75N                                      1
#define RSSFU_VAL_IQC_VISION_PICT_C75S                                      2
#define RSSFU_VAL_IQC_VISION_PICT_FUBP                                      3
#define RSSFU_VAL_IQC_VISION_PICT_CPAM                                      4
#define RSSFU_VAL_IQC_VISION_PICT_CPAN                                      5
#define RSSFU_VAL_IQC_VISION_PICT_LIBR                                      6

// rssfu_rngIqcJ83BConstellation
#define RSSFU_VAL_IQC_J83B_CONSTEL_J64                                      0
#define RSSFU_VAL_IQC_J83B_CONSTEL_J256                                     1
#define RSSFU_VAL_IQC_J83B_CONSTEL_J1024                                    2

// rssfu_rngIqcJ83BIntrleaverMode
#define RSSFU_VAL_IQC_J83B_INTERLEAVER_0                                    0
#define RSSFU_VAL_IQC_J83B_INTERLEAVER_1                                    1
#define RSSFU_VAL_IQC_J83B_INTERLEAVER_2                                    2
#define RSSFU_VAL_IQC_J83B_INTERLEAVER_3                                    3
#define RSSFU_VAL_IQC_J83B_INTERLEAVER_4                                    4
#define RSSFU_VAL_IQC_J83B_INTERLEAVER_5                                    5
#define RSSFU_VAL_IQC_J83B_INTERLEAVER_6                                    6
#define RSSFU_VAL_IQC_J83B_INTERLEAVER_7                                    7
#define RSSFU_VAL_IQC_J83B_INTERLEAVER_8                                    8
#define RSSFU_VAL_IQC_J83B_INTERLEAVER_9                                    9
#define RSSFU_VAL_IQC_J83B_INTERLEAVER_10                                   10
#define RSSFU_VAL_IQC_J83B_INTERLEAVER_12                                   12
#define RSSFU_VAL_IQC_J83B_INTERLEAVER_14                                   14

// rssfu_rngIqcJ83BPackLength
#define RSSFU_VAL_IQC_J83B_PACK_LEN_INV                                     0
#define RSSFU_VAL_IQC_J83B_PACK_LEN_P188                                    1
#define RSSFU_VAL_IQC_J83B_PACK_LEN_P204                                    2

// rssfu_rngIqcVsbPackLength
#define RSSFU_VAL_IQC_8VSB_PACK_LEN_INV                                     0
#define RSSFU_VAL_IQC_8VSB_PACK_LEN_P188                                    1
#define RSSFU_VAL_IQC_8VSB_PACK_LEN_P204                                    2
#define RSSFU_VAL_IQC_8VSB_PACK_LEN_P208                                    3

// rssfu_rngIqcPackedLength
#define RSSFU_VAL_IQC_PACK_LEN_INV                                          0
#define RSSFU_VAL_IQC_PACK_LEN_P188                                         1
#define RSSFU_VAL_IQC_PACK_LEN_P204                                         2

// rssfu_rngIqcDmbthTestSig
#define RSSFU_VAL_IQC_DMBTH_TEST_TTSP                                       0
#define RSSFU_VAL_IQC_DMBTH_TEST_PRBS                                       1

// rssfu_rngIqcDmbthCodeRate
#define RSSFU_IQC_DMBTH_CRATE_04                                            0
#define RSSFU_IQC_DMBTH_CRATE_06                                            1
#define RSSFU_IQC_DMBTH_CRATE_08                                            2

// rssfu_rngIqcDmbthLpcd
#define RSSFU_VAL_IQC_DMBTH_LDPC_OUT_IFIR                                   0
#define RSSFU_VAL_IQC_DMBTH_LDPC_OUT_QFIR                                   1

// rssfu_rngIqcDmbthPolarity
#define RSSFU_VAL_IQC_DMBTH_POLARITY_MINUS                                  0
#define RSSFU_VAL_IQC_DMBTH_POLARITY_PLUS                                   1

// rssfu_rngIqcIsdbtPortion
#define RSSFU_IQC_VAL_ISDBT_PORTION_PDD                                     0
#define RSSFU_IQC_VAL_ISDBT_PORTION_PDC                                     1
#define RSSFU_IQC_VAL_ISDBT_PORTION_PCC                                     2
#define RSSFU_IQC_VAL_ISDBT_PORTION_DDD                                     3
#define RSSFU_IQC_VAL_ISDBT_PORTION_DDC                                     4
#define RSSFU_IQC_VAL_ISDBT_PORTION_DCC                                     5
#define RSSFU_IQC_VAL_ISDBT_PORTION_CCC                                     6

// rssfu_rngIqcIsdbtConstel
#define RSSFU_IQC_VAL_ISDBT_CONSTEL_DQPSK                                   0
#define RSSFU_IQC_VAL_ISDBT_CONSTEL_QPSK                                    1
#define RSSFU_IQC_VAL_ISDBT_CONSTEL_16QAM                                   2
#define RSSFU_IQC_VAL_ISDBT_CONSTEL_64QAM                                   3

// rssfu_rngIqcIsdbtInterleaving
#define RSSFU_VAL_IQC_ISDBT_TIME_INTER_0                                    0
#define RSSFU_VAL_IQC_ISDBT_TIME_INTER_1                                    1
#define RSSFU_VAL_IQC_ISDBT_TIME_INTER_2                                    2
#define RSSFU_VAL_IQC_ISDBT_TIME_INTER_4                                    3
#define RSSFU_VAL_IQC_ISDBT_TIME_INTER_8                                    4
#define RSSFU_VAL_IQC_ISDBT_TIME_INTER_16                                   5
#define RSSFU_VAL_IQC_ISDBT_TIME_INTER_32                                   6

// rssfu_rngIqcIsdbtMode
#define RSSFU_VAL_IQC_ISDBT_MODE_2K                                         0
#define RSSFU_VAL_IQC_ISDBT_MODE_4K                                         1
#define RSSFU_VAL_IQC_ISDBT_MODE_8K                                         2

// rssfu_rngIqcIsdbtGuardInt
#define RSSFU_VAL_IQC_ISDBT_GUARD_1_4                                       0
#define RSSFU_VAL_IQC_ISDBT_GUARD_1_8                                       1
#define RSSFU_VAL_IQC_ISDBT_GUARD_1_16                                      2
#define RSSFU_VAL_IQC_ISDBT_GUARD_1_32                                      3

// rssfu_rngIqcIsdbtAcData
#define RSSFU_VAL_IQC_ISDBT_AC_DATA_PRBS                                    0
#define RSSFU_VAL_IQC_ISDBT_AC_DATA_ALL1                                    1

// rssfu_rngIqcAtvPreemphasis
#define RSSFU_VAL_IQC_ATV_PREEMPHASIS_OFF                                   0
#define RSSFU_VAL_IQC_ATV_PREEMPHASIS_D50                                   1
#define RSSFU_VAL_IQC_ATV_PREEMPHASIS_D75                                   2

// rssfu_rngFsimp2dynProfile
#define RSSFU_VAL_FADING_P2DYN_PROF_PDOP                                    0
#define RSSFU_VAL_FADING_P2DYN_PROF_SPAT                                    1
#define RSSFU_VAL_FADING_P2DYN_PROF_RAYL                                    2

// rssfu_rngFsimP2dynMovMode
#define RSSFU_VAL_FADING_P2DYN_MOV_MODE_HOPP                                0
#define RSSFU_VAL_FADING_P2DYN_MOV_MODE_SLID                                1

// rssfu_rngArbTrigMode
#define RSSFU_ARB_VAL_TRIG_AUTO                                             0
#define RSSFU_ARB_VAL_TRIG_RETR                                             1
#define RSSFU_ARB_VAL_TRIG_AAUT                                             2
#define RSSFU_ARB_VAL_TRIG_ARET                                             3

// rssfu_rngArbTrigSource
#define RSSFU_ARB_VAL_TRIG_SOURCE_INT                                       0
#define RSSFU_ARB_VAL_TRIG_SOURCE_EXT                                       1

// rssfu_rngArbMkrMode
#define RSSFU_ARB_VAL_MARKER_MODE_RESTART                                   0

// rssfu_rngTrigIoSource
#define RSSFU_VAL_TRIG_IO_SOURCE_SMA1                                       0
#define RSSFU_VAL_TRIG_IO_SOURCE_SMA2                                       1
#define RSSFU_VAL_TRIG_IO_SOURCE_IMP1                                       2
#define RSSFU_VAL_TRIG_IO_SOURCE_IMP2                                       3
#define RSSFU_VAL_TRIG_IO_SOURCE_GND                                        4
#define RSSFU_VAL_TRIG_IO_SOURCE_5V                                         5

// rssfu_rngTrigIoDestination
#define RSSFU_VAL_TRIG_IO_DESTINATION_NONE                                  0

// rssfu_rngFreqVsbFreq
#define RSSFU_VAL_FREQ_VSB_FREQ_PILOT                                       0
#define RSSFU_VAL_FREQ_VSB_FREQ_CENTER                                      1

// rssfu_rngSystemKLock
#define RSSFU_VAL_SYST_KLOCK_OFF                                            0
#define RSSFU_VAL_SYST_KLOCK_ON                                             1

// rssfu_rngTrigIoState
#define RSSFU_VAL_TRIG_IO_STATE_OFF                                         0
#define RSSFU_VAL_TRIG_IO_STATE_IN                                          1
#define RSSFU_VAL_TRIG_IO_STATE_OUT                                         2

// rssfu_rngTsgenCommandState
#define RSSFU_VAL_TSGEN_STAT_STOP                                           0
#define RSSFU_VAL_TSGEN_STAT_PAUSE                                          1
#define RSSFU_VAL_TSGEN_STAT_RUN                                            2
#define RSSFU_VAL_TSGEN_STAT_RECORD                                         3

// rssfu_rngIqcAtvAudioSource
#define RSSFU_VAL_IQC_ATV_AUDIO_SOURCE_EXT                                  0
#define RSSFU_VAL_IQC_ATV_AUDIO_SOURCE_AGEN                                 1
#define RSSFU_VAL_IQC_ATV_AUDIO_SOURCE_APLAY                                2

// rssfu_rngIqcAtvAudioInputImpedance
#define RSSFU_VAL_IQC_ATV_AUDIO_INPUT_IMP_Z50                               0
#define RSSFU_VAL_IQC_ATV_AUDIO_INPUT_IMP_Z600                              1

// rssfu_rngIqcAtvSoundNICSignal
#define RSSFU_VAL_IQC_ATV_SOUND_MODUL_NICAM_STE1                            0
#define RSSFU_VAL_IQC_ATV_SOUND_MODUL_NICAM_DUA1                            1
#define RSSFU_VAL_IQC_ATV_SOUND_MODUL_NICAM_MON1                            2
#define RSSFU_VAL_IQC_ATV_SOUND_MODUL_NICAM_STE2                            3
#define RSSFU_VAL_IQC_ATV_SOUND_MODUL_NICAM_DUA2                            4
#define RSSFU_VAL_IQC_ATV_SOUND_MODUL_NICAM_MON2                            5
#define RSSFU_VAL_IQC_ATV_SOUND_MODUL_NICAM_STE3                            6
#define RSSFU_VAL_IQC_ATV_SOUND_MODUL_NICAM_DUA3                            7
#define RSSFU_VAL_IQC_ATV_SOUND_MODUL_NICAM_MON3                            8

// rssfu_rngIqcAtvSpecialVsbChar
#define RSSFU_VAL_IQC_ATV_SPECIAL_VSB_CHAR_DKFM                             0
#define RSSFU_VAL_IQC_ATV_SPECIAL_VSB_CHAR_DK                               1
#define RSSFU_VAL_IQC_ATV_SPECIAL_VSB_CHAR_DKN                              2
#define RSSFU_VAL_IQC_ATV_SPECIAL_VSB_CHAR_I                                3
#define RSSFU_VAL_IQC_ATV_SPECIAL_VSB_CHAR_I1                               4
#define RSSFU_VAL_IQC_ATV_SPECIAL_VSB_CHAR_M                                5
#define RSSFU_VAL_IQC_ATV_SPECIAL_VSB_CHAR_N                                6
#define RSSFU_VAL_IQC_ATV_SPECIAL_VSB_CHAR_BG                               7
#define RSSFU_VAL_IQC_ATV_SPECIAL_VSB_CHAR_L                                8
#define RSSFU_VAL_IQC_ATV_SPECIAL_VSB_CHAR_LNIC                             9
#define RSSFU_VAL_IQC_ATV_SPECIAL_VSB_CHAR_BGA                              10

// rssfu_rngIqcAtvVideoInput
#define RSSFU_VAL_IQC_ATV_VIDEO_SOURCE_EXT                                  0
#define RSSFU_VAL_IQC_ATV_VIDEO_SOURCE_VGEN                                 1

// rssfu_rngIqcMfloChanBw
#define RSSFU_IQC_VAL_MFLO_CHBW5                                            0
#define RSSFU_IQC_VAL_MFLO_CHBW6                                            1
#define RSSFU_IQC_VAL_MFLO_CHBW7                                            2
#define RSSFU_IQC_VAL_MFLO_CHBW8                                            3

// rssfu_rngFsimReference
#define RSSFU_VAL_FADING_REFERENCE_SPE                                      0
#define RSSFU_VAL_FADING_REFERENCE_FDOP                                     1

// rssfu_rngFsimConfig
#define RSSFU_VAL_FADING_STANDARD                                           0
#define RSSFU_VAL_FADING_DEL30                                              1
#define RSSFU_VAL_FADING_DEL50                                              2
#define RSSFU_VAL_FADING_BIRTH_DEATH                                        3
#define RSSFU_VAL_FADING_MOVING_PROP                                        4
#define RSSFU_VAL_FADING_2PATH_DYNAMIC                                      5

// rssfu_rngIqcDvbcRollOff
#define RSSFU_VAL_DVBC_ROLL_OFF_0_10                                        0
#define RSSFU_VAL_DVBC_ROLL_OFF_0_13                                        1
#define RSSFU_VAL_DVBC_ROLL_OFF_0_15                                        2
#define RSSFU_VAL_DVBC_ROLL_OFF_0_18                                        3
#define RSSFU_VAL_DVBC_ROLL_OFF_0_20                                        4

// rssfu_rngIqcSigSour
#define RSSFU_IQC_SIG_SOUR_EXT                                              0
#define RSSFU_IQC_SIG_SOUR_TSP                                              1
#define RSSFU_IQC_SIG_SOUR_TEST                                             2
#define RSSFU_IQC_SIG_SOUR_XAUTO                                            3
#define RSSFU_IQC_SIG_SOUR_TAUTO                                            4

// rssfu_rngIqcDtmbTestSig
#define RSSFU_DTMB_TEST_TTSP                                                0
#define RSSFU_DTMB_TEST_PRBS                                                1

// rssfu_rngIqcDtmbConstel
#define RSSFU_IQC_DTMB_CONST_QAM                                            0
#define RSSFU_IQC_DTMB_CONST_QAM_NR                                         1
#define RSSFU_IQC_DTMB_CONST_16QAM                                          2
#define RSSFU_IQC_DTMB_CONST_32QAM                                          3
#define RSSFU_IQC_DTMB_CONST_64QAM                                          4

// rssfu_rngIqcDtmbCodeRate
#define RSSFU_IQC_DTMB_CRATE_04                                             0
#define RSSFU_IQC_DTMB_CRATE_06                                             1
#define RSSFU_IQC_DTMB_CRATE_08                                             2

// rssfu_rngIqcDtmbGuar
#define RSSFU_IQC_DTMB_GUAR_G420                                            0
#define RSSFU_IQC_DTMB_GUAR_G595                                            1
#define RSSFU_IQC_DTMB_GUAR_G945                                            2

// rssfu_rngIqcDtmbChanBw
#define RSSFU_IQC_DTMB_CHBW6                                                1
#define RSSFU_IQC_DTMB_CHBW7                                                2
#define RSSFU_IQC_DTMB_CHBW8                                                3

// rssfu_rngIqcDtmbGic
#define RSSFU_VAL_IQC_DTMB_GIC_VAR                                          0
#define RSSFU_VAL_IQC_DTMB_GIC_CONST                                        1

// rssfu_rngIqcIsdbtSystem
#define RSSFU_VAL_IQC_ISDBT_SYSTEM_T                                        0
#define RSSFU_VAL_IQC_ISDBT_SYSTEM_TSB1                                     1
#define RSSFU_VAL_IQC_ISDBT_SYSTEM_TSB3                                     2

// rssfu_rngPowerMeterUnit
#define RSSFU_VAL_POWER_METER_UNIT_DBM                                      0
#define RSSFU_VAL_POWER_METER_UNIT_DBUV                                     1
#define RSSFU_VAL_POWER_METER_UNIT_WATT                                     2

// rssfu_rngPowerMeterSource
#define RSSFU_VAL_PWR_METER_SOURCE_TX                                       0
#define RSSFU_VAL_PWR_METER_SOURCE_USER                                     1

// rssfu_rngPowerMeterRelState
#define RSSFU_VAL_PWR_METER_REL_STAT_OFF                                    0
#define RSSFU_VAL_PWR_METER_REL_STAT_DB                                     1
#define RSSFU_VAL_PWR_METER_REL_STAT_PCT                                    2

// rssfu_rngPowerMeterFilterType
#define RSSFU_VAL_PWR_METER_FILTER_AUTO                                     0
#define RSSFU_VAL_PWR_METER_FILTER_USER                                     1

// rssfu_rngPowerMeterFilterLength
#define RSSFU_VAL_PWR_METER_FILTER_LEN_1                                    0
#define RSSFU_VAL_PWR_METER_FILTER_LEN_2                                    1
#define RSSFU_VAL_PWR_METER_FILTER_LEN_4                                    2
#define RSSFU_VAL_PWR_METER_FILTER_LEN_8                                    3
#define RSSFU_VAL_PWR_METER_FILTER_LEN_16                                   4
#define RSSFU_VAL_PWR_METER_FILTER_LEN_32                                   5
#define RSSFU_VAL_PWR_METER_FILTER_LEN_64                                   6
#define RSSFU_VAL_PWR_METER_FILTER_LEN_128                                  7

// rssfu_rngDmInterferRef
#define RSSFU_VAL_DM_INTERFERER_REF_LEV                                     0
#define RSSFU_VAL_DM_INTERFERER_REF_ATT                                     1

// rssfu_rngIqcDirPhNoiseShape
#define RSSFU_VAL_IQC_DIR_PH_NOISE_SHAPE1                                   0
#define RSSFU_VAL_IQC_DIR_PH_NOISE_SHAPE2                                   1
#define RSSFU_VAL_IQC_DIR_PH_NOISE_SHAPE3                                   2

// rssfu_rngBBImpairOptMode
#define RSSFU_VAL_BB_IMPAIR_MODE_FAST                                       0
#define RSSFU_VAL_BB_IMPAIR_MODE_QHIGH                                      1

// rssfu_rngIqcDvbs2Fecframe
#define RSSFU_IQC_DVBS2_FECFR_NORMAL                                        0
#define RSSFU_IQC_DVBS2_FECFR_SHORT                                         1

// rssfu_rngDmAudioBcStd
#define RSSFU_VAL_MOD_AUDIO_BC_STD_AM                                       0
#define RSSFU_VAL_MOD_AUDIO_BC_STD_FM                                       1

// rssfu_rngAudioBcFmInput
#define RSSFU_VAL_AUDIO_BC_INPUT_OFF                                        0
#define RSSFU_VAL_AUDIO_BC_INPUT_EXT                                        1
#define RSSFU_VAL_AUDIO_BC_INPUT_AGEN                                       2
#define RSSFU_VAL_AUDIO_BC_INPUT_MPX                                        3
#define RSSFU_VAL_AUDIO_BC_INPUT_APL                                        4

// rssfu_rngAudioBcFmMode
#define RSSFU_VAL_AUDIO_BC_AF_MODE_LEFT                                     0
#define RSSFU_VAL_AUDIO_BC_AF_MODE_RIGH                                     1
#define RSSFU_VAL_AUDIO_BC_AF_MODE_REL                                      2
#define RSSFU_VAL_AUDIO_BC_AF_MODE_REM                                      3
#define RSSFU_VAL_AUDIO_BC_AF_MODE_RNE                                      4

// rssfu_rngAudioBcImped
#define RSSFU_VAL_AUDIO_BC_IMPEDANCE_50                                     0
#define RSSFU_VAL_AUDIO_BC_IMPEDANCE_600                                    1

// rssfu_rngAudioBcFmSigType
#define RSSFU_VAL_AUDIO_BC_SIG_TYPE_MONO                                    0
#define RSSFU_VAL_AUDIO_BC_SIG_TYPE_STEREO                                  1

// rssfu_rngAudioBcMoPreemphasis
#define RSSFU_VAL_AUDIO_BC_PREEMPHASIS_OFF                                  0
#define RSSFU_VAL_AUDIO_BC_PREEMPHASIS_D50                                  1
#define RSSFU_VAL_AUDIO_BC_PREEMPHASIS_D75                                  2

// rssfu_rngFsimSource
#define RSSFU_VAL_FADING_SOURCE_DMSOUR                                      0
#define RSSFU_VAL_FADING_SOURCE_ISRC                                        1

// rssfu_rngIcqCmmbSour
#define RSSFU_VAL_IQC_CMMB_SOUR_EXT                                         0
#define RSSFU_VAL_IQC_CMMB_SOUR_GEN                                         1
#define RSSFU_VAL_IQC_CMMB_SOUR_TEST                                        2

// rssfu_rngIqcCmmbControl
#define RSSFU_VAL_IQC_CMMB_CONTROL_AUTO                                     0
#define RSSFU_VAL_IQC_CMMB_CONTROL_MANUAL                                   1

// rssfu_rngIqcCmmbBw
#define RSSFU_VAL_IQC_CMMB_BW_2                                             0
#define RSSFU_VAL_IQC_CMMB_BW_8                                             1

// rssfu_rngIqcCmmbOdfm
#define RSSFU_VAL_IQC_CMMB_OFDM_M1K                                         0
#define RSSFU_VAL_IQC_CMMB_OFDM_M4K                                         1

// rssfu_rngIcgAudioFmRdsMs
#define RSSFU_VAL_AUDIO_BC_RDS_MS_MUSIC                                     0
#define RSSFU_VAL_AUDIO_BC_RDS_MS_SPEECH                                    1

// rssfu_rngIcgAudioFmRdsMethod
#define RSSFU_VAL_AUDIO_BC_RDS_AF_METHOD_A                                  0
#define RSSFU_VAL_AUDIO_BC_RDS_AF_METHOD_B                                  1

// rssfu_rngIcgAudioFmAfBOrder
#define RSSFU_VAL_AUDIO_BC_AFB_ORDER_ASC                                    0
#define RSSFU_VAL_AUDIO_BC_AFB_ORDER_DESC                                   1

// rssfu_rngIcgAudioFmEonMethod
#define RSSFU_VAL_AUDIO_BC_EON_METHOD_A                                     0
#define RSSFU_VAL_AUDIO_BC_EON_METHOD_MAPF                                  1

// rssfu_rngDvbt2MiSource
#define RSSFU_VAL_DVBT2_MI_SOUR_INT                                         0
#define RSSFU_VAL_DVBT2_MI_SOUR_EXT                                         1

// rssfu_rngDvbt2InpFormat
#define RSSFU_VAL_DVBT2_INPUT_FORMAT_TS                                     0
#define RSSFU_VAL_DVBT2_INPUT_FORMAT_GFPS                                   1
#define RSSFU_VAL_DVBT2_INPUT_FORMAT_GCS                                    2
#define RSSFU_VAL_DVBT2_INPUT_FORMAT_GSE                                    3

// rssfu_rngDvbt2PlpType
#define RSSFU_VAL_DVBT2_PLP_TYPE_DT1                                        0
#define RSSFU_VAL_DVBT2_PLP_TYPE_DT2                                        1
#define RSSFU_VAL_DVBT2_PLP_TYPE_COMM                                       2

// rssfu_rngDvbt2BbMode
#define RSSFU_VAL_DVBT2_BB_MODE_HEM                                         0
#define RSSFU_VAL_DVBT2_BB_MODE_NM                                          1

// rssfu_rngDvbt2BicmFec
#define RSSFU_VAL_DVBT2_BICM_FEC_NORMAL                                     0
#define RSSFU_VAL_DVBT2_BICM_FEC_SHORT                                      1

// rssfu_rngDvbt2CRate
#define RSSFU_VAL_IQC_DVBT2_CRATE_R12                                       0
#define RSSFU_VAL_IQC_DVBT2_CRATE_R23                                       1
#define RSSFU_VAL_IQC_DVBT2_CRATE_R34                                       2
#define RSSFU_VAL_IQC_DVBT2_CRATE_R56                                       3
#define RSSFU_VAL_IQC_DVBT2_CRATE_R35                                       4
#define RSSFU_VAL_IQC_DVBT2_CRATE_R45                                       5
#define RSSFU_VAL_IQC_DVBT2_CRATE_R13                                       6
#define RSSFU_VAL_IQC_DVBT2_CRATE_R25                                       7

// rssfu_rngDvbt2Constel
#define RSSFU_VAL_IQC_DVBT2_CONSTEL_T4                                      0
#define RSSFU_VAL_IQC_DVBT2_CONSTEL_T16                                     1
#define RSSFU_VAL_IQC_DVBT2_CONSTEL_T64                                     2
#define RSSFU_VAL_IQC_DVBT2_CONSTEL_T256                                    3

// rssfu_rngDvbt2TimeInt
#define RSSFU_VAL_IQC_DVBT2_TIME_TYPE_T0                                    0
#define RSSFU_VAL_IQC_DVBT2_TIME_TYPE_T1                                    1

// rssfu_rngDvbt2ChBWidth
#define RSSFU_VAL_IQC_DVBT2_CH_BWIDTH_BW_2                                  0
#define RSSFU_VAL_IQC_DVBT2_CH_BWIDTH_BW_5                                  1
#define RSSFU_VAL_IQC_DVBT2_CH_BWIDTH_BW_6                                  2
#define RSSFU_VAL_IQC_DVBT2_CH_BWIDTH_BW_7                                  3
#define RSSFU_VAL_IQC_DVBT2_CH_BWIDTH_BW_8                                  4
#define RSSFU_VAL_IQC_DVBT2_CH_BWIDTH_BW_10                                 5

// rssfu_rngDvbt2FftMode
#define RSSFU_VAL_IQC_DVBT2_FFT_M1K                                         0
#define RSSFU_VAL_IQC_DVBT2_FFT_M2K                                         1
#define RSSFU_VAL_IQC_DVBT2_FFT_M4K                                         2
#define RSSFU_VAL_IQC_DVBT2_FFT_M8K                                         3
#define RSSFU_VAL_IQC_DVBT2_FFT_M8E                                         4
#define RSSFU_VAL_IQC_DVBT2_FFT_M16K                                        5
#define RSSFU_VAL_IQC_DVBT2_FFT_M16E                                        6
#define RSSFU_VAL_IQC_DVBT2_FFT_M32K                                        7
#define RSSFU_VAL_IQC_DVBT2_FFT_M32E                                        8

// rssfu_rngDvbt2GuardInt
#define RSSFU_VAL_IQC_DVBT2_GUARD_G1_4                                      0
#define RSSFU_VAL_IQC_DVBT2_GUARD_G1_8                                      1
#define RSSFU_VAL_IQC_DVBT2_GUARD_G1_16                                     2
#define RSSFU_VAL_IQC_DVBT2_GUARD_G1_32                                     3
#define RSSFU_VAL_IQC_DVBT2_GUARD_G1128                                     4
#define RSSFU_VAL_IQC_DVBT2_GUARD_G19128                                    5
#define RSSFU_VAL_IQC_DVBT2_GUARD_G19256                                    6

// rssfu_rngDvbt2PilotPatt
#define RSSFU_VAL_IQC_DVBT2_PILOT_PP1                                       0
#define RSSFU_VAL_IQC_DVBT2_PILOT_PP2                                       1
#define RSSFU_VAL_IQC_DVBT2_PILOT_PP3                                       2
#define RSSFU_VAL_IQC_DVBT2_PILOT_PP4                                       3
#define RSSFU_VAL_IQC_DVBT2_PILOT_PP5                                       4
#define RSSFU_VAL_IQC_DVBT2_PILOT_PP6                                       5
#define RSSFU_VAL_IQC_DVBT2_PILOT_PP7                                       6
#define RSSFU_VAL_IQC_DVBT2_PILOT_PP8                                       7

// rssfu_rngDvbt2TransSyst
#define RSSFU_VAL_IQC_DVBT2_TRANS_SISO                                      0
#define RSSFU_VAL_IQC_DVBT2_TRANS_MISO                                      1
#define RSSFU_VAL_IQC_DVBT2_TRANS_NONT2                                     2
#define RSSFU_VAL_IQC_DVBT2_TRANS_T2LS                                      3
#define RSSFU_VAL_IQC_DVBT2_TRANS_T2LM                                      4

// rssfu_rngDvbt2PeakAverPow
#define RSSFU_VAL_IQC_DVBT2_PEAK_AVER_POW_OFF                               0
#define RSSFU_VAL_IQC_DVBT2_PEAK_AVER_POW_TR                                1

// rssfu_rngDvbt2L1PostModul
#define RSSFU_VAL_IQC_DVBT2_L1_POST_T2                                      0
#define RSSFU_VAL_IQC_DVBT2_L1_POST_T4                                      1
#define RSSFU_VAL_IQC_DVBT2_L1_POST_T16                                     2
#define RSSFU_VAL_IQC_DVBT2_L1_POST_T64                                     3

// rssfu_rngIqcIsdbtTmccNext
#define RSSFU_VAL_IQC_ISDBT_TMCC_UNUSED                                     0
#define RSSFU_VAL_IQC_ISDBT_TMCC_CURRENT                                    1

// rssfu_rngIqcIsdbtTxParam
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_NORM                                    0
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_N1                                      1
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_N2                                      2
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_N3                                      3
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_N4                                      4
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_N5                                      5
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_N6                                      6
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_N7                                      7
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_N8                                      8
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_N9                                      9
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_N10                                     10
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_N11                                     11
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_N12                                     12
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_N13                                     13
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_N14                                     14
#define RSSFU_IQC_VAL_ISDBT_TXPARAM_N15                                     15

// rssfu_rngIcqCmmbTstSignal
#define RSSFU_VAL_IQC_CMMB_TST_SIG_CLCHT                                    0
#define RSSFU_VAL_IQC_CMMB_TST_SIG_TONLY                                    1

// rssfu_rngIqcAtsmPackLength
#define RSSFU_VAL_IQC_ATSM_PACK_LEN_INV                                     0
#define RSSFU_VAL_IQC_ATSM_PACK_LEN_P188                                    1
#define RSSFU_VAL_IQC_ATSM_PACK_LEN_P204                                    2
#define RSSFU_VAL_IQC_ATSM_PACK_LEN_P208                                    3

// rssfu_rngIqcAtsmTestSig
#define RSSFU_VAL_IQC_ATSM_TEST_TTSP                                        0
#define RSSFU_VAL_IQC_ATSM_TEST_PBIN                                        1
#define RSSFU_VAL_IQC_ATSM_TEST_PBET                                        2
#define RSSFU_VAL_IQC_ATSM_TEST_PBEM                                        3

// rssfu_rngIqcAtsmBury
#define RSSFU_VAL_IQC_ATSM_BURY_39DB                                        0
#define RSSFU_VAL_IQC_ATSM_BURY_36DB                                        1
#define RSSFU_VAL_IQC_ATSM_BURY_33DB                                        2
#define RSSFU_VAL_IQC_ATSM_BURY_30DB                                        3
#define RSSFU_VAL_IQC_ATSM_BURY_27DB                                        4
#define RSSFU_VAL_IQC_ATSM_BURY_24DB                                        5
#define RSSFU_VAL_IQC_ATSM_BURY_21DB                                        6

// rssfu_rngTsgenStopData
#define RSSFU_VAL_TSGEN_STOP_DATA_NONE                                      0
#define RSSFU_VAL_TSGEN_STOP_DATA_TTSP                                      1

// rssfu_rngTsgenTsPacket
#define RSSFU_VAL_TSGEN_TS_PACKET_H184                                      0
#define RSSFU_VAL_TSGEN_TS_PACKET_S187                                      1
#define RSSFU_VAL_TSGEN_TS_PACKET_H200                                      2
#define RSSFU_VAL_TSGEN_TS_PACKET_S203                                      3
#define RSSFU_VAL_TSGEN_TS_PACKET_H204                                      4
#define RSSFU_VAL_TSGEN_TS_PACKET_S207                                      5

// rssfu_rngDvbt2L1Version
#define RSSFU_VAL_IQC_DVBT2_L1_VER_V111                                     0
#define RSSFU_VAL_IQC_DVBT2_L1_VER_V121                                     1
#define RSSFU_VAL_IQC_DVBT2_L1_VER_V131                                     2

// rssfu_rngDvbt2MisoGroup
#define RSSFU_VAL_IQC_DVBT2_MISO_G1                                         0
#define RSSFU_VAL_IQC_DVBT2_MISO_G2                                         1

// rssfu_rngNetworkMode
#define RSSFU_VAL_IQC_NETWORK_MFN                                           0
#define RSSFU_VAL_IQC_NETWORK_SFN                                           1

// rssfu_rngDvbt2PlpModulType
#define RSSFU_VAL_DVBT2_PLP_MODUL_TYPE_CCM                                  0
#define RSSFU_VAL_DVBT2_PLP_MODUL_TYPE_ACM                                  1

// rssfu_rngDvbt2IssyMode
#define RSSFU_VAL_DVBT2_MODEISSY_OFF                                        0
#define RSSFU_VAL_DVBT2_MODEISSY_SHORT                                      1
#define RSSFU_VAL_DVBT2_MODEISSY_LONG                                       2

// rssfu_rngMfloIfftMode
#define RSSFU_VAL_MFLO_IFFT_M1K                                             0
#define RSSFU_VAL_MFLO_IFFT_M2K                                             1
#define RSSFU_VAL_MFLO_IFFT_M4K                                             2
#define RSSFU_VAL_MFLO_IFFT_M8K                                             3

// rssfu_rngMfloStimMap
#define RSSFU_VAL_MFLO_STIM_MAP_1                                           0
#define RSSFU_VAL_MFLO_STIM_MAP_2                                           1
#define RSSFU_VAL_MFLO_STIM_MAP_3                                           2

// rssfu_rngMfloCPLength
#define RSSFU_VAL_MFLO_CPR_LENGTH_G1_16                                     0
#define RSSFU_VAL_MFLO_CPR_LENGTH_G1_8                                      1
#define RSSFU_VAL_MFLO_CPR_LENGTH_G3_16                                     2
#define RSSFU_VAL_MFLO_CPR_LENGTH_G1_4                                      3

// rssfu_rngDmbthGuardInt
#define RSSFU_IQC_DMBTH_GUAR_G420                                           0
#define RSSFU_IQC_DMBTH_GUAR_G595                                           1
#define RSSFU_IQC_DMBTH_GUAR_G945                                           2

// rssfu_rngDvbc2InpFormat
#define RSSFU_VAL_DVBC2_INPUT_FORMAT_TS                                     0

// rssfu_rngDvbc2PlpType
#define RSSFU_VAL_DVBC2_PLP_TYPE_NORMAL                                     0
#define RSSFU_VAL_DVBC2_PLP_TYPE_COMMON                                     1
#define RSSFU_VAL_DVBC2_PLP_TYPE_GROUPED                                    2

// rssfu_rngDvbc2BbMode
#define RSSFU_VAL_DVBC2_BB_MODE_HEM                                         0
#define RSSFU_VAL_DVBC2_BB_MODE_NM                                          1

// rssfu_rngDvbc2IssyMode
#define RSSFU_VAL_DVBC2_MODE_ISSY_OFF                                       0
#define RSSFU_VAL_DVBC2_MODE_ISSY_SHORT                                     1
#define RSSFU_VAL_DVBC2_MODE_ISSY_LONG                                      2

// rssfu_rngDvbc2BicmFec
#define RSSFU_VAL_DVBC2_BICM_FEC_NORMAL                                     0
#define RSSFU_VAL_DVBC2_BICM_FEC_SHORT                                      1

// rssfu_rngDvbc2CodeRate
#define RSSFU_VAL_IQC_DVBC2_CRATE_R2_3                                      0
#define RSSFU_VAL_IQC_DVBC2_CRATE_R3_4                                      1
#define RSSFU_VAL_IQC_DVBC2_CRATE_R4_5                                      2
#define RSSFU_VAL_IQC_DVBC2_CRATE_R5_6                                      3
#define RSSFU_VAL_IQC_DVBC2_CRATE_R8_9                                      4
#define RSSFU_VAL_IQC_DVBC2_CRATE_R9_10                                     5

// rssfu_rngDvbc2Constell
#define RSSFU_VAL_IQC_DVBC2_CONSTEL_Q16                                     0
#define RSSFU_VAL_IQC_DVBC2_CONSTEL_Q64                                     1
#define RSSFU_VAL_IQC_DVBC2_CONSTEL_Q256                                    2
#define RSSFU_VAL_IQC_DVBC2_CONSTEL_Q1024                                   3
#define RSSFU_VAL_IQC_DVBC2_CONSTEL_Q4096                                   4

// rssfu_rngDvbc2DslTIDepth
#define RSSFU_VAL_IQC_DVBC2_DSLICE_TI_DEPTH_0                               0
#define RSSFU_VAL_IQC_DVBC2_DSLICE_TI_DEPTH_4                               1
#define RSSFU_VAL_IQC_DVBC2_DSLICE_TI_DEPTH_8                               2
#define RSSFU_VAL_IQC_DVBC2_DSLICE_TI_DEPTH_16                              3

// rssfu_rngDvbc2DslType
#define RSSFU_VAL_IQC_DVBC2_DSLICE_TYPE_1                                   0
#define RSSFU_VAL_IQC_DVBC2_DSLICE_TYPE_2                                   1

// rssfu_rngDvbc2DslFecHeaderType
#define RSSFU_VAL_IQC_DVBC2_DSLICE_FEC_HEADER_ROBUST                        0
#define RSSFU_VAL_IQC_DVBC2_DSLICE_FEC_HEADER_HEM                           1

// rssfu_rngDvbc2ChBWidth
#define RSSFU_VAL_IQC_DVBC2_CHANNEL_BW_6                                    0
#define RSSFU_VAL_IQC_DVBC2_CHANNEL_BW_8                                    1

// rssfu_rngDvbc2GuardInt
#define RSSFU_VAL_IQC_DVBC2_GUARD_1_64                                      0
#define RSSFU_VAL_IQC_DVBC2_GUARD_1_128                                     1

// rssfu_rngDvbc2SystemInterleaver
#define RSSFU_VAL_IQC_DVBC2_SYSTEM_INTERLEAVER_OFF                          0
#define RSSFU_VAL_IQC_DVBC2_SYSTEM_INTERLEAVER_BEST                         1
#define RSSFU_VAL_IQC_DVBC2_SYSTEM_INTERLEAVER_FOUR                         2
#define RSSFU_VAL_IQC_DVBC2_SYSTEM_INTERLEAVER_EIGHT                        3

// rssfu_rngIqcIsdbtChanBw
#define RSSFU_VAL_ISDBT_CHAN_BW6                                            0
#define RSSFU_VAL_ISDBT_CHAN_BW7                                            1
#define RSSFU_VAL_ISDBT_CHAN_BW8                                            2

// rssfu_rngCodingControl
#define RSSFU_VAL_IQC_CONTROL_MODE_AUTO                                     0
#define RSSFU_VAL_IQC_CONTROL_MODE_MANUAL                                   1

// rssfu_rngISDBTmmSuperSegmentsType
#define RSSFU_VAL_TMM_SUPER_SEGMENT_A                                       0
#define RSSFU_VAL_TMM_SUPER_SEGMENT_B                                       1

// rssfu_rngISDBTmmCodingISDBTMode
#define RSSFU_VAL_TMM_ISDBT_MODE_1                                          0
#define RSSFU_VAL_TMM_ISDBT_MODE_2                                          1
#define RSSFU_VAL_TMM_ISDBT_MODE_3                                          2

// rssfu_rngDVBT2SFNTimeStampMode
#define RSSFU_VAL_DVBT2_SFN_TIMESTAMP_MODE_REL                              0
#define RSSFU_VAL_DVBT2_SFN_TIMESTAMP_MODE_ABS                              1

// rssfu_rngDVBT2T2SystemFutureExtensionFramesPayload
#define RSSFU_VAL_IQC_DVBT2_FEF_PAYLOAD_NULL                                0
#define RSSFU_VAL_IQC_DVBT2_FEF_PAYLOAD_NOISE                               1

// rssfu_rngDVBT2T2SystemProfileMode
#define RSSFU_VAL_IQC_DVBT2_PROFILE_SINGLE                                  0
#define RSSFU_VAL_IQC_DVBT2_PROFILE_MULTI                                   1

// rssfu_rngDVBC2FramingBasebandFilter
#define RSSFU_VAL_IQC_DVBC2_BB_FILTER_FIR                                   0
#define RSSFU_VAL_IQC_DVBC2_BB_FILTER_G1_4                                  1
#define RSSFU_VAL_IQC_DVBC2_BB_FILTER_G1_2                                  2
#define RSSFU_VAL_IQC_DVBC2_BB_FILTER_G3_4                                  3
#define RSSFU_VAL_IQC_DVBC2_BB_FILTER_G1_1                                  4

// rssfu_rngDVBC2NotchType
#define RSSFU_VAL_DVBC2_NOTCT_TYPE_NARROW                                   0
#define RSSFU_VAL_DVBC2_NOTCT_TYPE_BROAD                                    1

// rssfu_rngIqcStuffingSFC
#define RSSFU_IQC_SFC_STUF_OFF                                              0
#define RSSFU_IQC_SFC_STUF_ON                                               1

// rssfu_rngBTCInputSignalSource
#define RSSFU_VAL_DTV_SIGNAL_SOURCE_EXTERNAL                                0
#define RSSFU_VAL_DTV_SIGNAL_SOURCE_MMGEN                                   1
#define RSSFU_VAL_DTV_SIGNAL_SOURCE_TEST                                    2

// rssfu_rngBTCInputSignalInput
#define RSSFU_IQC_INPUT_TS1                                                 0
#define RSSFU_IQC_INPUT_TS2                                                 1
#define RSSFU_IQC_INPUT_TS3                                                 2
#define RSSFU_IQC_INPUT_IP                                                  3

// rssfu_rngBERInputBTC
#define RSSFU_VAL_BER_INPUT_SERIAL                                          0
#define RSSFU_VAL_BER_INPUT_TS1                                             1
#define RSSFU_VAL_BER_INPUT_TS2                                             2
#define RSSFU_VAL_BER_INPUT_TS3A                                            3
#define RSSFU_VAL_BER_INPUT_TS3B                                            4
#define RSSFU_VAL_BER_INPUT_IPA                                             5
#define RSSFU_VAL_BER_INPUT_IPB                                             6

// rssfu_rngTxModulationModulatorLevelBTC
#define RSSFU_VAL_IQ_GAIN_DBM4                                              0
#define RSSFU_VAL_IQ_GAIN_DBM2                                              1
#define RSSFU_VAL_IQ_GAIN_DB0                                               2
#define RSSFU_VAL_IQ_GAIN_DB2                                               3
#define RSSFU_VAL_IQ_GAIN_DB4                                               4
#define RSSFU_VAL_IQ_GAIN_DB6                                               5
#define RSSFU_VAL_IQ_GAIN_DB8                                               6

// rssfu_rngAudioBCInputSourceBTC
#define RSSFU_VAL_AUDIO_BC_INPUT_AUDIO_GENERATOR                            0
#define RSSFU_VAL_AUDIO_BC_INPUT_AUDIO_PLAYER                               1

// rssfu_rngMMGeneratorPlayerOutputPacketLength
#define RSSFU_VAL_MM_GENERATOR_PLENGTH_188                                  0
#define RSSFU_VAL_MM_GENERATOR_PLENGTH_204                                  1
#define RSSFU_VAL_MM_GENERATOR_PLENGTH_208                                  2

// rssfu_rngMMGeneratorPlayerOutputMode
#define RSSFU_VAL_MM_GEN_MODE_BURST                                         0
#define RSSFU_VAL_MM_GEN_MODE_CONT                                          1

// rssfu_rngDVBSCodingRollOffBTC
#define RSSFU_VAL_BTC_DVBS_ROLL_OFF_0_05                                    0
#define RSSFU_VAL_BTC_DVBS_ROLL_OFF_0_10                                    1
#define RSSFU_VAL_BTC_DVBS_ROLL_OFF_0_15                                    2
#define RSSFU_VAL_BTC_DVBS_ROLL_OFF_0_20                                    3
#define RSSFU_VAL_BTC_DVBS_ROLL_OFF_0_25                                    4
#define RSSFU_VAL_BTC_DVBS_ROLL_OFF_0_35                                    5
/* END GENERATE */



/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSSFU_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSSFU_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSSFU_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSSFU_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *------------------------ Attribute Value Defines -------------------------*
 ****************************************************************************/

    /*- Instrument specific attribute value definitions --------------------*/

#define RSSFU_SWEEP_START       0
#define RSSFU_SWEEP_CENTER      1

#define RSSFU_SWEEP_ACT_TRIGGER     0
#define RSSFU_SWEEP_ACT_RESET       1
#define RSSFU_SWEEP_ACT_SET_FREQ    2

#define RSSFU_VAL_PRIORITY_HIGH     0
#define RSSFU_VAL_PRIORITY_LOW      1
#define RSSFU_VAL_PRIORITY_NONE     2

#define RSSFU_VAL_REQ_SOURCE_DRATE  0    
#define RSSFU_VAL_PACKET_LENGTH     0
#define RSSFU_VAL_MAX_USEFUL_DRATE  1
#define RSSFU_VAL_MEAS_USEFUL_DRATE 2
#define RSSFU_VAL_MEAS_DRATE        2
#define RSSFU_VAL_USEFUL_DRATE      3
#define RSSFU_VAL_REQUIRED_SOURCE_DRATE 4

#define RSSFU_VAL_FADING_PATH_LOSS     0
#define RSSFU_VAL_FADING_BASIC_DELAY   1
#define RSSFU_VAL_FADING_ADD_DELAY     2
#define RSSFU_VAL_FADING_POWER_RATIO   3
#define RSSFU_VAL_FADING_CONST_PHASE   4
#define RSSFU_VAL_FADING_SPEED         5
#define RSSFU_VAL_FADING_FREQ_RATIO    6
#define RSSFU_VAL_FADING_RES_COEFF     7
#define RSSFU_VAL_FADING_RES_PHASE     8
#define RSSFU_VAL_FADING_RES_LOC_CONST 9
#define RSSFU_VAL_FADING_RES_STD_DEV   10

#define RSSFU_VAL_FADING_CORR_PATH       0
#define RSSFU_VAL_FADING_LOGNORMAL_STATE 1

#define RSSFU_VAL_FADING_RES_MAX_DELAY  0
#define RSSFU_VAL_FADING_RES_DELAY      0
#define RSSFU_VAL_FADING_RES_DOPP_SHIFT 1

#define RSSFU_VAL_BER_BER               0
#define RSSFU_VAL_BER_EVAL              1
#define RSSFU_VAL_BER_STATE             2
#define RSSFU_VAL_BER_ERROR_COUNT       3
#define RSSFU_VAL_BER_GATING_TIME       4
#define RSSFU_VAL_BER_ALL               5

#define RSSFU_VAL_CAL_ALL               0
#define RSSFU_VAL_CAL_SYNTHESIS         1
#define RSSFU_VAL_CAL_LEVEL             2
#define RSSFU_VAL_CAL_VML               3
#define RSSFU_VAL_CAL_VMF               4

#define RSSFU_VAL_BER_STOP              0
#define RSSFU_VAL_BER_START             1
#define RSSFU_VAL_BER_RESTART           2

#define RSSFU_VAL_SIGN_TIMESTAMP        0
#define RSSFU_VAL_MAX_DELAY             1
#define RSSFU_VAL_LOC_DELAY             2
#define RSSFU_VAL_ADD_DELAY             3
#define RSSFU_VAL_SFN_DISTRIB_DELAY     4
#define RSSFU_VAL_SFN_ADJUST_DELAY      5
#define RSSFU_VAL_SFN_FREQ_OFFSET       6
#define RSSFU_VAL_SFN_TX_POWER          7

#define RSSFU_VAL_TDMB_NUM_STREAMS      0
#define RSSFU_VAL_TDMB_MODE_IDENTITY    1

#define RSSFU_VAL_MMEM_COPY             0
#define RSSFU_VAL_MMEM_DELETE           1
#define RSSFU_VAL_MMEM_RENAME           2
#define RSSFU_VAL_MMEM_MDIR             3
#define RSSFU_VAL_MMEM_CDIR             4
#define RSSFU_VAL_MMEM_RDIR             5
#define RSSFU_VAL_MMEM_MSIS             6

#define RSSFU_VAL_MOD_AN_IO_INP_RMS     0
#define RSSFU_VAL_MOD_AN_IO_INP_PEAK    1
#define RSSFU_VAL_MOD_DIG_IO_INP_RMS    2
#define RSSFU_VAL_MOD_DIG_IO_INP_PEAK   3

#define RSSFU_VAL_MFLO_MEAS_DRATE       0
#define RSSFU_VAL_MFLO_MEAS_WID_COND    1
#define RSSFU_VAL_MFLO_MEAS_WID_CTRD    2
#define RSSFU_VAL_MFLO_MEAS_WID_OIS     3
#define RSSFU_VAL_MFLO_MEAS_LID_COND    4
#define RSSFU_VAL_MFLO_MEAS_LID_CTRD    5
#define RSSFU_VAL_MFLO_MEAS_LID_OIS     6

#define RSSFU_VAL_MFLO_STATUS_SSF_TIME  0
#define RSSFU_VAL_MFLO_STATUS_PPS_TDM   1

#define RSSFU_VAL_MFLO_STATUS_OUTF_COUNT 0
#define RSSFU_VAL_MFLO_STATUS_SEER_COUNT 1
#define RSSFU_VAL_MFLO_STATUS_SCER_COUNT 2

#define RSSFU_VAL_IQC_MFLO_WIDE_PID     0
#define RSSFU_VAL_IQC_MFLO_LOCAL_PID    1

#define RSSFU_VAL_MFLO_LOCAL_AREA_LENGTH 1

#define RSSFU_VAL_MMEM_CATALOG_FILES    0
#define RSSFU_VAL_MMEM_CATALOG_SUBDIR   1


#define RSSFU_VAL_IQC_ISDBT_LAYER_A     0
#define RSSFU_VAL_IQC_ISDBT_LAYER_B     1
#define RSSFU_VAL_IQC_ISDBT_LAYER_C     2

#define RSSFU_VAL_ATV_SOUND_FREQ_DEV_MONO    0
#define RSSFU_VAL_ATV_SOUND_FREQ_DEV_SUBCAR1 1
#define RSSFU_VAL_ATV_SOUND_FREQ_DEV_SUBCAR2 2
#define RSSFU_VAL_ATV_SOUND_FREQ_DEV_PILOT   3

#define RSSFU_VAL_ATV_SOUND_SPEC_SUBCAR_MONO  0
#define RSSFU_VAL_ATV_SOUND_SPEC_SUBCAR1      1
#define RSSFU_VAL_ATV_SOUND_SPEC_SUBCAR2      2

#define RSSFU_VAL_ATV_AUDIO_SOUND_FREQ_MONO     0
#define RSSFU_VAL_ATV_AUDIO_SOUND_FREQ_LEFT     1
#define RSSFU_VAL_ATV_AUDIO_SOUND_FREQ_RIGHT    2
#define RSSFU_VAL_ATV_AUDIO_SOUND_FREQ_CH1      3
#define RSSFU_VAL_ATV_AUDIO_SOUND_FREQ_CH2      4

#define RSSFU_VAL_ATV_AUDIO_SOUND_LEVEL_MONO    0
#define RSSFU_VAL_ATV_AUDIO_SOUND_LEVEL_LEFT    1
#define RSSFU_VAL_ATV_AUDIO_SOUND_LEVEL_RIGHT   2
#define RSSFU_VAL_ATV_AUDIO_SOUND_LEVEL_CH1     3
#define RSSFU_VAL_ATV_AUDIO_SOUND_LEVEL_CH2     4

#define RSSFU_VAL_FADING_P2DYN_REF_PATH         0
#define RSSFU_VAL_FADING_P2DYN_MOVING_PATH      1

#define RSSFU_ARB_VAL_TRIGGER_ARM               0
#define RSSFU_ARB_VAL_TRIGGGER_EXECUTE          1

#define RSSFU_VAL_FREQ_CHAN_TAB_SELECT          0
#define RSSFU_VAL_FREQ_CHAN_TAB_STORE           1
#define RSSFU_VAL_FREQ_CHAN_TAB_DELETE          2

#define RSSFU_VAL_PHASE_NOISE_1E2               0
#define RSSFU_VAL_PHASE_NOISE_1E3               1
#define RSSFU_VAL_PHASE_NOISE_1E4               2
#define RSSFU_VAL_PHASE_NOISE_1E5               3
#define RSSFU_VAL_PHASE_NOISE_1E6               4

#define RSSFU_VAL_PRESET_STAT_REG               0
#define RSSFU_VAL_QUEST_STAT_REG                1
#define RSSFU_VAL_OPER_STAT_REG                 2

#define RSSFU_VAL_REG_CONDITION                 0
#define RSSFU_VAL_REG_EVENT                     1
#define RSSFU_VAL_REG_ENABLE                    2
#define RSSFU_VAL_REG_PTRANSITION               3
#define RSSFU_VAL_REG_NTRANSITION               4

#define RSSFU_VAL_ARB_WF_TAG_TYPE               0
#define RSSFU_VAL_ARB_WF_TAG_CRESTFACTOR        1       
#define RSSFU_VAL_ARB_WF_TAG_LEVEL_OFFS         2
#define RSSFU_VAL_ARB_WF_TAG_CLOCK              3
#define RSSFU_VAL_ARB_WF_TAG_SAMPLES            4   
#define RSSFU_VAL_ARB_WF_TAG_IQ_SWAP            5
#define RSSFU_VAL_ARB_WF_TAG_DATE               6
#define RSSFU_VAL_ARB_WF_TAG_COMMENT            7

#define RSSFU_VAL_ATV_AUDIO_GEN_AF1             0
#define RSSFU_VAL_ATV_AUDIO_GEN_AF2             1

#define RSSFU_VAL_SAVE                          0
#define RSSFU_VAL_RECALL                        1
#define RSSFU_VAL_DELETE                        2

#define RSSFU_VAL_MOD_IQ_INPUT_AN               0
#define RSSFU_VAL_MOD_IQ_INPUT_DIG              1


#define RSSFU_VAL_AUDIO_BC_SOUR_LEFT            0
#define RSSFU_VAL_AUDIO_BC_SOUR_RIGHT           1
#define RSSFU_VAL_AUDIO_BC_SOUR_MPX             2

#define RSSFU_VAL_AUDIO_FREQ_DEV_AUDIO          0
#define RSSFU_VAL_AUDIO_FREQ_DEV_MPX            1

#define RSSFU_VAL_IQC_CMMB_RS_0   0
#define RSSFU_VAL_IQC_CMMB_RS_1   1
#define RSSFU_VAL_IQC_CMMB_RS_2   2
#define RSSFU_VAL_IQC_CMMB_RS_3   3
    
#define RSSFU_VAL_IQC_CMMB_LDPC_R1_2  0
#define RSSFU_VAL_IQC_CMMB_LDPC_R3_4  1

#define RSSFU_VAL_IQC_CMMB_CONST_C2  0
#define RSSFU_VAL_IQC_CMMB_CONST_C4  1
#define RSSFU_VAL_IQC_CMMB_CONST_C16 2

#define RSSFU_VAL_AUDIO_BC_OF_GROUP_A   0
#define RSSFU_VAL_AUDIO_BC_OF_GROUP_B   1

#define RSSFU_VAL_DVBC2_DSLICE_START_REL    0
#define RSSFU_VAL_DVBC2_DSLICE_STOP_REL     1
#define RSSFU_VAL_DVBC2_DSLICE_WIDTH        2
#define RSSFU_VAL_DVBC2_DSLICE_START_ABS    3
#define RSSFU_VAL_DVBC2_DSLICE_TUNE_POS_ABS 4
#define RSSFU_VAL_DVBC2_DSLICE_STOP_ABS     5
#define RSSFU_VAL_DVBC2_DSLICE_TUNE_POS_REL 6   

#define RSSFU_VAL_DVBC2_DSLICE_TUNE_FREQ     0
#define RSSFU_VAL_DVBC2_DSLICE_START_FREQ    1
#define RSSFU_VAL_DVBC2_DSLICE_STOP_FREQ     2

#define RSSFU_VAL_DVBC2_NOTCH_START_REL    0
#define RSSFU_VAL_DVBC2_NOTCH_STOP_REL     1
#define RSSFU_VAL_DVBC2_NOTCH_WIDTH        2
#define RSSFU_VAL_DVBC2_NOTCH_START_ABS    3
#define RSSFU_VAL_DVBC2_NOTCH_STOP_ABS     4

#define RSSFU_VAL_DVBC2_NOTCH_START_FREQ   0
#define RSSFU_VAL_DVBC2_NOTCH_STOP_FREQ    1

#define RSSFU_VAL_DVBT2_SFN_MAX_DEVIATION_TIME  0
#define RSSFU_VAL_DVBT2_SFN_STATIC_DELAY        1
#define RSSFU_VAL_DVBT2_SFN_DYNAMIC_DELAY       2
#define RSSFU_VAL_DVBT2_SFN_TOTAL_DELAY         3
#define RSSFU_VAL_DVBT2_SFN_PROCESS_DELAY       4

#define RSSFU_VAL_IQC_ISDBT_LAYER_A_A           0
#define RSSFU_VAL_IQC_ISDBT_LAYER_A_B           1
#define RSSFU_VAL_IQC_ISDBT_LAYER_A_C           2
#define RSSFU_VAL_IQC_ISDBT_LAYER_B_1           3
#define RSSFU_VAL_IQC_ISDBT_LAYER_B_2           4
#define RSSFU_VAL_IQC_ISDBT_LAYER_B_3           5
#define RSSFU_VAL_IQC_ISDBT_LAYER_B_4           6
#define RSSFU_VAL_IQC_ISDBT_LAYER_B_5           7
#define RSSFU_VAL_IQC_ISDBT_LAYER_B_6           8
#define RSSFU_VAL_IQC_ISDBT_LAYER_B_7           9

#define RSSFU_VAL_IQC_TMM_RECEPTION_CODER_A1    0
#define RSSFU_VAL_IQC_TMM_RECEPTION_CODER_A2    1

#define RSSFU_VAL_IQC_ISDBTMM_LAYER_A1A         0
#define RSSFU_VAL_IQC_ISDBTMM_LAYER_A1B         1
#define RSSFU_VAL_IQC_ISDBTMM_LAYER_A1C         2
#define RSSFU_VAL_IQC_ISDBTMM_LAYER_A2A         3
#define RSSFU_VAL_IQC_ISDBTMM_LAYER_A2B         4
#define RSSFU_VAL_IQC_ISDBTMM_LAYER_A2C         5
#define RSSFU_VAL_IQC_ISDBTMM_LAYER_B1          6
#define RSSFU_VAL_IQC_ISDBTMM_LAYER_B2          7
#define RSSFU_VAL_IQC_ISDBTMM_LAYER_B3          8
#define RSSFU_VAL_IQC_ISDBTMM_LAYER_B4          9
#define RSSFU_VAL_IQC_ISDBTMM_LAYER_B5          10
#define RSSFU_VAL_IQC_ISDBTMM_LAYER_B6          11
#define RSSFU_VAL_IQC_ISDBTMM_LAYER_B7          12


/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
ViStatus _VI_FUNC rssfu_init (ViRsrc resourceName, ViBoolean IDQuery,
                              ViBoolean resetDevice, ViPSession instrumentHandle);
ViStatus _VI_FUNC rssfu_InitWithOptions (ViRsrc resourceName, ViBoolean IDQuery,
                                         ViBoolean resetDevice,
                                         ViString optionString,
                                         ViPSession instrumentHandle);
ViStatus _VI_FUNC rssfu_confTxFreq (ViSession instrumentHandle, ViReal64 frequency,
                                    ViReal64 frequencyOffset);
ViStatus _VI_FUNC rssfu_SetTxActualCenterFrequency (ViSession instrumentHandle,
                                                    ViReal64 RFOutputFrequency);
ViStatus _VI_FUNC rssfu_SetTxFrequencyChannel (ViSession instrumentHandle,
                                               ViInt32 frequencyChannel);
ViStatus _VI_FUNC rssfu_FrequencyChannelTableOperations (ViSession instrumentHandle,
                                                         ViInt32 operation,
                                                         ViString channelName);
ViStatus _VI_FUNC rssfu_ConfigureChannelTableFrequency (ViSession instrumentHandle,
                                                        ViInt32 channel,
                                                        ViString channelName,
                                                        ViReal64 channelFrequency);
ViStatus _VI_FUNC rssfu_SetFrequencyVSBReferencePoint (ViSession instrumentHandle,
                                                       ViInt32 frequencyReferencePoint);
ViStatus _VI_FUNC rssfu_readTxFreq (ViSession instrumentHandle,
                                    ViPReal64 TXFrequency);
ViStatus _VI_FUNC rssfu_readPeakEnvelopePower (ViSession instrumentHandle,
                                               ViPReal64 peakEnvelopePower);
ViStatus _VI_FUNC rssfu_actEnableFrequencySweep (ViSession instrumentHandle,
                                                 ViBoolean state);
ViStatus _VI_FUNC rssfu_confTxFreqSweepRange (ViSession instrumentHandle,
                                              ViInt32 settingType,
                                              ViReal64 startFrequency,
                                              ViReal64 stopFrequency,
                                              ViReal64 centerFrequency,
                                              ViReal64 frequencySpan);
ViStatus _VI_FUNC rssfu_confTxFreqSweepStep (ViSession instrumentHandle,
                                             ViInt32 sweepSpacing,
                                             ViReal64 sweepStep,
                                             ViReal64 sweepDwell);
ViStatus _VI_FUNC rssfu_confTxFreqSweepMode (ViSession instrumentHandle,
                                             ViInt32 sweepMode);
ViStatus _VI_FUNC rssfu_actTxFreqSweep (ViSession instrumentHandle,
                                        ViInt32 actionType,
                                        ViReal64 manualSweepFrequency);
ViStatus _VI_FUNC rssfu_confTxLevel (ViSession instrumentHandle, ViReal64 level,
                                     ViBoolean RF, ViReal64 offset,
                                     ViReal64 userLimit, ViInt32 attenuatorMode,
                                     ViInt32 levelUnit);
ViStatus _VI_FUNC rssfu_readTxLevel (ViSession instrumentHandle, ViPReal64 TXLevel);
ViStatus _VI_FUNC rssfu_getTxAttFixedRange (ViSession instrumentHandle,
                                            ViPReal64 lower, ViPReal64 upper);
ViStatus _VI_FUNC rssfu_txRfOutputProtectionTripped (ViSession instrumentHandle,
                                                     ViPBoolean tripped);
ViStatus _VI_FUNC rssfu_actTxRfOutputClear (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfu_confTxALC (ViSession instrumentHandle, ViInt32 state,
                                   ViInt32 ALCOFFMode);
ViStatus _VI_FUNC rssfu_actTxALCSearchOnce (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfu_confTxModulation (ViSession instrumentHandle,
                                          ViBoolean modulation,
                                          ViInt32 signalSource,
                                          ViInt32 transmissionStandard,
                                          ViInt32 spectrum);
ViStatus _VI_FUNC rssfu_confAtvTransStandard (ViSession instrumentHandle,
                                              ViInt32 ATVTransmissionStandard);
ViStatus _VI_FUNC rssfu_confTxModulationInterferer (ViSession instrumentHandle,
                                                    ViInt32 interfererSource,
                                                    ViReal64 interfererAttenuation,
                                                    ViInt32 interfererAddition,
                                                    ViReal64 interfererFrequencyOffset,
                                                    ViReal64 signalFrequencyOffset);
ViStatus _VI_FUNC rssfu_confTxModulationInterfererSignal (ViSession instrumentHandle,
                                                          ViInt32 interfererReference,
                                                          ViReal64 interfererLevel);
ViStatus _VI_FUNC rssfu_confTxModInterfAtvPredefStd (ViSession instrumentHandle,
                                                     ViInt32 ATVPredefinedStandard);
ViStatus _VI_FUNC rssfu_confTxModulationSettings (ViSession instrumentHandle,
                                                  ViReal64 iQWidebandInCrestFactor,
                                                  ViBoolean iQWidebandRFFiltering,
                                                  ViInt32 iQDigitalInMode,
                                                  ViInt32 iQDigitalOutMode);
ViStatus _VI_FUNC rssfu_confTxModulatorLevel (ViSession instrumentHandle,
                                              ViInt32 modulatorLevel);
ViStatus _VI_FUNC rssfu_readModulationSigInfoStat (ViSession instrumentHandle,
                                                   ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfu_confTxModIqInputRefresh (ViSession instrumentHandle,
                                                 ViInt32 refresh);
ViStatus _VI_FUNC rssfu_audioTransmissionStandard (ViSession instrumentHandle,
                                                   ViInt32 transmissionStandard);
ViStatus _VI_FUNC rssfu_readDiditalIqSymbolRate (ViSession instrumentHandle,
                                                 ViPReal64 IQSymbolRate);
ViStatus _VI_FUNC rssfu_readDVBTCoderStatus (ViSession instrumentHandle,
                                             ViInt32 priorityPath,
                                             ViChar _VI_FAR status[]);
ViStatus _VI_FUNC rssfu_confDVBTInputSignal (ViSession instrumentHandle,
                                             ViInt32 priorityPath, ViInt32 source,
                                             ViInt32 input, ViInt32 stuffing);
ViStatus _VI_FUNC rssfu_confDVBTTestSignal (ViSession instrumentHandle,
                                            ViInt32 priorityPath,
                                            ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_readDVBTValues (ViSession instrumentHandle,
                                        ViInt32 priorityPath, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfu_confDVBTCoding (ViSession instrumentHandle,
                                        ViInt32 channelBandwidth,
                                        ViReal64 usedBandwidth, ViInt32 FFTMode,
                                        ViInt32 guardInterval, ViInt32 hierarchy,
                                        ViInt32 constellation);
ViStatus _VI_FUNC rssfu_confDVBTCodeRate (ViSession instrumentHandle,
                                          ViInt32 priorityPath, ViInt32 codeRate);
ViStatus _VI_FUNC rssfu_confDVBHCoding (ViSession instrumentHandle, ViBoolean state,
                                        ViInt32 symbolInterleaverMode);
ViStatus _VI_FUNC rssfu_actEnableDVBTSpecial (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rssfu_confDVBTSpecial (ViSession instrumentHandle,
                                         ViInt32 priorityPath, ViBoolean scrambler,
                                         ViBoolean syncByteInversion,
                                         ViBoolean reedSolomon,
                                         ViBoolean convolutionalInterleaver);
ViStatus _VI_FUNC rssfu_confDVBTSpecialInterleaver (ViSession instrumentHandle,
                                                    ViBoolean bitInterleaver,
                                                    ViBoolean symbolInterleaver,
                                                    ViBoolean guardInsertion);
ViStatus _VI_FUNC rssfu_confDVBTSpecialCarriers (ViSession instrumentHandle,
                                                 ViBoolean modulationDataCarrier,
                                                 ViBoolean modulationPilotCarrier,
                                                 ViBoolean modulationTPSCarrier,
                                                 ViBoolean dataCarrier,
                                                 ViBoolean pilotCarrier,
                                                 ViBoolean TPSCarrier,
                                                 ViBoolean allCarriersEqualCW,
                                                 ViString disableCarriers);
ViStatus _VI_FUNC rssfu_storeLoadDVBTCarriers (ViSession instrumentHandle,
                                               ViInt32 operation, ViString source);
ViStatus _VI_FUNC rssfu_confDVBTPacketsPayload (ViSession instrumentHandle,
                                                ViInt32 testTSPacket,
                                                ViInt32 PIDTestPacket, ViInt32 PID,
                                                ViInt32 payloadTestStuff,
                                                ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_confDVBTTPS (ViSession instrumentHandle, ViInt32 TPSCellID,
                                     ViBoolean TPSResevedState,
                                     ViInt32 TPSReservedValue);
ViStatus _VI_FUNC rssfu_confDVBTTimeMPE (ViSession instrumentHandle,
                                         ViInt32 priorityPath,
                                         ViBoolean timeSlicing, ViBoolean MPEFEC);
ViStatus _VI_FUNC rssfu_readDVBCCoderStatus (ViSession instrumentHandle,
                                             ViChar _VI_FAR status[]);
ViStatus _VI_FUNC rssfu_confDVBCInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input,
                                             ViInt32 stuffing);
ViStatus _VI_FUNC rssfu_confDVBCTestSignal (ViSession instrumentHandle,
                                            ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_readDVBCValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfu_confDVBCCoding (ViSession instrumentHandle,
                                        ViReal64 symbolRate, ViInt32 constellation,
                                        ViInt32 rollOff);
ViStatus _VI_FUNC rssfu_actEnableDVBCSpecial (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rssfu_confDVBCSpecial (ViSession instrumentHandle,
                                         ViBoolean scrambler,
                                         ViBoolean syncByteInversion,
                                         ViBoolean reedSolomon,
                                         ViBoolean convolutionalInterleaver);
ViStatus _VI_FUNC rssfu_confDVBCSettings (ViSession instrumentHandle,
                                          ViInt32 testTSPacket,
                                          ViInt32 PIDTestPacket, ViInt32 PID,
                                          ViInt32 payloadTestStuff, ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_readDVBSCoderStatus (ViSession instrumentHandle,
                                             ViChar _VI_FAR status[]);
ViStatus _VI_FUNC rssfu_confDVBSInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input,
                                             ViInt32 stuffing);
ViStatus _VI_FUNC rssfu_confDVBSTestSignal (ViSession instrumentHandle,
                                            ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_readDVBSValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfu_confDVBSCoding (ViSession instrumentHandle,
                                        ViReal64 symbolRate, ViInt32 constellation,
                                        ViInt32 rollOff, ViInt32 codeRate);
ViStatus _VI_FUNC rssfu_actEnableDVBSSpecial (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rssfu_confDVBSSpecial (ViSession instrumentHandle,
                                         ViBoolean scrambler,
                                         ViBoolean syncByteInversion,
                                         ViBoolean reedSolomon,
                                         ViBoolean convolutionalInterleaver);
ViStatus _VI_FUNC rssfu_confDVBSSettings (ViSession instrumentHandle,
                                          ViInt32 testTSPacket,
                                          ViInt32 PIDTestPacket, ViInt32 PID,
                                          ViInt32 payloadTestStuff, ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_read8VSBCoderStatus (ViSession instrumentHandle,
                                             ViChar _VI_FAR status[]);
ViStatus _VI_FUNC rssfu_conf8VSBInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input,
                                             ViInt32 stuffing);
ViStatus _VI_FUNC rssfu_conf8VSBTestSignal (ViSession instrumentHandle,
                                            ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_read8VSBPackedLength (ViSession instrumentHandle,
                                              ViPInt32 packedLength);
ViStatus _VI_FUNC rssfu_read8VSBValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfu_set8VSBSymbolRate (ViSession instrumentHandle,
                                           ViReal64 symbolRate);
ViStatus _VI_FUNC rssfu_read8VSBConstellation (ViSession instrumentHandle,
                                               ViChar _VI_FAR constellation[]);
ViStatus _VI_FUNC rssfu_read8VSBRollOff (ViSession instrumentHandle,
                                         ViPReal64 rollOff);
ViStatus _VI_FUNC rssfu_actEnable8VSBSpecial (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rssfu_conf8VSBSpecial (ViSession instrumentHandle,
                                         ViBoolean randomizer,
                                         ViBoolean reedSolomon,
                                         ViBoolean interleaver, ViBoolean pilot,
                                         ViReal64 pilotValue);
ViStatus _VI_FUNC rssfu_conf8VSBSettings (ViSession instrumentHandle,
                                          ViInt32 testTSPacket,
                                          ViInt32 PIDTestPacket, ViInt32 PID,
                                          ViInt32 payloadTestStuff, ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_readJ83BCoderStatus (ViSession instrumentHandle,
                                             ViChar _VI_FAR status[]);
ViStatus _VI_FUNC rssfu_confJ83BInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input,
                                             ViInt32 stuffing);
ViStatus _VI_FUNC rssfu_confJ83BTestSignal (ViSession instrumentHandle,
                                            ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_readJ83BPackedLength (ViSession instrumentHandle,
                                              ViPInt32 packedLength);
ViStatus _VI_FUNC rssfu_readJ83BValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfu_confJ83BCoding (ViSession instrumentHandle,
                                        ViReal64 symbolRate, ViInt32 constellation,
                                        ViInt32 interleaver);
ViStatus _VI_FUNC rssfu_readJ83BRollOff (ViSession instrumentHandle,
                                         ViPReal64 rollOff);
ViStatus _VI_FUNC rssfu_actEnableJ83BSpecial (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rssfu_confJ83BSpecial (ViSession instrumentHandle,
                                         ViBoolean checksumgen,
                                         ViBoolean reedSolomon,
                                         ViBoolean interleaver,
                                         ViBoolean randomizer);
ViStatus _VI_FUNC rssfu_confJ83BSettings (ViSession instrumentHandle,
                                          ViInt32 testTSPacket,
                                          ViInt32 PIDTestPacket, ViInt32 PID,
                                          ViInt32 payloadTestStuff, ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_readISDBTCoderStatus (ViSession instrumentHandle,
                                              ViChar _VI_FAR status[]);
ViStatus _VI_FUNC rssfu_confISDBTInputSignal (ViSession instrumentHandle,
                                              ViInt32 layer, ViInt32 source,
                                              ViInt32 input);
ViStatus _VI_FUNC rssfu_ConfigureISDBTInputParameters (ViSession instrumentHandle,
                                                       ViBoolean remux,
                                                       ViBoolean stuffing);
ViStatus _VI_FUNC rssfu_confISDBTTestSignal (ViSession instrumentHandle,
                                             ViInt32 layer, ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_readISDBTInputDataRate (ViSession instrumentHandle,
                                                ViPReal64 inputDataRate);
ViStatus _VI_FUNC rssfu_readISDBTValues (ViSession instrumentHandle, ViInt32 layer,
                                         ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfu_confISDBTSystem (ViSession instrumentHandle,
                                         ViInt32 ISDBTSystem);
ViStatus _VI_FUNC rssfu_ConfigureISDBTCodingControl (ViSession instrumentHandle,
                                                     ViInt32 control);
ViStatus _VI_FUNC rssfu_confISDBTLayerCoding (ViSession instrumentHandle,
                                              ViInt32 portion, ViInt32 layer,
                                              ViInt32 constellation,
                                              ViInt32 codeRate,
                                              ViInt32 timeInterleaving);
ViStatus _VI_FUNC rssfu_confISDBTCoding (ViSession instrumentHandle,
                                         ViInt32 ISDBTMode, ViInt32 guardInterval,
                                         ViInt32 bandwidthVariation);
ViStatus _VI_FUNC rssfu_confISDBTSubChannel (ViSession instrumentHandle,
                                             ViInt32 subChannel);
ViStatus _VI_FUNC rssfu_confISDBTSegments (ViSession instrumentHandle,
                                           ViInt32 layer, ViInt32 segments);
ViStatus _VI_FUNC rssfu_ConfigureISDBTChannelBandwidth (ViSession instrumentHandle,
                                                        ViInt32 channelBandwidth);
ViStatus _VI_FUNC rssfu_readISDBTBandwidth (ViSession instrumentHandle,
                                            ViPReal64 bandwidth);
ViStatus _VI_FUNC rssfu_actEnableISDBTSpecial (ViSession instrumentHandle,
                                               ViBoolean state);
ViStatus _VI_FUNC rssfu_confISDBTSpecial (ViSession instrumentHandle,
                                          ViBoolean scrambler,
                                          ViBoolean reedSolomon,
                                          ViBoolean byteInterleaver,
                                          ViBoolean bitInterleaver,
                                          ViBoolean frequencyInterleaver,
                                          ViBoolean alertBroadcastFlag);
ViStatus _VI_FUNC rssfu_confISDBTSpecialPilotSettings (ViSession instrumentHandle,
                                                       ViBoolean dataCarriers,
                                                       ViBoolean scatteredPilots,
                                                       ViBoolean continualPilots,
                                                       ViBoolean TMCCPilots,
                                                       ViBoolean ACPilots);
ViStatus _VI_FUNC rssfu_confISDBTSpecialPilotModulationSettings
             (ViSession instrumentHandle, ViBoolean modDataCarriers,
              ViBoolean modScatteredPilots, ViBoolean modContinualPilots,
              ViBoolean modTMCCPilots, ViBoolean modACPilots);
ViStatus _VI_FUNC rssfu_confISDBTSpecialSegmentSettings (ViSession instrumentHandle,
                                                         ViInt32 segment,
                                                         ViBoolean state);
ViStatus _VI_FUNC rssfu_confISDBTSpecialAcDataSettings (ViSession instrumentHandle,
                                                        ViInt32 ACData_AC1,
                                                        ViInt32 ACData_AC2);
ViStatus _VI_FUNC rssfu_confISDBTSpecialGuardInsertionSettings
             (ViSession instrumentHandle, ViBoolean guardInsertion);
ViStatus _VI_FUNC rssfu_ConfigureISDBTTmccSpecialSettings
             (ViSession instrumentHandle, ViInt32 TXParamSwitchingIndicator,
              ViInt32 TMCCNext);
ViStatus _VI_FUNC rssfu_confISDBTSettings (ViSession instrumentHandle,
                                           ViInt32 layer, ViInt32 testTSPacket,
                                           ViInt32 PIDTestPacket, ViInt32 PID,
                                           ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_ConfigureISDBTPayloadTestStuff (ViSession instrumentHandle,
                                                        ViInt32 layer,
                                                        ViInt32 payloadTestStuff);
ViStatus _VI_FUNC rssfu_confISDBTmmInputSignal (ViSession instrumentHandle,
                                                ViInt32 layer, ViInt32 source,
                                                ViInt32 input, ViBoolean stuffing);
ViStatus _VI_FUNC rssfu_confISDBTmmTestSignal (ViSession instrumentHandle,
                                               ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_readISDBTmmInputDataRate (ViSession instrumentHandle,
                                                  ViPReal64 inputDataRate);
ViStatus _VI_FUNC rssfu_readISDBTmmValues (ViSession instrumentHandle,
                                           ViInt32 layer, ViInt32 value,
                                           ViPReal64 result);
ViStatus _VI_FUNC rssfu_ConfigureISDBTmmCodingParameters (ViSession instrumentHandle,
                                                            ViInt32 control,
                                                          ViInt32 coder,
                                                            ViBoolean partialReception,
                                                          ViInt32 numberSuperSegments);
ViStatus _VI_FUNC rssfu_ConfigureISDBTmmCodingSegmentParameters
             (ViSession instrumentHandle, ViInt32 superSegments,
              ViInt32 superSegmentsType, ViInt32 numberOFDMSegments);
ViStatus _VI_FUNC rssfu_ConfigureISDBTmmCodingLayerParameters
             (ViSession instrumentHandle, ViInt32 layer,
              ViInt32 OFDMSegments, ViInt32 centerSubchannel, ViInt32 constellation,
              ViInt32 codeRate, ViInt32 timeInterleaving);
ViStatus _VI_FUNC rssfu_ConfigureISDBTmmCoding (ViSession instrumentHandle,
                                                ViBoolean emergencyAlarm,
                                                ViInt32 ISDBTMode,
                                                ViInt32 guardInterval,
                                                ViInt32 referenceChannel);
ViStatus _VI_FUNC rssfu_ReadISDBTmmRFBandwidth (ViSession instrumentHandle,
                                                ViPReal64 bandwidth);
ViStatus _VI_FUNC rssfu_actEnableISDBTmmSpecial (ViSession instrumentHandle,
                                                 ViBoolean state);
ViStatus _VI_FUNC rssfu_confISDBTmmSpecialSettings (ViSession instrumentHandle,
                                                    ViBoolean scrambler,
                                                    ViBoolean reedSolomon,
                                                    ViBoolean byteInterleaver,
                                                    ViBoolean bitInterleaver,
                                                    ViBoolean frequencyInterleaver);
ViStatus _VI_FUNC rssfu_ConfigureISDBTmmTmccSpecialSettings
             (ViSession instrumentHandle, ViInt32 TXParamSwitchingIndicator,
              ViInt32 TMCCNext);
ViStatus _VI_FUNC rssfu_confISDBTmmSettings (ViSession instrumentHandle,
                                             ViInt32 testTSPacket,
                                             ViInt32 PIDTestPacket, ViInt32 PID,
                                             ViInt32 payloadTestStuff,
                                             ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_readDMBTCoderStatus (ViSession instrumentHandle,
                                             ViChar _VI_FAR status[]);
ViStatus _VI_FUNC rssfu_confDMBTInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input,
                                             ViInt32 stuffing);
ViStatus _VI_FUNC rssfu_confDMBTTestSignal (ViSession instrumentHandle,
                                            ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_readDMBTValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfu_confDMBTNetworkMode (ViSession instrumentHandle,
                                             ViInt32 networkMode);
ViStatus _VI_FUNC rssfu_confDMBTControl (ViSession instrumentHandle,
                                         ViInt32 control, ViInt32 channelBandwidth);
ViStatus _VI_FUNC rssfu_confDMBTCoding (ViSession instrumentHandle,
                                        ViInt32 constellation, ViInt32 codeRate,
                                        ViInt32 guardInterval,
                                        ViInt32 timeInterleaver);
ViStatus _VI_FUNC rssfu_readDMBTSFNValues (ViSession instrumentHandle,
                                           ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfu_actEnableDMBTSpecial (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rssfu_confDMBTSpecial (ViSession instrumentHandle,
                                         ViBoolean syncWordRandomized,
                                         ViBoolean randomizer,
                                         ViInt32 randomizerRestart,
                                         ViBoolean byteInterleaver,
                                         ViBoolean pilotData,
                                         ViBoolean GIPowerBoost);
ViStatus _VI_FUNC rssfu_confDMBTSettings (ViSession instrumentHandle,
                                          ViBoolean controlFrames,
                                          ViInt32 testTSPacket,
                                          ViInt32 PIDTestPacket, ViInt32 PID,
                                          ViInt32 payloadTestStuff, ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_readDTMBCoderStatus (ViSession instrumentHandle,
                                             ViChar _VI_FAR status[]);
ViStatus _VI_FUNC rssfu_confDTMBInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input,
                                             ViBoolean stuffing);
ViStatus _VI_FUNC rssfu_confDTMBTestSignal (ViSession instrumentHandle,
                                            ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_readDTMBValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfu_confDTMBNetworkMode (ViSession instrumentHandle,
                                             ViInt32 networkMode,
                                             ViBoolean singleCarrierMode,
                                             ViBoolean controlFrames);
ViStatus _VI_FUNC rssfu_confDTMBDualPilotTone (ViSession instrumentHandle,
                                               ViBoolean dualPilotTone);
ViStatus _VI_FUNC rssfu_confDTMBChannelBandwidth (ViSession instrumentHandle,
                                                  ViInt32 channelBandwidth);
ViStatus _VI_FUNC rssfu_confDTMBCoding (ViSession instrumentHandle,
                                        ViInt32 constellation, ViInt32 codeRate,
                                        ViInt32 guardInterval,
                                        ViInt32 timeInterleaver);

ViStatus _VI_FUNC rssfu_ConfigureDTMBGuardIntervalPN (ViSession instrumentHandle,
                                                      ViInt32 guardIntervalPN);
ViStatus _VI_FUNC rssfu_readDTMBSFNValues (ViSession instrumentHandle,
                                           ViInt32 value, ViPReal64 result);

ViStatus _VI_FUNC rssfu_ConfigureDTMBSFNSettings (ViSession instrumentHandle,
                                                  ViReal64 RFDelay,
                                                  ViReal64 delayOffset,
                                                  ViInt32 TXAddress);
ViStatus _VI_FUNC rssfu_actEnableDTMBSpecial (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rssfu_ConfigureDTMBSpecialSettings (ViSession instrumentHandle,
                                                      ViBoolean GIPowerBoost,
                                                      ViBoolean SIPowerNormalization,
                                                      ViBoolean coChannelInterferer);

ViStatus _VI_FUNC rssfu_confDTMBSettings (ViSession instrumentHandle,
                                          ViInt32 testTSPacket,
                                          ViInt32 PIDTestPacket, ViInt32 PID,
                                          ViInt32 payloadTestStuff, ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_readDVBS2CoderStatus (ViSession instrumentHandle,
                                              ViChar _VI_FAR status[]);
ViStatus _VI_FUNC rssfu_confDVBS2InputSignal (ViSession instrumentHandle,
                                              ViInt32 source, ViInt32 input,
                                              ViInt32 stuffing);
ViStatus _VI_FUNC rssfu_confDVBS2ACMMode (ViSession instrumentHandle,
                                          ViBoolean ACMMode);
ViStatus _VI_FUNC rssfu_confDVBS2TestSignal (ViSession instrumentHandle,
                                             ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_readDVBS2Values (ViSession instrumentHandle, ViInt32 value,
                                         ViPReal64 result);
ViStatus _VI_FUNC rssfu_confDVBS2Coding (ViSession instrumentHandle,
                                         ViReal64 symbolRate, ViInt32 constellation,
                                         ViInt32 rollOff, ViInt32 codeRate,
                                         ViInt32 AMC);
ViStatus _VI_FUNC rssfu_confDVBS2FecFrame (ViSession instrumentHandle,
                                           ViInt32 FECFrame);
ViStatus _VI_FUNC rssfu_confDVBS2Pilots (ViSession instrumentHandle,
                                         ViBoolean pilots);
ViStatus _VI_FUNC rssfu_actEnableDVBS2Special (ViSession instrumentHandle,
                                               ViBoolean state);
ViStatus _VI_FUNC rssfu_confDVBS2Special (ViSession instrumentHandle,
                                          ViInt32 PLScramblingSequenceID,
                                          ViBoolean CWMode);
ViStatus _VI_FUNC rssfu_confDVBS2ErrorInsertion (ViSession instrumentHandle,
                                                 ViBoolean CRC8InHeader,
                                                 ViBoolean CRC8InPayload,
                                                 ViInt32 BCH, ViInt32 LDPCCC);
ViStatus _VI_FUNC rssfu_confDVBS2PhaseNoise (ViSession instrumentHandle,
                                             ViBoolean state, ViInt32 shape,
                                             ViInt32 magnitude);
ViStatus _VI_FUNC rssfu_confDVBS2Settings (ViSession instrumentHandle,
                                           ViInt32 testTSPacket,
                                           ViInt32 PIDTestPacket, ViInt32 PID,
                                           ViInt32 payloadTestStuff, ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_confDirectvInputSignal (ViSession instrumentHandle,
                                                ViInt32 source, ViInt32 input,
                                                ViInt32 stuffing,
                                                ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_readDirectvPackedLength (ViSession instrumentHandle,
                                                 ViPInt32 packedLength);
ViStatus _VI_FUNC rssfu_readDirectvValues (ViSession instrumentHandle,
                                           ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfu_confDirectvCoding (ViSession instrumentHandle,
                                           ViReal64 symbolRate,
                                           ViInt32 constellation, ViInt32 rollOff,
                                           ViInt32 codeRate);
ViStatus _VI_FUNC rssfu_actEnableDirectvSpecial (ViSession instrumentHandle,
                                                 ViBoolean state);
ViStatus _VI_FUNC rssfu_confDirectvSpecial (ViSession instrumentHandle,
                                            ViInt32 insertErrorsAfterConvENC,
                                            ViBoolean CWMode);
ViStatus _VI_FUNC rssfu_confDirectvPhaseNoise (ViSession instrumentHandle,
                                               ViBoolean state, ViInt32 shape,
                                               ViInt32 magnitude);
ViStatus _VI_FUNC rssfu_confDirectvSettings (ViSession instrumentHandle,
                                             ViInt32 testTSPacket, ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_readMfloCoderStatus (ViSession instrumentHandle,
                                             ViChar _VI_FAR status[]);
ViStatus _VI_FUNC rssfu_confMfloInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input);
ViStatus _VI_FUNC rssfu_readMfloMeasDataRate (ViSession instrumentHandle,
                                              ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfu_confMfloDelaySettings (ViSession instrumentHandle,
                                               ViReal64 networkDelay,
                                               ViReal64 transmitterDelay);
ViStatus _VI_FUNC rssfu_actEnableMfloSpecial (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rssfu_confMfloSpecial (ViSession instrumentHandle,
                                         ViBoolean specialTDM1Null,
                                         ViBoolean specialSinusoidTest,
                                         ViReal64 specialSinusoidTestFreq,
                                         ViReal64 gain);
ViStatus _VI_FUNC rssfu_setMfloChannelBandwidth (ViSession instrumentHandle,
                                                 ViInt32 channelBandwidth);
ViStatus _VI_FUNC rssfu_confMfloAreaSettings (ViSession instrumentHandle,
                                              ViInt32 wideAreaContentPID,
                                              ViInt32 localAreaContentPID,
                                              ViInt32 positioningPilotLength,
                                              ViInt32 wideAreaLength);
ViStatus _VI_FUNC rssfu_confMfloIdSettings (ViSession instrumentHandle,
                                            ViInt32 wideAreaIDValue,
                                            ViInt32 localAreaIDValue,
                                            ViInt32 infrastructureID,
                                            ViReal64 localTimeOffset,
                                            ViBoolean daylightSavingTimeIndicator);
ViStatus _VI_FUNC rssfu_readMfloLengthSettings (ViSession instrumentHandle,
                                                ViInt32 value, ViPInt32 result);
ViStatus _VI_FUNC rssfu_ConfigureMediaFLOInputSignal (ViSession instrumentHandle,
                                                      ViInt32 source,
                                                      ViInt32 input);
ViStatus _VI_FUNC rssfu_ReadMediaFLOValues (ViSession instrumentHandle,
                                            ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfu_ReadStatusMediaFLODelayParameters
             (ViSession instrumentHandle, ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfu_ReadStatusMediaFLOCountParameters
             (ViSession instrumentHandle, ViInt32 value, ViPInt32 result);
ViStatus _VI_FUNC rssfu_ConfigureMediaFLOCoding (ViSession instrumentHandle,
                                                 ViInt32 channelBandwidth,
                                                 ViInt32 IFFTMode,
                                                 ViInt32 slotToInterlaceMapping,
                                                 ViInt32 cyclicPrefixLength);
ViStatus _VI_FUNC rssfu_ConfigureMediaFLOCodingParameters
             (ViSession instrumentHandle, ViInt32 wideAreaIDValue,
              ViInt32 localAreaIDValue, ViInt32 wideMACSymbolsFrame,
              ViInt32 localMACSymbolsFrame, ViReal64 networkGeographyDelay);
ViStatus _VI_FUNC rssfu_EnableMediaFLOSpecialSettings (ViSession instrumentHandle,
                                                       ViBoolean state);
ViStatus _VI_FUNC rssfu_ConfigureMediaFLOSpecialSettings (ViSession instrumentHandle,
                                                          ViBoolean TDM1Null);
ViStatus _VI_FUNC rssfu_ConfigureMediaFLOPIDSettings (ViSession instrumentHandle,
                                                      ViInt32 PID, ViInt32 content,
                                                      ViInt32 controlChannel,
                                                      ViInt32 OIS);
ViStatus _VI_FUNC rssfu_ConfigureMediaFLOLocalOISSystemSettings
             (ViSession instrumentHandle, ViBoolean localOISInsertion,
              ViInt32 infrastructureID, ViReal64 localTimeOffset,
              ViBoolean daylightSavingTimeIndicator);
ViStatus _VI_FUNC rssfu_ConfigureMediaFLOPositionPilotSettings
             (ViSession instrumentHandle, ViBoolean positionPilotSymbols,
              ViInt32 transmitterID, ViInt32 numberOfTransmitters);
ViStatus _VI_FUNC rssfu_EnableMediaFLOTXPositionSettings (ViSession instrumentHandle,
                                                          ViBoolean TXPositionEnable);
ViStatus _VI_FUNC rssfu_ConfigureMediaFLOTXSettings (ViSession instrumentHandle,
                                                     ViInt32 TXPosition,
                                                     ViBoolean TXOffsetEnable,
                                                     ViReal64 TXOffset,
                                                     ViReal64 TXLatitude,
                                                     ViReal64 TXLongitude,
                                                     ViReal64 TXAltitude);
ViStatus _VI_FUNC rssfu_readTDMBCoderStatus (ViSession instrumentHandle,
                                             ViChar _VI_FAR status[]);
ViStatus _VI_FUNC rssfu_confTDMBInputSignal (ViSession instrumentHandle,
                                             ViInt32 source);
ViStatus _VI_FUNC rssfu_readTDMBValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPInt32 result);
ViStatus _VI_FUNC rssfu_readTDMBEtiInput (ViSession instrumentHandle,
                                          ViPInt32 ETIInput);
ViStatus _VI_FUNC rssfu_readTDMBInfo (ViSession instrumentHandle,
                                      ViInt32 subchannel, ViPInt32 SCID,
                                      ViPInt32 protProfile, ViPInt32 protLevel,
                                      ViPInt32 dataRate);
ViStatus _VI_FUNC rssfu_actEnableTDMBSpecial (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rssfu_confTDMBSpecial (ViSession instrumentHandle,
                                         ViInt32 transmissionMode,
                                         ViInt32 selectTransmissionMode,
                                         ViBoolean PRBSTestsignal,
                                         ViInt32 testsignalSCID);
ViStatus _VI_FUNC rssfu_confTDMBConfiguration (ViSession instrumentHandle,
                                               ViBoolean TDMBTTI, ViInt32 TIIMainID,
                                               ViInt32 TIISubID,
                                               ViInt32 TDMBNetwork,
                                               ViInt32 TDMBPRBS);
ViStatus _VI_FUNC rssfu_confAnalogTvVideoInputSignal (ViSession instrumentHandle,
                                                      ViInt32 videoInputSignal);
ViStatus _VI_FUNC rssfu_confAnalogTvVideo (ViSession instrumentHandle,
                                           ViInt32 visionPicture);
ViStatus _VI_FUNC rssfu_loadAnalogTvVideoLibrary (ViSession instrumentHandle,
                                                  ViString loadLibrary);
ViStatus _VI_FUNC rssfu_analogTvVideoLibraryCatalog (ViSession instrumentHandle,
                                                     ViString directory,
                                                     ViInt32 bufferSize,
                                                     ViChar _VI_FAR output[],
                                                     ViPInt32 returnedValues);
ViStatus _VI_FUNC rssfu_analogTvVideoLibraryCatalogLength
             (ViSession instrumentHandle, ViString directory,
              ViPInt32 catalogLength);
ViStatus _VI_FUNC rssfu_confAnalogTvAudioInputSignal (ViSession instrumentHandle,
                                                      ViInt32 audioInputSignal);
ViStatus _VI_FUNC rssfu_configAnalogTvAudio (ViSession instrumentHandle,
                                             ViInt32 frequencyParameter,
                                             ViReal64 frequencyValue,
                                             ViInt32 levelParameter,
                                             ViReal64 levelValue);
ViStatus _VI_FUNC rssfu_configAnalogTvAudioAf (ViSession instrumentHandle,
                                               ViInt32 audioChannel,
                                               ViBoolean state);
ViStatus _VI_FUNC rssfu_configAnalogTvAudioImpedance (ViSession instrumentHandle,
                                                      ViInt32 inputImpedance);
ViStatus _VI_FUNC rssfu_readExternalAudioInputLevel (ViSession instrumentHandle,
                                                     ViPReal64 audioInputLevel);
ViStatus _VI_FUNC rssfu_loadAnalogTvAudioLibrary (ViSession instrumentHandle,
                                                  ViString loadLibrary);
ViStatus _VI_FUNC rssfu_analogTvAudioLibraryCatalog (ViSession instrumentHandle,
                                                     ViString directory,
                                                     ViInt32 bufferSize,
                                                     ViChar _VI_FAR output[],
                                                     ViPInt32 returnedValues);
ViStatus _VI_FUNC rssfu_analogTvAudioLibraryCatalogLength
             (ViSession instrumentHandle, ViString directory,
              ViPInt32 catalogLength);
ViStatus _VI_FUNC rssfu_confAnalogTvVideoVisionPicture (ViSession instrumentHandle,
                                                        ViInt32 mode);
ViStatus _VI_FUNC rssfu_confAnalogTvNICAMSignal (ViSession instrumentHandle,
                                                 ViInt32 NICAMSignal);
ViStatus _VI_FUNC rssfu_readAnalogTvValues (ViSession instrumentHandle,
                                            ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfu_actEnableAnalogTvSpecial (ViSession instrumentHandle,
                                                  ViBoolean state);
ViStatus _VI_FUNC rssfu_confAnalogTvPreemphasis (ViSession instrumentHandle,
                                                 ViInt32 preemphasis);
ViStatus _VI_FUNC rssfu_confAnalogTvPilot (ViSession instrumentHandle,
                                           ViBoolean pilot,
                                           ViReal64 nomFreqDevPilot);
ViStatus _VI_FUNC rssfu_confAnalogTvSubcarrierSettings (ViSession instrumentHandle,
                                                        ViInt32 subcarrier,
                                                        ViReal64 nomFreqDev,
                                                        ViBoolean subcarrierState,
                                                        ViReal64 frequencySubcarrier,
                                                        ViReal64 levelSubcarrier);
ViStatus _VI_FUNC rssfu_confAnalogTvSpecialSettings (ViSession instrumentHandle,
                                                     ViBoolean VSBFilter,
                                                     ViBoolean GDPrecorrection,
                                                     ViReal64 residualCarrier);
ViStatus _VI_FUNC rssfu_confAnalogTvSpecialVideoCarrier (ViSession instrumentHandle,
                                                         ViBoolean video,
                                                         ViBoolean carrier);
ViStatus _VI_FUNC rssfu_confAnalogTvSpecialVsbCharacteristic
             (ViSession instrumentHandle, ViInt32 VSBCharacteristic);
ViStatus _VI_FUNC rssfu_setAnalogTvSpecialAmModulationDepth
             (ViSession instrumentHandle, ViInt32 AMModulationDepth);

ViStatus _VI_FUNC rssfu_confCMMBInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input,
                                             ViInt32 stuffing);
ViStatus _VI_FUNC rssfu_configureCMMBTestSignal (ViSession instrumentHandle,
                                                 ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_readCMMBValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfu_SetCMMBNumberOfServices (ViSession instrumentHandle,
                                                 ViInt32 numberOfServices);
ViStatus _VI_FUNC rssfu_confCMMBCoding (ViSession instrumentHandle, ViInt32 control,
                                        ViInt32 bandwidth);
ViStatus _VI_FUNC rssfu_ReadCMMBOFDMMode (ViSession instrumentHandle,
                                          ViPInt32 OFDMMode);
ViStatus _VI_FUNC rssfu_confCMMBPLCHTable (ViSession instrumentHandle, ViInt32 PLCH,
                                           ViInt32 RS, ViInt32 byteIL, ViInt32 LDPC,
                                           ViInt32 constel, ViInt32 SCRMode,
                                           ViInt32 startTS, ViInt32 stopTS);
ViStatus _VI_FUNC rssfu_actEnableCMMBSpecial (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rssfu_confCMMBSpecial (ViSession instrumentHandle,
                                         ViBoolean reedSolomon,
                                         ViBoolean byteInterleaver,
                                         ViBoolean bitInterleaver,
                                         ViBoolean scrambling);
ViStatus _VI_FUNC rssfu_confCMMBSettings (ViSession instrumentHandle,
                                          ViInt32 transmitterID, ViInt32 areaID,
                                          ViInt32 payloadTestSignal, ViInt32 PRBS);

ViStatus _VI_FUNC rssfu_ConfigureDVBT2InputT2MIInterface (ViSession instrumentHandle,
                                                          ViBoolean t2MIInterface, ViInt32 t2MIInput);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2InputT2MIPID (ViSession instrumentHandle,
                                                    ViInt32 t2MIPID);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2InputT2MISID (ViSession instrumentHandle,
                                                    ViInt32 t2MISID);
ViStatus _VI_FUNC rssfu_ResetDVBT2T2MIAnalyzerLogFile (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfu_ReadDVBT2T2MIAnalyzer (ViSession instrumentHandle,
                                               ViChar _VI_FAR t2MIAnalyzer[]);
ViStatus _VI_FUNC rssfu_confDVBT2InputSignal (ViSession instrumentHandle,
                                              ViInt32 t2MISource,
                                              ViInt32 numberOfPLP, ViInt32 CMType);
ViStatus _VI_FUNC rssfu_configureDVBT2Plp (ViSession instrumentHandle, ViInt32 PLP,
                                           ViInt32 inputFormat, ViInt32 source,
                                           ViInt32 input, ViBoolean stuffing);
ViStatus _VI_FUNC rssfu_readDVBT2Values (ViSession instrumentHandle, ViInt32 PLP,
                                         ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfu_confDVBT2TestSignal (ViSession instrumentHandle,
                                             ViInt32 PLP, ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_confDVBT2ModeStreamAdaptation (ViSession instrumentHandle,
                                                       ViInt32 PLP, ViInt32 PLPID,
                                                       ViInt32 PLPType,
                                                       ViInt32 BBMode,
                                                       ViInt32 ISSY,
                                                       ViBoolean nullPacketDel,
                                                       ViBoolean inBandSignal);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2ModeStreamAdaptationInBandSignal
             (ViSession instrumentHandle, ViInt32 PLP, ViBoolean inBandSignalA,
              ViBoolean inBandSignalB);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2ModeStreamAdaptationCM
             (ViSession instrumentHandle, ViInt32 plp, ViInt32 CMType);
ViStatus _VI_FUNC rssfu_ReadDVBT2ModeStreamAdaptationValues
             (ViSession instrumentHandle, ViInt32 PLP, ViPInt32 PLPGroupID,
              ViPInt32 otherInBandPLP);
ViStatus _VI_FUNC rssfu_confDVBT2BICMParameters (ViSession instrumentHandle,
                                                 ViInt32 PLP, ViInt32 FECFrame,
                                                 ViInt32 codeRate,
                                                 ViInt32 constellation,
                                                 ViBoolean constellRotation);
ViStatus _VI_FUNC rssfu_confDVBT2BICMTimeInterleaverParameters
             (ViSession instrumentHandle, ViInt32 PLP, ViInt32 timeInterleaverType,
              ViInt32 frameIntIJump, ViInt32 timeInterleaverLength);
ViStatus _VI_FUNC rssfu_readDVBT2BICMFECBlocksPerIF (ViSession instrumentHandle,
                                                     ViInt32 PLP,
                                                     ViPInt32 FECBlocksPerIF);
ViStatus _VI_FUNC rssfu_readDVBT2BICMMaxFECBlocksPerIF (ViSession instrumentHandle,
                                                     ViInt32 PLP,
                                                     ViPInt32 MaxFECBlocksPerIF);
ViStatus _VI_FUNC rssfu_confDVBT2BICMFramingOFDMParameters
             (ViSession instrumentHandle, ViInt32 channelBandwidth, ViInt32 FFTSize,
              ViInt32 guardInterval, ViInt32 pilotPattern);
ViStatus _VI_FUNC rssfu_readDVBT2FramingOFDMUsedBandwidth
             (ViSession instrumentHandle, ViPReal64 usedBandwidth);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2FramingOFDMBandwidthVariation
             (ViSession instrumentHandle, ViInt32 bandwidthVariation);

ViStatus _VI_FUNC rssfu_confDVBT2FramingOFDM (ViSession instrumentHandle,
                                              ViInt32 t2FramesPerSuperFrame,
                                              ViInt32 dataSymbolsPerT2Frame,
                                              ViInt32 subslicesPerT2Frame);
ViStatus _VI_FUNC rssfu_readDVBT2FramingOFDMSymbolsPerT2Frame
             (ViSession instrumentHandle, ViPInt32 OFDMSymbolsPerT2Frame);
ViStatus _VI_FUNC rssfu_readDVBT2FramingOFDMDataSymbols (ViSession instrumentHandle,
                                                         ViPInt32 dataSymbolsPerT2Frame);
ViStatus _VI_FUNC rssfu_confDVBT2TransmissionSystem (ViSession instrumentHandle,
                                                     ViInt32 transmissionSystem,
                                                     ViInt32 peakToAvragePowerRatio,
                                                     ViBoolean futureExtensionFrames,
                                                     ViBoolean timeFrequencySlicing);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2TransmissionSystemNetwork
             (ViSession instrumentHandle, ViInt32 networkMode);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2TransmissionProfileMode
             (ViSession instrumentHandle, ViInt32 profileMode);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2TransmissionSystemMISO
             (ViSession instrumentHandle, ViInt32 MISO);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2TransmissionMISOGroupMode
             (ViSession instrumentHandle, ViInt32 groupMode);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2TransmissionFutureExtensionFrames
             (ViSession instrumentHandle, ViInt32 FEFLength, ViInt32 FEFType,
              ViInt32 FEFInterval);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2TransmissionFutureExtensionPayload
             (ViSession instrumentHandle, ViInt32 FEFPayload);
ViStatus _VI_FUNC rssfu_confDVBT2TransmissionL1Param (ViSession instrumentHandle,
                                                      ViInt32 l1PostModulation,
                                                      ViBoolean l1Repetition,
                                                      ViBoolean l1PostExtension,
                                                      ViInt32 numAuxStreams,
                                                      ViBoolean l1RFSignalling);
ViStatus _VI_FUNC rssfu_confDVBT2TransmissionLParametersL1T2
             (ViSession instrumentHandle, ViBoolean l1PostScrambled,
              ViBoolean t2BaseLite);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2TransmissionL1T2Version
             (ViSession instrumentHandle, ViInt32 l1T2Version);
ViStatus _VI_FUNC rssfu_confDVBT2TransmissionSystemIdentification
             (ViSession instrumentHandle, ViInt32 cellID, ViInt32 networkID,
              ViInt32 systemID, ViBoolean transmitterIDState);
ViStatus _VI_FUNC rssfu_ReadDVBT2T2SystemTxIDAvailability
             (ViSession instrumentHandle, ViPInt32 txIDAvailability);
ViStatus _VI_FUNC rssfu_ReadDVBT2T2SystemL1SignallingFrequency
             (ViSession instrumentHandle, ViPReal64 frequency);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2SFNDelayParameters (ViSession instrumentHandle,
                                                          ViInt32 delayParameter,
                                                          ViReal64 timeValue);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2SFNMuteP1Symbol (ViSession instrumentHandle,
                                                       ViBoolean muteP1SymbolOfSuperFrame);
ViStatus _VI_FUNC rssfu_ReadDVBT2SFNDelayParameters (ViSession instrumentHandle,
                                                     ViInt32 delayParameter,
                                                     ViPReal64 timeValue);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2SFNTimestampOffset (ViSession instrumentHandle,
                                                          ViInt32 timestampOffset);
ViStatus _VI_FUNC rssfu_ConfigureDVBT2SFNUpdateTimestamp
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfu_ReadDVBT2SFNTimestampMode (ViSession instrumentHandle,
                                                   ViPInt32 timestampMode);
ViStatus _VI_FUNC rssfu_ReadDVBT2SFNTimestampParameters (ViSession instrumentHandle,
                                                         ViPInt32 UTCDate,
                                                         ViPInt32 UTCTime,
                                                         ViPInt32 secondsSince2000);
ViStatus _VI_FUNC rssfu_confDVBT2Settings (ViSession instrumentHandle,
                                           ViInt32 testTSPacket,
                                           ViInt32 PIDTestPacket, ViInt32 PID,
                                           ViInt32 payloadTestTSPacket,
                                           ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_ConfigureDVBC2NumberOfPLP (ViSession instrumentHandle,
                                                   ViInt32 numberOfPLP);
ViStatus _VI_FUNC rssfu_configureDVBC2InputSignal (ViSession instrumentHandle,
                                                   ViInt32 PLP, ViInt32 inputFormat,
                                                   ViInt32 source, ViInt32 input);
ViStatus _VI_FUNC rssfu_ReadDVBC2Values (ViSession instrumentHandle, ViInt32 PLP,
                                         ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfu_ConfigureDVB2CTestSignal (ViSession instrumentHandle,
                                                  ViInt32 PLP, ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_ConfigureDVBC2ModeStreamAdaptation
             (ViSession instrumentHandle, ViInt32 PLP, ViInt32 PLPID,
              ViInt32 BBMode, ViInt32 ISSY,
              ViBoolean nullPacketDel);
ViStatus _VI_FUNC rssfu_ReadDVBC2ModeStreamAdaptationPLPType
             (ViSession instrumentHandle, ViInt32 PLP, ViPInt32 PLPType);
ViStatus _VI_FUNC rssfu_ConfigureDVBC2BICMPLPMappingParameters
             (ViSession instrumentHandle, ViInt32 PLP, ViInt32 FECFrame,
              ViInt32 codeRate, ViInt32 constellation, ViInt32 mapToDSlice);
ViStatus _VI_FUNC rssfu_ReadDVBC2BICMXFECFrameLength (ViSession instrumentHandle,
                                                      ViInt32 PLP,
                                                      ViPInt32 XFECFrameLength);
ViStatus _VI_FUNC rssfu_ReadDVBC2DataSliceMinMax (ViSession instrumentHandle,
                                                  ViPInt32 min_REL_DxTu,
                                                  ViPInt32 max_REL_DxTu,
                                                  ViPInt32 min_ABS_DxTu,
                                                  ViPInt32 max_ABS_DxTu);
ViStatus _VI_FUNC rssfu_ConfigureDVBC2NumberOfDataSlices (ViSession instrumentHandle,
                                                          ViInt32 numberOfDataSlices);
ViStatus _VI_FUNC rssfu_ConfigureDVBC2DataSliceParameters
             (ViSession instrumentHandle, ViInt32 DSlice, ViInt32 DSliceID_HEX,
              ViInt32 DSliceTIDepth, ViInt32 DSliceType, ViInt32 FECHeaderType,
              ViInt32 numXFECFrames);
ViStatus _VI_FUNC rssfu_ReadDVBC2DataSliceNumPLP (ViSession instrumentHandle,
                                                  ViInt32 DSlice,
                                                  ViPInt32 DSliceNumPLP);
ViStatus _VI_FUNC rssfu_ConfigureDVBC2CurrentDataSliceParameters
             (ViSession instrumentHandle, ViInt32 DSlice, ViInt32 offsetLeftDxTu,
              ViInt32 tunePos_REL_DxTu, ViInt32 offsetRightDxTu);
ViStatus _VI_FUNC rssfu_ReadDVBC2DataSliceValues (ViSession instrumentHandle,
                                                  ViInt32 DSlice, ViInt32 value,
                                                  ViPInt32 result);
ViStatus _VI_FUNC rssfu_ReadDVBC2DataSliceFrequencyValues
             (ViSession instrumentHandle, ViInt32 DSlice, ViInt32 DSliceValue,
              ViPReal64 result);
ViStatus _VI_FUNC rssfu_ConfigureDVBC2NumberOfNotches (ViSession instrumentHandle,
                                                  ViInt32 numberOfNotches);
ViStatus _VI_FUNC rssfu_ReadDVBC2NumberOfNotches (ViSession instrumentHandle,
                                                  ViPInt32 numberOfNotches);
ViStatus _VI_FUNC rssfu_ReadDVBC2NotchType (ViSession instrumentHandle,
                                            ViInt32 notch, ViPInt32 notchType);
ViStatus _VI_FUNC rssfu_ConfigureDVBC2NotchValues (ViSession instrumentHandle,
                                                   ViInt32 notch,
                                                   ViInt32 start_REL_DxTu,
                                                   ViInt32 stop_REL_DxTu,
                                                   ViInt32 widthDxTu);
ViStatus _VI_FUNC rssfu_ReadDVBC2NotchValues (ViSession instrumentHandle,
                                              ViInt32 notch, ViInt32 notchParameter,
                                              ViPInt32 result);
ViStatus _VI_FUNC rssfu_ReadDVBC2NotchFrequencyValues (ViSession instrumentHandle,
                                                       ViInt32 notch,
                                                       ViInt32 notchParameter,
                                                       ViPReal64 result);
ViStatus _VI_FUNC rssfu_ConfigureDVBC2FramingOFDMParameters
             (ViSession instrumentHandle, ViInt32 channelBandwidth,
              ViInt32 numBundledCH, ViInt32 guardInterval);
ViStatus _VI_FUNC rssfu_ConfigureDVBC2FramingOFDMC2Bandwidth
             (ViSession instrumentHandle, ViInt32 c2Bandwidth);
ViStatus _VI_FUNC rssfu_ReadDVBC2FramingOFDMUsedBandwidth
             (ViSession instrumentHandle, ViPReal64 usedBandwidth);
ViStatus _VI_FUNC rssfu_ConfigureDVBC2FramingOFDMBasebandFilter
             (ViSession instrumentHandle, ViInt32 basebandFilter);
ViStatus _VI_FUNC rssfu_ConfigureDVBC2FramingOFDMAdjustRFFrequency
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfu_ReadDVBC2FramingOFDMCalculateCenterFrequency
             (ViSession instrumentHandle, ViPReal64 calculateCenterFrequency);
ViStatus _VI_FUNC rssfu_ReadDVBC2FramingOFDMParameters (ViSession instrumentHandle,
                                                        ViPInt32 DX,
                                                        ViPReal64 startFrequency,
                                                        ViPReal64 carrierSpacing_1Tu,
                                                        ViPInt32 numberOfDataSymbolC2Frame,
                                                        ViPInt32 numberOfPreambleSymbols);
ViStatus _VI_FUNC rssfu_ConfigureDVBC2C2SystemParameters (ViSession instrumentHandle,
                                                          ViInt32 networkID,
                                                          ViInt32 c2SystemID,
                                                          ViInt32 l1TimeInterleaver,
                                                          ViBoolean systemReservedTones);
ViStatus _VI_FUNC rssfu_ConfigureDVBC2Settings (ViSession instrumentHandle,
                                                ViInt32 testTSPacket,
                                                ViInt32 PIDTestPacket, ViInt32 PID,
                                                ViInt32 payloadTestTSPacket,
                                                ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_confATSCMHInputSignal (ViSession instrumentHandle,
                                               ViInt32 source, ViInt32 input,
                                               ViInt32 stuffing);
ViStatus _VI_FUNC rssfu_confATSCMHTestSignal (ViSession instrumentHandle,
                                              ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_readATSCMHPackedLength (ViSession instrumentHandle,
                                                ViPInt32 packedLength);
ViStatus _VI_FUNC rssfu_readATSCMHValues (ViSession instrumentHandle, ViInt32 value,
                                          ViPReal64 result);
ViStatus _VI_FUNC rssfu_confATSCMHCodingParameters (ViSession instrumentHandle,
                                                    ViReal64 symbolRate,
                                                    ViBoolean MHState);
ViStatus _VI_FUNC rssfu_readATSCMHConstellation (ViSession instrumentHandle,
                                                 ViChar _VI_FAR constellation[]);
ViStatus _VI_FUNC rssfu_readATSCMHRollOff (ViSession instrumentHandle,
                                           ViPReal64 rollOff);
ViStatus _VI_FUNC rssfu_enableATSCMHSpecial (ViSession instrumentHandle,
                                             ViBoolean state);
ViStatus _VI_FUNC rssfu_confATSCMHSpecial (ViSession instrumentHandle,
                                           ViBoolean randomizer,
                                           ViBoolean reedSolomon,
                                           ViBoolean interleaver,
                                           ViBoolean SFNInitialization,
                                           ViBoolean trellisInitialization,
                                           ViBoolean pilot, ViReal64 pilotValue);
ViStatus _VI_FUNC rssfu_setAtscmhMhePid (ViSession instrumentHandle,
                                         ViInt32 MHEPID);
ViStatus _VI_FUNC rssfu_confATSCMHRfWatermarkSettings (ViSession instrumentHandle,
                                                       ViBoolean RFWatermark,
                                                       ViInt32 txAddress,
                                                       ViInt32 networkID,
                                                       ViInt32 buryRatio);
ViStatus _VI_FUNC rssfu_configATSCMHMTXIDTransmission (ViSession instrumentHandle,
                                                       ViBoolean MTXIDTransmission,
                                                       ViInt32 transmitterID,
                                                       ViInt32 marketID);
ViStatus _VI_FUNC rssfu_confATSCMHSettings (ViSession instrumentHandle,
                                            ViInt32 testTSPacket,
                                            ViInt32 PIDTestPacket, ViInt32 PID,
                                            ViInt32 payloadTestStuff, ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_configAudioBCFMInputSignal (ViSession instrumentHandle,
                                                    ViInt32 sourceLeft,
                                                    ViInt32 sourceRight,
                                                    ViInt32 AFMode,
                                                    ViInt32 impedanceSignalSource);
ViStatus _VI_FUNC rssfu_confAudioBCFMSource (ViSession instrumentHandle,
                                             ViInt32 source, ViReal64 frequency,
                                             ViReal64 level);
ViStatus _VI_FUNC rssfu_readAudioBCFMExternalSource (ViSession instrumentHandle,
                                                     ViInt32 source,
                                                     ViPReal64 inputLevel);
ViStatus _VI_FUNC rssfu_configAudioBCFMRDSRBDS (ViSession instrumentHandle,
                                                ViString groupSequence, ViInt32 RS_PI,
                                                ViString PS, ViBoolean TP,
                                                ViBoolean TA, ViInt32 PTY,
                                                ViString PTYN, ViString RT,
                                                ViInt32 MS);
ViStatus _VI_FUNC rssfu_ReadAudioBCFMRDSRBDSRadioTextStatus
             (ViSession instrumentHandle, ViPInt32 RTReady);
ViStatus _VI_FUNC rssfu_configAudioBCFMRDSRBDSDecoderIdn (ViSession instrumentHandle,
                                                          ViBoolean DIDynamicPTY,
                                                          ViBoolean DICompressed,
                                                          ViBoolean DIArtHead,
                                                          ViBoolean DIStereo,
                                                          ViBoolean DICT,
                                                          ViString DICTOffset,
                                                          ViInt32 DIAFMethod);
ViStatus _VI_FUNC rssfu_SetAudioBCFMAFAFreq (ViSession instrumentHandle,
                                             ViInt32 numberOfFreq);
ViStatus _VI_FUNC rssfu_ConfigureAudioBCFMAFAFrequency (ViSession instrumentHandle,
                                                        ViInt32 AF,
                                                        ViReal64 frequency);
ViStatus _VI_FUNC rssfu_SetAudioBCFMAFBList (ViSession instrumentHandle,
                                             ViInt32 numberOfLists);
ViStatus _VI_FUNC rssfu_SetAudioBCFMAFBFreq (ViSession instrumentHandle,
                                             ViInt32 list, ViInt32 numberOfFreq,
                                             ViReal64 tuningFreq);
ViStatus _VI_FUNC rssfu_ConfigureAudioBCFMAFBFrequency (ViSession instrumentHandle,
                                                        ViInt32 list, ViInt32 AF,
                                                        ViReal64 frequency,
                                                        ViInt32 order);
ViStatus _VI_FUNC rssfu_configAudioBCFMEONParameters (ViSession instrumentHandle,
                                                      ViInt32 EONPI, ViString EONPS,
                                                      ViBoolean EONTP,
                                                      ViBoolean EONTA,
                                                      ViBoolean EONLA,
                                                      ViBoolean EONEG,
                                                      ViBoolean EONILS,
                                                      ViInt32 EONLSN,
                                                      ViInt32 EONPTY,
                                                      ViInt32 EONPIN,
                                                      ViInt32 EONAFMethod);
ViStatus _VI_FUNC rssfu_SetAudioBCFMEONAFAFreq (ViSession instrumentHandle,
                                                ViInt32 numberOfFreq);
ViStatus _VI_FUNC rssfu_ConfigureAudioBCFMEONAFAFrequency
             (ViSession instrumentHandle, ViInt32 AF, ViReal64 frequency);
ViStatus _VI_FUNC rssfu_SetAudioBCFMEONAFMappedFreqNumberOfFreq
             (ViSession instrumentHandle, ViInt32 numberOfFreq,
              ViReal64 tuningFreq);
ViStatus _VI_FUNC rssfu_ConfigureAudioBCFMEONAFMappedFrequency
             (ViSession instrumentHandle, ViInt32 AF, ViReal64 frequency);
ViStatus _VI_FUNC rssfu_EnableAudioBCFMTMC (ViSession instrumentHandle,
                                            ViBoolean TMC);
ViStatus _VI_FUNC rssfu_AudioBCFMTMCSendData (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfu_SetAudioBCTMCGroup3AVARParameters
             (ViSession instrumentHandle, ViInt32 group3AVAR00,
              ViInt32 group3AVAR01);
ViStatus _VI_FUNC rssfu_SetAudioBCTMCNumberOf8AGroups (ViSession instrumentHandle,
                                                       ViInt32 numberOf8AGroups);
ViStatus _VI_FUNC rssfu_ConfigureAudioBCFMTMC8ABlock (ViSession instrumentHandle,
                                                      ViInt32 group8A,
                                                      ViInt32 block, ViInt32 value);
ViStatus _VI_FUNC rssfu_EnableAudioBCFMOpenFormat (ViSession instrumentHandle,
                                                   ViBoolean openFormat);
ViStatus _VI_FUNC rssfu_AudioBCFMOpenFormatSendData (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfu_ConfigureAudioBCOpenFormatGroupA (ViSession instrumentHandle,
                                                          ViInt32 groupA,
                                                          ViInt32 block,
                                                          ViInt32 value);
ViStatus _VI_FUNC rssfu_ConfigureAudioBCOpenFormatGroupB (ViSession instrumentHandle,
                                                          ViInt32 groupB,
                                                          ViInt32 block,
                                                          ViInt32 value);
ViStatus _VI_FUNC rssfu_AudioBCOpenFormatGroupDataTransferStatus
             (ViSession instrumentHandle, ViInt32 group, ViInt32 groupType,
              ViPInt32 transferStatus);
ViStatus _VI_FUNC rssfu_configAudioBCFMAudioModulation (ViSession instrumentHandle,
                                                        ViInt32 mode,
                                                        ViInt32 preemphasis,
                                                        ViReal64 nomFreqDevAudio);
ViStatus _VI_FUNC rssfu_configureAudioBCModulationRDS (ViSession instrumentHandle,
                                                       ViBoolean RDS,
                                                       ViReal64 freqDevRDS,
                                                       ViReal64 freqDevPilot19_kHz);
ViStatus _VI_FUNC rssfu_configureAudioMPXFreqDeviation (ViSession instrumentHandle,
                                                        ViReal64 nomFreqDevMPX);
ViStatus _VI_FUNC rssfu_readAudioBCFMModulationValues (ViSession instrumentHandle,
                                                       ViInt32 value,
                                                       ViPReal64 result);
ViStatus _VI_FUNC rssfu_enableAudioBCFMSpecialSettings (ViSession instrumentHandle,
                                                        ViBoolean state);
ViStatus _VI_FUNC rssfu_confAudioBCFMSpecialSettings (ViSession instrumentHandle,
                                                      ViBoolean pilot,
                                                      ViReal64 phaseOffsetPilot19kHz,
                                                      ViReal64 phaseOffsetRDS);
ViStatus _VI_FUNC rssfu_configAudioBCAMInputSignal (ViSession instrumentHandle,
                                                    ViInt32 source,
                                                    ViInt32 impedanceSignalSource);
ViStatus _VI_FUNC rssfu_confAudioBCAMSource (ViSession instrumentHandle,
                                             ViReal64 frequency, ViReal64 level);
ViStatus _VI_FUNC rssfu_readAudioBCAMExternalSource (ViSession instrumentHandle,
                                                     ViPReal64 inputLevel);
ViStatus _VI_FUNC rssfu_confAudioBCAMModulationDepth (ViSession instrumentHandle,
                                                      ViReal64 nomModDepth);
ViStatus _VI_FUNC rssfu_readAudioBCAMModeDepth (ViSession instrumentHandle,
                                                ViPReal64 modeDepth);
ViStatus _VI_FUNC rssfu_confImpModulator (ViSession instrumentHandle,
                                          ViBoolean state, ViReal64 iOffset,
                                          ViReal64 qOffset,
                                          ViReal64 quadratureError,
                                          ViReal64 amplitudeImbalance);
ViStatus _VI_FUNC rssfu_confImpBaseband (ViSession instrumentHandle,
                                         ViBoolean state, ViReal64 iOffset,
                                         ViReal64 qOffset, ViReal64 quadratureError,
                                         ViReal64 amplitudeImbalance,
                                         ViBoolean optimizeBBImp_forRFOutput);
ViStatus _VI_FUNC rssfu_setImpOptimizationMode (ViSession instrumentHandle,
                                                ViInt32 impairmentsOptimizationMode);
ViStatus _VI_FUNC rssfu_confNoise (ViSession instrumentHandle, ViInt32 noise,
                                   ViBoolean AWGN, ViBoolean impulsiveNoise,
                                   ViBoolean phaseNoise);
ViStatus _VI_FUNC rssfu_readNoiseGenState (ViSession instrumentHandle,
                                           ViPInt32 noiseState);
ViStatus _VI_FUNC rssfu_confNoiseCn (ViSession instrumentHandle, ViReal64 cN);
ViStatus _VI_FUNC rssfu_readNoiseCN (ViSession instrumentHandle, ViPReal64 cN);
ViStatus _VI_FUNC rssfu_readNoiseEbN0 (ViSession instrumentHandle, ViPReal64 ebN0);
ViStatus _VI_FUNC rssfu_confNoisePulse (ViSession instrumentHandle, ViReal64 cI,
                                        ViInt32 frameDuration,
                                        ViInt32 pulses_perBurst,
                                        ViReal64 pulseSpacingMin,
                                        ViReal64 pulseSpacingMax);
ViStatus _VI_FUNC rssfu_confNoisePhase (ViSession instrumentHandle,
                                        ViString SSBShapeProfile,
                                        ViReal64 phaseNoise_at100Hz);
ViStatus _VI_FUNC rssfu_GetLevelOfPhaseNoise (ViSession instrumentHandle,
                                              ViInt32 offset, ViPReal64 result);
ViStatus _VI_FUNC rssfu_confNoiseBwSettings (ViSession instrumentHandle,
                                             ViBoolean bandwidthCoupling,
                                             ViReal64 receiverBandwidth);
ViStatus _VI_FUNC rssfu_readNoiseGenBand (ViSession instrumentHandle,
                                          ViPReal64 generatedNoiseBandwidth);
ViStatus _VI_FUNC rssfu_noiseFileOperations (ViSession instrumentHandle,
                                             ViInt32 operation, ViString source);
ViStatus _VI_FUNC rssfu_actEnableFading (ViSession instrumentHandle, ViInt32 fader,
                                         ViBoolean state);
ViStatus _VI_FUNC rssfu_actRestartFading (ViSession instrumentHandle,
                                          ViInt32 fader);
ViStatus _VI_FUNC rssfu_actFadingConfig (ViSession instrumentHandle, ViInt32 fader,
                                         ViInt32 configuration, ViBoolean state);
ViStatus _VI_FUNC rssfu_configureFading (ViSession instrumentHandle, ViInt32 fader,
                                         ViInt32 configuration);
ViStatus _VI_FUNC rssfu_storeLoadFadingSettings (ViSession instrumentHandle,
                                                 ViInt32 fader, ViInt32 operation,
                                                 ViString source);
ViStatus _VI_FUNC rssfu_fadingCatalog (ViSession instrumentHandle, ViInt32 fader,
                                       ViString directory, ViInt32 bufferSize,
                                       ViChar _VI_FAR output[],
                                       ViPInt32 returnedValues);
ViStatus _VI_FUNC rssfu_configureFadingSource (ViSession instrumentHandle,
                                               ViInt32 fader, ViInt32 source);
ViStatus _VI_FUNC rssfu_confFadingStandardSet (ViSession instrumentHandle,
                                               ViInt32 fader, ViInt32 standardSet);
ViStatus _VI_FUNC rssfu_actEnableFadingPath (ViSession instrumentHandle,
                                             ViInt32 configuration, ViInt32 fader,
                                             ViInt32 group, ViInt32 path,
                                             ViBoolean state);
ViStatus _VI_FUNC rssfu_confFadingPathProfile (ViSession instrumentHandle,
                                               ViInt32 configuration, ViInt32 fader,
                                               ViInt32 group, ViInt32 path,
                                               ViInt32 profile);
ViStatus _VI_FUNC rssfu_confFadingPathProfileTableNumeric
             (ViSession instrumentHandle, ViInt32 configuration, ViInt32 fader,
              ViInt32 group, ViInt32 path, ViInt32 parameterName, ViReal64 value);
ViStatus _VI_FUNC rssfu_confFadingPathProfileTableBoolean
             (ViSession instrumentHandle, ViInt32 configuration, ViInt32 fader,
              ViInt32 group, ViInt32 path, ViInt32 parameterName, ViBoolean value);
ViStatus _VI_FUNC rssfu_readFadingPathProfileTableResults
             (ViSession instrumentHandle, ViInt32 configuration, ViInt32 fader,
              ViInt32 group, ViInt32 path, ViInt32 parameterName, ViPReal64 value);
ViStatus _VI_FUNC rssfu_confFadingPathProfileResultDopplerFreq
             (ViSession instrumentHandle, ViInt32 configuration, ViInt32 fader,
              ViInt32 group, ViInt32 path, ViReal64 dopplerFrequency);
ViStatus _VI_FUNC rssfu_confFadingBirthDeathPathLoss (ViSession instrumentHandle,
                                                      ViInt32 fader, ViInt32 path,
                                                      ViReal64 pathLoss);
ViStatus _VI_FUNC rssfu_readFadingBirthDeathPathProfile (ViSession instrumentHandle,
                                                         ViInt32 fader,
                                                         ViInt32 path,
                                                         ViChar _VI_FAR profile[]);
ViStatus _VI_FUNC rssfu_confFadingBirthDeathPathProfile (ViSession instrumentHandle,
                                                         ViInt32 fader,
                                                         ViReal64 minDelay,
                                                         ViReal64 delayGrid,
                                                         ViInt32 delayPositions,
                                                         ViReal64 startOffset,
                                                         ViReal64 hoppingDwell,
                                                         ViReal64 speed,
                                                         ViReal64 freqRatio);
ViStatus _VI_FUNC rssfu_confFadingBirthDeathDopplerFrequency
             (ViSession instrumentHandle, ViInt32 fader, ViReal64 dopplerFrequency);
ViStatus _VI_FUNC rssfu_readFadingBirthDeathPathProfileResults
             (ViSession instrumentHandle, ViInt32 fader, ViInt32 parameterName,
              ViPReal64 value);
ViStatus _VI_FUNC rssfu_confFadingMovingPropagPathReference
             (ViSession instrumentHandle, ViInt32 fader,
              ViBoolean referencePathState, ViReal64 referencePathPathLoss,
              ViReal64 referencePathDelay);
ViStatus _VI_FUNC rssfu_confFadingMovingPropagPath (ViSession instrumentHandle,
                                                    ViInt32 fader,
                                                    ViBoolean movingPathState,
                                                    ViReal64 movingPathPathLoss,
                                                    ViReal64 movingPathDelay,
                                                    ViReal64 movingPathVariationPK,
                                                    ViReal64 movingPathVariationPeriod);
ViStatus _VI_FUNC rssfu_confFading2pathDynamicDelayPath (ViSession instrumentHandle,
                                                         ViInt32 fader,
                                                         ViInt32 configurePath,
                                                         ViBoolean state,
                                                         ViInt32 profile,
                                                         ViReal64 pathLoss,
                                                         ViReal64 speed,
                                                         ViReal64 frequencyRatio,
                                                         ViReal64 minDelay);
ViStatus _VI_FUNC rssfu_confFading2pathDynamicDelay (ViSession instrumentHandle,
                                                     ViInt32 fader,
                                                     ViInt32 movingMode,
                                                     ViReal64 movingPathMaxDelay,
                                                     ViReal64 period,
                                                     ViReal64 dwell);
ViStatus _VI_FUNC rssfu_confFading2pathDynamicDelayDopplerShift
             (ViSession instrumentHandle, ViInt32 fader, ViInt32 configurePath,
              ViReal64 dopplerShift);
ViStatus _VI_FUNC rssfu_readFading2pathDynamicDelayDopplerShift
             (ViSession instrumentHandle, ViInt32 fader, ViPReal64 resDopplerShift);
ViStatus _VI_FUNC rssfu_confFadingCommonSettings (ViSession instrumentHandle,
                                                  ViInt32 fader, ViInt32 speedUnit,
                                                  ViBoolean localConstantCoupled_AB,
                                                  ViBoolean standardDeviationCoupled_AB,
                                                  ViBoolean ignoreRFFrequency5,
                                                  ViInt32 signalDedicatedTo,
                                                  ViReal64 virtualRF,
                                                  ViInt32 restartMode);
ViStatus _VI_FUNC rssfu_confFadingCommonCoupledSettings (ViSession instrumentHandle,
                                                         ViInt32 fader,
                                                         ViBoolean localConstantCoupled_AB,
                                                         ViBoolean standardDeviationCoupled_AB);
ViStatus _VI_FUNC rssfu_confFadingSignalDelayShift (ViSession instrumentHandle,
                                                    ViInt32 fader,
                                                    ViReal64 signal_B_DelayShift);
ViStatus _VI_FUNC rssfu_confFadingInsertionLossSettings (ViSession instrumentHandle,
                                                         ViInt32 fader,
                                                         ViInt32 mode,
                                                         ViReal64 insertionLoss);
ViStatus _VI_FUNC rssfu_confFadingDelaySettings (ViSession instrumentHandle,
                                                 ViInt32 fader,
                                                 ViBoolean commonSpeedAllPath);
ViStatus _VI_FUNC rssfu_actFadingSettingsDefault (ViSession instrumentHandle,
                                                  ViInt32 fader);
ViStatus _VI_FUNC rssfu_confFadingReferenceSettings (ViSession instrumentHandle,
                                                     ViInt32 fader,
                                                     ViInt32 reference,
                                                     ViBoolean commonSpeedAllPath,
                                                     ViBoolean commonDopplerShiftAllPath);
ViStatus _VI_FUNC rssfu_confFadingMaxPaths (ViSession instrumentHandle,
                                            ViInt32 fader, ViBoolean maxPaths);
ViStatus _VI_FUNC rssfu_confFadingCouplingSettings (ViSession instrumentHandle,
                                                    ViInt32 fader,
                                                    ViInt32 couplingSelection,
                                                    ViBoolean speedCoupled_AB,
                                                    ViBoolean dopplerShiftCoupled_AB);
ViStatus _VI_FUNC rssfu_readFadingClippedSample (ViSession instrumentHandle,
                                                 ViInt32 fader,
                                                 ViPReal64 clippedSample);
ViStatus _VI_FUNC rssfu_actBER (ViSession instrumentHandle, ViInt32 action);
ViStatus _VI_FUNC rssfu_actBERSelect (ViSession instrumentHandle, ViInt32 input);
ViStatus _VI_FUNC rssfu_confBERSerial (ViSession instrumentHandle, ViInt32 clock,
                                       ViInt32 data, ViInt32 enable);
ViStatus _VI_FUNC rssfu_confBERInputs (ViSession instrumentHandle, ViInt32 signal,
                                       ViInt32 SPIDVALID, ViInt32 gatingMode);
ViStatus _VI_FUNC rssfu_confBERGatingTime (ViSession instrumentHandle,
                                           ViString gatingTime);
ViStatus _VI_FUNC rssfu_confBERSettings (ViSession instrumentHandle,
                                         ViInt32 payload, ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_readBER (ViSession instrumentHandle, ViInt32 measurement,
                                 ViInt32 bufferSize, ViChar _VI_FAR result[]);
ViStatus _VI_FUNC rssfu_actEnableARB (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rssfu_actLoadARBWaveform (ViSession instrumentHandle,
                                            ViString loadWaveform);
ViStatus _VI_FUNC rssfu_DeleteARBWaveform (ViSession instrumentHandle,
                                           ViString deleteWaveform);
ViStatus _VI_FUNC rssfu_ARBWaveformSamples (ViSession instrumentHandle,
                                            ViString waveformFilename,
                                            ViPInt32 numberOfSamples);
ViStatus _VI_FUNC rssfu_actARBWaveformFileTag (ViSession instrumentHandle,
                                               ViString waveformFileName,
                                               ViInt32 tag, ViInt32 bufferSize,
                                               ViChar _VI_FAR output[],
                                               ViPInt32 returnedValues);
ViStatus _VI_FUNC rssfu_ARBWaveformCatalog (ViSession instrumentHandle,
                                            ViString directory, ViInt32 bufferSize,
                                            ViChar _VI_FAR output[],
                                            ViPInt32 returnedValues);
ViStatus _VI_FUNC rssfu_ARBWaveformCatalogLength (ViSession instrumentHandle,
                                                  ViString directory,
                                                  ViPInt32 catalogLength);
ViStatus _VI_FUNC rssfu_ARBMemorySize (ViSession instrumentHandle, ViPInt32 size);
ViStatus _VI_FUNC rssfu_ARBSamplesMaximum (ViSession instrumentHandle,
                                           ViPInt32 samples);
ViStatus _VI_FUNC rssfu_confARBClock (ViSession instrumentHandle,
                                      ViReal64 clockFrequency, ViInt32 clockSource);
ViStatus _VI_FUNC rssfu_confARBExternalClock (ViSession instrumentHandle,
                                              ViInt32 clockMode,
                                              ViInt32 sampleClockMultiplier);
ViStatus _VI_FUNC rssfu_readARBExternalClockFrequency (ViSession instrumentHandle,
                                                       ViPReal64 measuredExtClock);
ViStatus _VI_FUNC rssfu_confARBTrigger (ViSession instrumentHandle, ViInt32 mode,
                                        ViInt32 triggerSource,
                                        ViReal64 triggerDelay,
                                        ViReal64 triggerInhibit);
ViStatus _VI_FUNC rssfu_actARBTriggerExecute (ViSession instrumentHandle,
                                              ViInt32 trigger);
ViStatus _VI_FUNC rssfu_readARBTriggerStatus (ViSession instrumentHandle,
                                              ViChar _VI_FAR triggerStatus[]);
ViStatus _VI_FUNC rssfu_confARBMarker (ViSession instrumentHandle, ViInt32 marker1,
                                       ViInt32 delay);
ViStatus _VI_FUNC rssfu_confARBTestSignal (ViSession instrumentHandle,
                                           ViReal64 frequency,
                                           ViInt32 samples_perPeriod,
                                           ViReal64 phaseOffset);
ViStatus _VI_FUNC rssfu_actARBGenerateTest (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfu_confTsgenApplication (ViSession instrumentHandle,
                                              ViInt32 application);
ViStatus _VI_FUNC rssfu_actTsgenStatus (ViSession instrumentHandle,
                                        ViInt32 command);
ViStatus _VI_FUNC rssfu_readTsgenStatus (ViSession instrumentHandle,
                                         ViPInt32 command);
ViStatus _VI_FUNC rssfu_readTsgenPlayerParam (ViSession instrumentHandle,
                                              ViChar _VI_FAR fileDateSize[],
                                              ViChar _VI_FAR originalLoopTime[],
                                              ViPReal64 originalTSDataRate);
ViStatus _VI_FUNC rssfu_actFileOperations (ViSession instrumentHandle,
                                           ViInt32 operation_to_bePerformed,
                                           ViString source, ViString destination);
ViStatus _VI_FUNC rssfu_actFileCatPath (ViSession instrumentHandle, ViInt32 read,
                                        ViString directory, ViInt32 bufferSize,
                                        ViChar _VI_FAR output[],
                                        ViPInt32 returnedValues);
ViStatus _VI_FUNC rssfu_readCatalogLength (ViSession instrumentHandle, ViInt32 read,
                                           ViPInt32 catalogLength);
ViStatus _VI_FUNC rssfu_readTSGenSeekPosition (ViSession instrumentHandle,
                                               ViPReal64 position);
ViStatus _VI_FUNC rssfu_readToFile (ViSession instrumentHandle, ViString source,
                                    ViString destination);
ViStatus _VI_FUNC rssfu_writeFromFile (ViSession instrumentHandle, ViString source,
                                       ViString destination);
ViStatus _VI_FUNC rssfu_confTsgenPlayfile (ViSession instrumentHandle,
                                           ViString fileName);
ViStatus _VI_FUNC rssfu_setTsByteRate (ViSession instrumentHandle,
                                       ViReal64 byteRate);
ViStatus _VI_FUNC rssfu_confTsgenTimingSettings (ViSession instrumentHandle,
                                                 ViReal64 TSDataRate,
                                                 ViReal64 playWindowStart,
                                                 ViReal64 playWindowStop,
                                                 ViBoolean PCRJitter);
ViStatus _VI_FUNC rssfu_confTsgenPcrJitter (ViSession instrumentHandle,
                                            ViInt32 waveform, ViReal64 amplitude,
                                            ViReal64 frequency);
ViStatus _VI_FUNC rssfu_TSGenNullpacketStuffing (ViSession instrumentHandle,
                                                 ViBoolean nullpacketStuffing);
ViStatus _VI_FUNC rssfu_confTsgenInterfaceSetGen (ViSession instrumentHandle,
                                                  ViInt32 packetLength,
                                                  ViInt32 TSSerialOutput);
ViStatus _VI_FUNC rssfu_confTsgenInterfaceStopData (ViSession instrumentHandle,
                                                    ViInt32 stopData);
ViStatus _VI_FUNC rssfu_confTSGENPacketSettings (ViSession instrumentHandle,
                                                 ViInt32 testTSPacket,
                                                 ViInt32 payloadTestStuff,
                                                 ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_configureTSGenSeamlessLoop (ViSession instrumentHandle,
                                                    ViBoolean continuityCounter,
                                                    ViBoolean PCRDTSPTS,
                                                    ViBoolean TDTTOT);
ViStatus _VI_FUNC rssfu_readTsgenRecordProgress (ViSession instrumentHandle,
                                                 ViPReal64 recordProgress);
ViStatus _VI_FUNC rssfu_readTsgenRecParam (ViSession instrumentHandle,
                                           ViPReal64 freeMemory,
                                           ViPReal64 inputTSDataRate,
                                           ViPReal64 recordLength);
ViStatus _VI_FUNC rssfu_confTsgenNewRecordStream (ViSession instrumentHandle,
                                                  ViString fileName);
ViStatus _VI_FUNC rssfu_confTsgenInterfaceSetRec (ViSession instrumentHandle,
                                                  ViInt32 input,
                                                  ViReal64 recordSize,
                                                  ViInt32 recordMode);
ViStatus _VI_FUNC rssfu_actEnablePowerMeter (ViSession instrumentHandle,
                                             ViBoolean state);
ViStatus _VI_FUNC rssfu_powerMeterConfiguration (ViSession instrumentHandle,
                                                 ViInt32 unit,
                                                 ViReal64 referencePower);
ViStatus _VI_FUNC rssfu_confPowerMeterFrequency (ViSession instrumentHandle,
                                                 ViInt32 source,
                                                 ViReal64 frequency);
ViStatus _VI_FUNC rssfu_relativePowerState (ViSession instrumentHandle,
                                            ViInt32 relativePowerState,
                                            ViPReal64 relativePower);
ViStatus _VI_FUNC rssfu_readAbsoluteOutputPower (ViSession instrumentHandle,
                                                 ViPReal64 power);
ViStatus _VI_FUNC rssfu_actPowerMeterM2Ref (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfu_actPowerMeterZero (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfu_readPowerSensorType (ViSession instrumentHandle,
                                             ViInt32 bufferSize,
                                             ViChar _VI_FAR sensorType[]);
ViStatus _VI_FUNC rssfu_confAverageFilter (ViSession instrumentHandle,
                                           ViInt32 filterType,
                                           ViInt32 filterLength);
ViStatus _VI_FUNC rssfu_actAverageAutoOnce (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfu_confCalInternal (ViSession instrumentHandle,
                                         ViBoolean internalLevelCorrection);
ViStatus _VI_FUNC rssfu_actCal (ViSession instrumentHandle, ViInt32 calibrationType,
                                ViPInt32 result);
ViStatus _VI_FUNC rssfu_getCalDate (ViSession instrumentHandle,
                                    ViInt32 calibrationType, ViChar _VI_FAR date[]);
ViStatus _VI_FUNC rssfu_systemDisplayUpdate (ViSession instrumentHandle,
                                             ViBoolean displayUpdate);
ViStatus _VI_FUNC rssfu_systemKeypadLock (ViSession instrumentHandle,
                                          ViInt32 keypadLock);
ViStatus _VI_FUNC rssfu_setStatusRegister (ViSession instrumentHandle,
                                           ViInt32 registerOperation,
                                           ViInt32 enable, ViInt32 PTransition,
                                           ViInt32 NTransition);
ViStatus _VI_FUNC rssfu_getStatusRegister (ViSession instrumentHandle,
                                           ViInt32 registerOperation,
                                           ViInt32 statusRegistersQuery,
                                           ViPInt32 registerValue);
ViStatus _VI_FUNC rssfu_setUserDefStatusRegister (ViSession instrumentHandle,
                                                  ViInt32 registerOperation,
                                                  ViInt32 userdefinableBit,
                                                  ViInt32 enable,
                                                  ViInt32 PTransition,
                                                  ViInt32 NTransition);
ViStatus _VI_FUNC rssfu_getUserDefStatusRegister (ViSession instrumentHandle,
                                                  ViInt32 registerOperation,
                                                  ViInt32 userdefinableBit,
                                                  ViInt32 statusRegistersQuery,
                                                  ViPInt32 registerValue);
ViStatus _VI_FUNC rssfu_confReferenceOscillator (ViSession instrumentHandle,
                                                 ViInt32 source,
                                                 ViInt32 externalRefFrequency,
                                                 ViInt32 synchronizationBandwidth,
                                                 ViBoolean adjustmentState,
                                                 ViInt32 adjustmentFrequency);
ViStatus _VI_FUNC rssfu_confTriggerIO (ViSession instrumentHandle,
                                       ViInt32 triggerIOPin, ViInt32 triggerIOState,
                                       ViInt32 triggerIOSource,
                                       ViInt32 destination);
ViStatus _VI_FUNC rssfu_SetAttributeViInt32 (ViSession instrumentHandle,
                                             ViString repeatedCapabilityName,
                                             ViUInt32 attributeID,
                                             ViInt32 attributeValue);
ViStatus _VI_FUNC rssfu_SetAttributeViReal64 (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViUInt32 attributeID,
                                              ViReal64 attributeValue);
ViStatus _VI_FUNC rssfu_SetAttributeViString (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViUInt32 attributeID,
                                              ViString attributeValue);
ViStatus _VI_FUNC rssfu_SetAttributeViBoolean (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViBoolean attributeValue);
ViStatus _VI_FUNC rssfu_SetAttributeViSession (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViSession attributeValue);
ViStatus _VI_FUNC rssfu_GetAttributeViInt32 (ViSession instrumentHandle,
                                             ViString repeatedCapabilityName,
                                             ViUInt32 attributeID,
                                             ViPInt32 attributeValue);
ViStatus _VI_FUNC rssfu_GetAttributeViReal64 (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViUInt32 attributeID,
                                              ViPReal64 attributeValue);
ViStatus _VI_FUNC rssfu_GetAttributeViString (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViUInt32 attributeID,
                                              ViInt32 bufferSize,
                                              ViChar _VI_FAR attributeValue[]);
ViStatus _VI_FUNC rssfu_GetAttributeViBoolean (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViPBoolean attributeValue);
ViStatus _VI_FUNC rssfu_GetAttributeViSession (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViPSession attributeValue);
ViStatus _VI_FUNC rssfu_CheckAttributeViInt32 (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViInt32 attributeValue);
ViStatus _VI_FUNC rssfu_CheckAttributeViReal64 (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViReal64 attributeValue);
ViStatus _VI_FUNC rssfu_CheckAttributeViString (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViString attributeValue);
ViStatus _VI_FUNC rssfu_CheckAttributeViBoolean (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViBoolean attributeValue);
ViStatus _VI_FUNC rssfu_CheckAttributeViSession (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViSession attributeValue);
ViStatus _VI_FUNC rssfu_GetAttributeRepeatedCapabilityIds
             (ViSession instrumentHandle, ViUInt32 attributeID, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityId_s[]);
ViStatus _VI_FUNC rssfu_GetAttributeRepeatedCapabilityIdNames
             (ViSession instrumentHandle, ViUInt32 attributeID,
              ViString repeatedCapabilityId, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityIdName_s[]);
ViStatus _VI_FUNC rssfu_confNoise_obs (ViSession instrumentHandle, ViInt32 state,
                                       ViInt32 mode);
ViStatus _VI_FUNC rssfu_confNoiseParameters (ViSession instrumentHandle,
                                             ViReal64 cN, ViReal64 cNOffset,
                                             ViBoolean bandwidthCoupling,
                                             ViReal64 receiverBandwidth);
ViStatus _VI_FUNC rssfu_confNoisePulse_obs (ViSession instrumentHandle,
                                            ViInt32 pulses_perBurst,
                                            ViReal64 pulseSpacingMin,
                                            ViReal64 pulseSpacingMax);
ViStatus _VI_FUNC rssfu_confTDMBSettings (ViSession instrumentHandle,
                                          ViBoolean TDMBTTI, ViInt32 TIIMainSubID,
                                          ViInt32 TDMBNetwork, ViInt32 TDMBPRBS);
ViStatus _VI_FUNC rssfu_confDVBCNetwork (ViSession instrumentHandle,
                                         ViInt32 networkMode,
                                         ViReal64 additionalDelay);
ViStatus _VI_FUNC rssfu_readDMBTHCoderStatus (ViSession instrumentHandle,
                                              ViChar _VI_FAR status[]);
ViStatus _VI_FUNC rssfu_confDMBTHInputSignal (ViSession instrumentHandle,
                                              ViInt32 source, ViInt32 input,
                                              ViInt32 stuffing);
ViStatus _VI_FUNC rssfu_confDMBTHTestSignal (ViSession instrumentHandle,
                                             ViInt32 testSignal);
ViStatus _VI_FUNC rssfu_readDMBTHPackedLength (ViSession instrumentHandle,
                                               ViPInt32 packedLength);
ViStatus _VI_FUNC rssfu_readDMBTHValues (ViSession instrumentHandle, ViInt32 value,
                                         ViPReal64 result);
ViStatus _VI_FUNC rssfu_confDMBTHNetwork (ViSession instrumentHandle,
                                          ViInt32 networkMode);
ViStatus _VI_FUNC rssfu_confDMBTHControl (ViSession instrumentHandle,
                                          ViInt32 channelBandwidth);
ViStatus _VI_FUNC rssfu_confDMBTHCoding (ViSession instrumentHandle,
                                         ViInt32 constellation, ViInt32 codeRate,
                                         ViInt32 guardInterval,
                                         ViInt32 timeInterleaver);

ViStatus _VI_FUNC rssfu_readDMBTHSFNValues (ViSession instrumentHandle,
                                            ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfu_actEnableDMBTHSpecial (ViSession instrumentHandle,
                                               ViBoolean state);
ViStatus _VI_FUNC rssfu_confDMBTHSpecial (ViSession instrumentHandle,
                                          ViBoolean GIPowerBoost,
                                          ViInt32 LDPCOutput, ViInt32 PNPolarity,
                                          ViInt32 QAMConstellation,
                                          ViInt32 QPSKConstellation);
ViStatus _VI_FUNC rssfu_setDMBTHSpecialSingleCarrier (ViSession instrumentHandle,
                                                      ViBoolean singleCarrier);
ViStatus _VI_FUNC rssfu_confDMBTHSettings (ViSession instrumentHandle,
                                           ViBoolean controlFrames,
                                           ViInt32 testTSPacket,
                                           ViInt32 PIDTestPacket, ViInt32 PID,
                                           ViInt32 payloadTestStuff, ViInt32 PRBS);
ViStatus _VI_FUNC rssfu_storeLoadApplication (ViSession instrumentHandle,
                                              ViInt32 operation, ViString source);
ViStatus _VI_FUNC rssfu_storeLoadInstrumentData (ViSession instrumentHandle,
                                                 ViInt32 operation,
                                                 ViInt32 stateNumber);
ViStatus _VI_FUNC rssfu_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfu_ResetWithDefaults (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfu_Disable (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfu_self_test (ViSession instrumentHandle,
                                   ViPInt16 selfTestResult,
                                   ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rssfu_revision_query (ViSession instrumentHandle,
                                        ViChar _VI_FAR instrumentDriverRevision[],
                                        ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rssfu_error_query (ViSession instrumentHandle, ViPInt32 errorCode,
                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssfu_error_message (ViSession instrumentHandle,
                                       ViStatus errorCode,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssfu_SetOPCTimeout (ViSession instrumentHandle, ViInt32 timeout);
ViStatus _VI_FUNC rssfu_GetOPCTimeout (ViSession instrumentHandle,
                                       ViPInt32 timeout);
ViStatus _VI_FUNC rssfu_GetError (ViSession instrumentHandle, ViPStatus code,
                                  ViInt32 bufferSize, ViChar _VI_FAR description[]);
ViStatus _VI_FUNC rssfu_ClearError (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfu_LockSession (ViSession instrumentHandle,
                                     ViPBoolean callerHasLock);
ViStatus _VI_FUNC rssfu_UnlockSession (ViSession instrumentHandle,
                                       ViPBoolean callerHasLock);
ViStatus _VI_FUNC rssfu_WriteInstrData (ViSession instrumentHandle,
                                        ViString writeBuffer);
ViStatus _VI_FUNC rssfu_ReadInstrData (ViSession instrumentHandle,
                                       ViInt32 number_ofBytesToRead,
                                       ViChar _VI_FAR readBuffer[],
                                       ViPInt32 numBytesRead);
ViStatus _VI_FUNC rssfu_close (ViSession instrumentHandle);

    /*********************************************************
        Functions reserved for class driver use only.
        End-users should not call these functions.
     *********************************************************/

ViStatus _VI_FUNC  rssfu_RsInit (ViRsrc resourceName, ViBoolean IDQuery,
                                  ViBoolean reset, ViSession* vi);
ViStatus _VI_FUNC  rssfu_RsClose (ViSession vi);


ViStatus _VI_FUNC rssfu_SetErrorInfo (ViSession session,
                          ViBoolean overWrite,
                          ViStatus primaryError,
                          ViStatus secondaryError,
                          ViConstString errorElaboration);

ViStatus _VI_FUNC rssfu_GetErrorInfo (ViSession session,
                          ViStatus *primaryError,
                          ViStatus *secondaryError,
                          ViChar errorElaboration[]);
                 
                 /* OBSOLETE */
ViStatus _VI_FUNC rssfu_confDVBCNetwork (ViSession instrumentHandle,
                                         ViInt32 networkMode,
                                         ViReal64 additionalDelay);                 
ViStatus _VI_FUNC rssfu_confTDMBSettings (ViSession instrumentHandle,
                                          ViBoolean TDMBTTI, ViInt32 TIIMainSubID,
                                          ViInt32 TDMBNetwork, ViInt32 TDMBPRBS);
                 

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSSFU_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSSFU_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSSFU_ERROR_INSTRUMENT_DATA_NOT_AVAILABLE (RS_CLASS_ERROR_BASE + 0x0004L) 
#define RSSFU_ERROR_MARKER_NOT_ENABLED     (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSSFU_ERROR_NOT_DELTA_MARKER       (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSSFU_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define RSSFU_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSSFU_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSSFU_ERRMSG_MARKER_NOT_ENABLED    "Marker Not Enabled"
#define RSSFU_ERRMSG_NOT_DELTA_MARKER      "Not Delta Marker"
#define RSSFU_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define RSSFU_ERROR_CODES_AND_MSGS \
    {RSSFU_WARN_MEASURE_UNCALIBRATED,  RSSFU_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSSFU_WARN_OVER_RANGE,            RSSFU_WARNMSG_OVER_RANGE},\
    {RSSFU_ERROR_MARKER_NOT_ENABLED,   RSSFU_ERRMSG_MARKER_NOT_ENABLED},\
    {RSSFU_ERROR_NOT_DELTA_MARKER,     RSSFU_ERRMSG_NOT_DELTA_MARKER},\
    {RSSFU_ERROR_MAX_TIME_EXCEEDED,    RSSFU_ERRMSG_MAX_TIME_EXCEEDED}

#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
    

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/


#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSSFU_HEADER */
